/*
 * ErrorReporting methods tests
 * Testing ErrorReporting methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_error_new
 * Params: GQuark domain, gint code, const gchar *format, ...
 * Returns: GError*
 * Assertion: Creates a new GError with the given domain and code, and a message formatted with format.
 *            domain : error domain
 *            code : error code
 *            format : printf()-style format for error message
 *            ... : parameters for message format
 *            Returns : a new GError 
 * Params Values: Domain = "G_TEST_ERROR", Code = 1 
 * Expected: Create one GError  
 */
static void test_purpose_1()
{
    #define DOMAIN    "G_TEST_ERROR"
    #define CODE      1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GError *g_error = NULL;
    GQuark quark;
    
    quark = g_quark_from_static_string(DOMAIN);
    g_error = g_error_new(quark, CODE, "Test Error functions: %s", "g_error_new");
    if ((g_error->domain != quark) || (g_error->code != CODE) || (g_ascii_strcasecmp("Test Error functions: g_error_new", g_error->message) != 0)){
        TEST_FAIL("g_error_new: failed", NULL);
    }
    g_error_free(g_error);
    
    #undef DOMAIN
    #undef CODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_set_error
 * Params: GError *err, GQuark domain, gint code, const gchar *format, ...
 * Returns: void
 * Assertion: Does nothing if err is NULL; if err is non-NULL, then *err must be NULL. A new GError is created and assigned to *err.
 *            err : a return location for a GError, or NULL
 *            domain : error domain
 *            code : error code
 *            format : printf()-style format
 *            ... : args for format 
 * Params Values: Domain = "G_TEST_ERROR", Code = 1, Err = g_err
 * Expected: Set new err.  
 */
static void test_purpose_2()
{
    #define DOMAIN    "G_TEST_ERROR"
    #define CODE      1
    #define ERR       g_err
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GError *g_err = NULL;
    GQuark quark;
    
    quark = g_quark_from_static_string(DOMAIN);
    g_set_error(&g_err, quark, CODE+1, "New Error functions: %s", "g_set_error");
    if ((g_err->domain != quark) || (g_err->code != (CODE + 1)) || (g_ascii_strcasecmp("New Error functions: g_set_error", g_err->message) != 0)){
        TEST_FAIL("g_set_error: set error failed", NULL);
    }
    
    g_error_free(g_err);
    #undef DOMAIN
    #undef CODE
    #undef ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_error_new_literal
 * Params: GQuark domain, gint code, const gchar *message
 * Returns: GError*
 * Assertion: Creates a new GError; unlike g_error_new(), message is not a printf()-style format string. Use this function if message contains text you don't have control over, that could include printf() escape sequences. 
 *            domain : error domain
 *            code : error code
 * 	   message : error message
 *            Returns : a new GError 
 * Params Values: Domain = "G_TEST_ERROR", Code = 1 
 * Expected: Create one GError  
 */
static void test_purpose_3()
{
    #define DOMAIN    "G_TEST_ERROR"
    #define CODE      1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GError *g_error = NULL;
    GQuark quark;
    
    quark = g_quark_from_static_string(DOMAIN);
    g_error = g_error_new_literal(quark, CODE, "Test Error functions: g_error_new");
    if ((g_error->domain != quark) || (g_error->code != CODE) || (g_ascii_strcasecmp("Test Error functions: g_error_new", g_error->message) != 0)){
        TEST_FAIL("g_error_new_literal: failed", NULL);
    }
    g_error_free(g_error);
    
    #undef DOMAIN
    #undef CODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_error_copy
 * Params: const GError *error
 * Returns: GError*
 * Assertion: Makes a copy of error. 
 *            error : a GError
 *            Returns : a new GError
 * Params Values: g_err
 * Expected: Get the same GError  
 */
static void test_purpose_4()
{
    #define ERR    g_err
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GError *g_err = NULL, *g_new_err = NULL;
    GQuark quark;
    
    quark = g_quark_from_static_string("Copy Error");
    g_err = g_error_new_literal(quark, 1, "Test Error functions: g_error_copy");
    
    g_new_err = g_error_copy(ERR);
    if ((g_new_err->domain != quark) || (g_new_err->code != 1) || (g_ascii_strcasecmp("Test Error functions: g_error_copy", g_new_err->message) != 0)){
        TEST_FAIL("g_error_copy: failed", NULL);
    }
    g_error_free(g_err);
    g_error_free(g_new_err);
    #undef ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_propagate_error
 * Params: GError **dest, GError *src
 * Returns: void
 * Assertion: If dest is NULL, free src; otherwise, moves src into *dest. *dest must be NULL.
 *            dest : error return location
 *            src : error to move into the return location
 * Params Values: dest
 * Expected: *dest == src  
 */
static void test_purpose_5()
{
    #define DEST    dest
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GError *g_err = NULL, *dest = NULL;
    GQuark quark;
    
    dest = DEST;
    quark = g_quark_from_static_string("propagate Error");
    g_err = g_error_new_literal(quark, 1, "Test Error functions: g_propagate_error");
    
    g_propagate_error(&dest, g_err);
    if ((dest->domain != quark) || (dest->code != 1) || (g_ascii_strcasecmp("Test Error functions: g_propagate_error", dest->message) != 0)){
        TEST_FAIL("g_propagate_error: failed", NULL);
        g_error_free(g_err);
    }
    
    #undef DEST
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for ErrorReporting ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
