/*
 * GByteArray methods tests
 * Testing GByteArray methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_byte_array_new
 * Params: void 
 * Returns: GByteArray*
 * Assertion: Creates a new GByteArray.
 * Params Values:
 * Expected: GByteArray*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GByteArray *gba = NULL;
    gba = g_byte_array_new();
    if (gba == NULL){
        TEST_FAIL("g_byte_array_new: new error", NULL);
    }
    else{
        if (gba->len != 0){
            TEST_FAIL("g_byte_array_new: length should be 0", NULL);
        }
    }
    g_byte_array_free(gba, TRUE);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_byte_array_free
 * Params: GByteArray* array, gboolean free_segment
 * Returns: guint8*
 * Assertion: Frees the memory allocated by the GByteArray. If free_segment is TRUE it frees the actual byte data. 
 *            array : a GByteArray.    
 *            free_segment : if TRUE the actual byte data is freed as well 
 * Params Values: gba, TRUE           
 * Expected: NULL   
 */
static void test_purpose_2()
{
    #define GBA        gba
    #define FREE_SEG   TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GByteArray *gba = NULL;
    guint8 *ret;
    guint8 i = 0;
    
    gba = g_byte_array_new();
    for (i = 0; i < 10; i++){
        gba = g_byte_array_append(gba, &i, 1);
    }
    ret = g_byte_array_free(GBA, FREE_SEG);
    if (FREE_SEG){
        if (ret != NULL){
            TEST_FAIL("g_byte_array_free: data should be NULL", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_byte_array_append
 * Params: GByteArray *array, const guint8 *data, guint len
 * Returns: GByteArray*
 * Assertion: Adds the given bytes to the end of the GByteArray. The array will grow in size automatically if necessary
 *            array : a GByteArray.  
 *            data : the byte data to be added.  
 *            len : the number of bytes to add 
 * Params Values: gba, (guint8 *)"abcd", 4
 * Expected: "abcd"  
 */
static void test_purpose_3()
{
    #define GBA	    gba
    #define DATA    (guint8 *)"abcd"
    #define LEN     4
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GByteArray *gba = g_byte_array_new();
    guint8 i = 0;
    
    for (i = 0; i < 10; i++)
        GBA = g_byte_array_append(GBA, DATA, LEN);
    for (i = 0; i < 10; i++){
        if ((GBA->data[4*i] != 'a') || (GBA->data[4*i+1] != 'b')
           || (GBA->data[4*i+2] != 'c') || (GBA->data[4*i+3] != 'd')){
            TEST_FAIL("g_byte_array_append: append failed", NULL);
        }
    }
    g_byte_array_free(GBA, TRUE);
    
    #undef GBA
    #undef DATA
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_byte_array_set_size
 * Params: void 
 * Returns: GByteArray*
 * Assertion: Sets the size of the GByteArray, expanding it if necessary.
 *            array : a GByteArray.  
 *            length : the new size of the GByteArray. 
 * Params Values: gba, 10
 * Expected: 10  
 */
static void test_purpose_4()
{
    #define GBA	gba
    #define LEN	10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GByteArray *gba = g_byte_array_new();
    
    gba = g_byte_array_set_size(GBA, LEN);
    if (gba->len != LEN){
        TEST_FAIL("g_byte_array_set_size: size should be %d, now is %d", LEN, gba->len);
    }
    
    g_byte_array_free(gba, TRUE);
    
    #undef GAB
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GByteArray ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {NULL,0}
};
