/*
 * GMisc methods tests
 * Testing GMisc methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_getenv
 * Params: const gchar *variable
 * Returns: const gchar*
 * Assertion: Returns the value of an environment variable. The name and value are in the GLib file name encoding. On Unix, this means the actual bytes which might or might not be in some consistent character set and encoding. On Windows, it is in UTF-8. On Windows, in case the environment variable's value contains references to other environment variables, they are expanded.
 *            variable : the environment variable to get, in the GLib file name encoding.
 *            Returns : the value of the environment variable, or NULL if the environment variable is not found. The returned string may be overwritten by the next call to g_getenv(), g_setenv() or g_unsetenv(). 
 * Params Values: "TEST"
 * Expected: "lsb"  
 */
static void test_purpose_1()
{
    #define VAR    "TEST"
    #define VAL    "lsb"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_setenv(VAR, VAL, TRUE)){
        if (strcmp(g_getenv(VAR), VAL) != 0){
            TEST_FAIL("g_getenv: should be %s", VAL);
        }
    }
    
    #undef VAR
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_get_prgname
 * Params: void
 * Returns: gchar*
 * Assertion: Gets the name of the program. This name should not be localized, contrast with g_get_application_name(). (If you are using GDK or GTK+ the program name is set in gdk_init(), which is called by gtk_init(). The program name is found by taking the last component of argv[0].)
 *            Returns : the name of the program. The returned string belongs to GLib and must not be modified or freed. 
 * Params Values: void
 * Expected: "test"  
 */
static void test_purpose_2()
{
    #define PRGNAME    "test"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    g_set_prgname(PRGNAME);
    if (strcmp(g_get_prgname(), PRGNAME) != 0){
        TEST_FAIL("g_get_prgname: failed", NULL);
    }
    #undef PRGNAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_basename
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the last component of the filename. If file_name ends with a directory separator it gets the component before the last slash. If file_name consists only of directory separators (and on Windows, possibly a drive letter), a single separator is returned. If file_name is empty, it gets ".".
 *            file_name : the name of the file.
 *            Returns : a newly allocated string containing the last component of the filename. 
 * Params Values: "/root/mike"
 * Expected: "mike"  
 */
static void test_purpose_3()
{
    #define FILENAME    "/root/mike"
    #define RETS        "mike"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_basename(FILENAME), RETS) != 0){
        TEST_FAIL("g_path_get_basename: now is %s, should be %s", g_path_get_basename(FILENAME), RETS);
    }
    
    #undef FILENAME
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_basename
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the last component of the filename. If file_name ends with a directory separator it gets the component before the last slash. If file_name consists only of directory separators (and on Windows, possibly a drive letter), a single separator is returned. If file_name is empty, it gets ".".
 *            file_name : the name of the file.
 *            Returns : a newly allocated string containing the last component of the filename. 
 * Params Values: "/root/mike/"
 * Expected: "mike"  
 */
static void test_purpose_4()
{
    #define FILENAME    "/root/mike/"
    #define RETS        "mike"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_basename(FILENAME), RETS) != 0){
        TEST_FAIL("g_path_get_basename: now is %s, should be %s", g_path_get_basename(FILENAME), RETS);
    }
    
    #undef FILENAME
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_basename
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the last component of the filename. If file_name ends with a directory separator it gets the component before the last slash. If file_name consists only of directory separators (and on Windows, possibly a drive letter), a single separator is returned. If file_name is empty, it gets ".".
 *            file_name : the name of the file.
 *            Returns : a newly allocated string containing the last component of the filename. 
 * Params Values: "/"
 * Expected: "/"  
 */
static void test_purpose_5()
{
    #define FILENAME    "/"
    #define RETS        "/"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_basename(FILENAME), RETS) != 0){
        TEST_FAIL("g_path_get_basename: now is %s, should be %s", g_path_get_basename(FILENAME), RETS);
    }
    
    #undef FILENAME
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_basename
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the last component of the filename. If file_name ends with a directory separator it gets the component before the last slash. If file_name consists only of directory separators (and on Windows, possibly a drive letter), a single separator is returned. If file_name is empty, it gets ".".
 *            file_name : the name of the file.
 *            Returns : a newly allocated string containing the last component of the filename. 
 * Params Values: ""
 * Expected: "."  
 */
static void test_purpose_6()
{
    #define FILENAME    ""
    #define RETS        "."
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_basename(FILENAME), RETS) != 0){
        TEST_FAIL("g_path_get_basename: now is %s, should be %s", g_path_get_basename(FILENAME), RETS);
    }
    
    #undef FILENAME
    #undef RETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_build_filename
 * Params: const gchar *first_element, ...
 * Returns: gchar*
 * Assertion: Creates a filename from a series of elements using the correct separator for filenames.
 * On Unix, this function behaves identically to g_build_path (G_DIR_SEPARATOR_S, first_element, ....).
 * On Windows, it takes into account that either the backslash (\ or slash (/) can be used as separator in filenames, but otherwise behaves as on Unix. When file pathname separators need to be inserted, the one that last previously occurred in the parameters (reading from left to right) is used.
 * No attempt is made to force the resulting filename to be an absolute path. If the first element is a relative path, the result will be a relative path.
 *            first_element : the first element in the path
 *            ... : remaining elements in path, terminated by NULL
 *            Returns : a newly-allocated string that must be freed with g_free(). 
 * Params Values: "/root", "test.txt", NULL
 * Expected: "/root/test.txt"  
 */
static void test_purpose_7()
{
    #define STR1    "/root"
    #define STR2    "test.txt"
    #define STR3    NULL
    #define STRS    "/root/test.txt"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_build_filename(STR1, STR2, STR3), STRS) != 0){
        TEST_FAIL("g_build_filename: should be %s", STRS);
    }
    #undef STR1
    #undef STR2
    #undef STR3
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_get_home_dir
 * Params: void
 * Returns: const gchar*
 * Assertion: Gets the current user's home directory.
 * Note that in contrast to traditional Unix tools, this function prefers passwd entries over the HOME environment variable.
 *            Returns : the current user's home directory.
 * Params Values: void
 * Expected: current user's home directory  
 */
static void test_purpose_8()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_get_home_dir(), g_getenv("HOME")) != 0){
        TEST_FAIL("g_get_home_dir: should be %s, now is %s", g_getenv("HOME"), g_get_home_dir());
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_is_absolute
 * Params: const gchar *file_name
 * Returns: gboolean
 * Assertion: Returns TRUE if the given file_name is an absolute file name, i.e. it contains a full path from the root directory such as '/usr/local' on UNIX or 'C:\windows' on Windows systems.
 *            file_name : a file name.
 *            Returns : TRUE if file_name is an absolute path.
 * Params Values: "/usr/local/bin"
 * Expected: TRUE  
 */
static void test_purpose_9()
{
    #define FILE_NAME    "/usr/local/bin"
    #define RETB         TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_path_is_absolute(FILE_NAME) != RETB){
        TEST_FAIL("g_path_is_absolute: failed", NULL);
    }
        
    #undef FILE_NAME
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_is_absolute
 * Params: const gchar *file_name
 * Returns: gboolean
 * Assertion: Returns TRUE if the given file_name is an absolute file name, i.e. it contains a full path from the root directory such as '/usr/local' on UNIX or 'C:\windows' on Windows systems.
 *            file_name : a file name.
 *            Returns : TRUE if file_name is an absolute path.
 * Params Values: "mike/tmp"
 * Expected: FALSE  
 */
static void test_purpose_10()
{
    #define FILE_NAME    "mike/tmp"
    #define RETB         FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_path_is_absolute(FILE_NAME) != RETB){
        TEST_FAIL("g_path_is_absolute: failed", NULL);
    }
        
    #undef FILE_NAME
    #undef RETB
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_dirname
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the directory components of a file name. If the file name has no directory components "." is returned. The returned string should be freed when no longer needed.
 *            file_name : the name of the file.
 *            Returns : the directory components of the file.
 * Params Values: "/"
 * Expected: "/"  
 */
static void test_purpose_11()
{
    #define FILENAME    "/"
    #define DIRNAME     "/"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_dirname(FILENAME), DIRNAME) != 0){
        TEST_FAIL("g_path_get_dirname: failed", NULL);
    }
    #undef FILENAME
    #undef DIRNAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_dirname
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the directory components of a file name. If the file name has no directory components "." is returned. The returned string should be freed when no longer needed.
 *            file_name : the name of the file.
 *            Returns : the directory components of the file.
 * Params Values: "////"
 * Expected: "/"  
 */
static void test_purpose_12()
{
    #define FILENAME    "////"
    #define DIRNAME     "/"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_dirname(FILENAME), DIRNAME) != 0){
        TEST_FAIL("g_path_get_dirname: failed", NULL);
    }
    #undef FILENAME
    #undef DIRNAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_dirname
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the directory components of a file name. If the file name has no directory components "." is returned. The returned string should be freed when no longer needed.
 *            file_name : the name of the file.
 *            Returns : the directory components of the file.
 * Params Values: "..////"
 * Expected: ".."  
 */
static void test_purpose_13()
{
    #define FILENAME    "..////"
    #define DIRNAME     ".."
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_dirname(FILENAME), DIRNAME) != 0){
        TEST_FAIL("g_path_get_dirname: failed", NULL);
    }
    #undef FILENAME
    #undef DIRNAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_path_get_dirname
 * Params: const gchar *file_name
 * Returns: gchar*
 * Assertion: Gets the directory components of a file name. If the file name has no directory components "." is returned. The returned string should be freed when no longer needed.
 *            file_name : the name of the file.
 *            Returns : the directory components of the file.
 * Params Values: "a/b/"
 * Expected: "a/b"  
 */
static void test_purpose_14()
{
    #define FILENAME    "a/b/"
    #define DIRNAME     "a/b"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_path_get_dirname(FILENAME), DIRNAME) != 0){
        TEST_FAIL("g_path_get_dirname: failed", NULL);
    }
    #undef FILENAME
    #undef DIRNAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_get_tmp_dir
 * Params: void
 * Returns: const gchar*
 * Assertion: Gets the directory to use for temporary files. This is found from inspecting the environment variables TMPDIR, TMP, and TEMP in that order. If none of those are defined "/tmp" is returned on UNIX and "C:\" on Windows. The encoding of the returned string is system defined. On Windows, it is always UTF-8. The return value is never NULL.
 * Returns : the directory to use for temporary files.
 * Params Values: void
 * Expected: "/tmp"  
 */
static void test_purpose_15()
{
    #define TMP_DIR    "/tmp"
    
    const gchar *tmpdir = NULL;
    const gchar *tmp = NULL;
    const gchar *temp = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tmpdir = g_getenv ("TMPDIR");
    tmp = g_getenv ("TMP");
    temp = g_getenv ("TEMP");
    
    if (tmpdir)
    {
        if (strcmp (g_get_tmp_dir (), tmpdir)) {
            TEST_FAIL ("Environment variable TMPDIR is set to %s, g_get_tmp_dir() returns %s", tmpdir, g_get_tmp_dir (), NULL);
            return;
        } else {
            test_passed ();
            return;
        }
    }
    
    if (tmp)
    {
        if (strcmp (g_get_tmp_dir (), tmp)) {
            TEST_FAIL ("Environment variable TMP is set to %s, g_get_tmp_dir() returns %s", tmp, g_get_tmp_dir (), NULL);
            return;
        } else {
            test_passed ();
            return;
        }
    }
    
    if (temp)
    {
        if (strcmp (g_get_tmp_dir (), temp)) {
            TEST_FAIL ("Environment variable TEMP is set to %s, g_get_tmp_dir() returns %s", temp, g_get_tmp_dir (), NULL);
            return;
        } else {
            test_passed ();
            return;
        }
    }
    
    if (strcmp (g_get_tmp_dir(), TMP_DIR) != 0)
    {
        TEST_FAIL("g_get_tmp_dir() should return %s, rather than %s", TMP_DIR, g_get_tmp_dir());
        return;
    }
    
    #undef TMP_DIR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_find_program_in_path
 * Params: const gchar *program
 * Returns: gchar*
 * Assertion: Locates the first executable named program in the user's path, in the same way that execvp() would locate it. Returns an allocated string with the absolute path name, or NULL if the program is not found in the path. If program is already an absolute path, returns a copy of program if program exists and is executable, and NULL otherwise. On Windows, if program does not have a file type suffix, tries with the suffixes .exe, .cmd, .bat and .com, and the suffixes in the PATHEXT environment variable.
 * It looks for the file in the same way as CreateProcess() would. This means first in the directory where the executing program was loaded from, then in the current directory, then in the Windows 32-bit system directory, then in the Windows directory, and finally in the directories in the PATH environment variable. If the program is found, the return value contains the full name including the type suffix.
 *            program : a program name in the GLib file name encoding
 *            Returns : absolute path, or NULL
 * Params Values: "ls"
 * Expected: "/bin/ls"  
 */
static void test_purpose_16()
{
    #define PROG    "ls"
    #define PATH    "/bin/ls"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_find_program_in_path(PROG), PATH) != 0){
        TEST_FAIL("g_find_program_in_path: failed", NULL);
    }
    #undef PROG
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_build_path
 * Params: const gchar *separator, const gchar *first_element, ...
 * Returns: gchar*
 * Assertion: Creates a path from a series of elements using separator as the separator between elements. At the boundary between two elements, any trailing occurrences of separator in the first element, or leading occurrences of separator in the second element are removed and exactly one copy of the separator is inserted.
 * Empty elements are ignored. 
 *            separator : a string used to separator the elements of the path.
 *            first_element : the first element in the path
 *            ... : remaining elements in path, terminated by NULL
 *            Returns : a newly-allocated string that must be freed with g_free().
 * Params Values: "", "x", "y", NULL
 * Expected: "xy"  
 */
static void test_purpose_17()
{
    #define SEPA    ""
    #define STR1    "x"
    #define STR2    "y"
    #define STR3    NULL
    #define STRS    "xy"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_build_path(SEPA, STR1, STR2, STR3), STRS) != 0){
        TEST_FAIL("g_build_path: failed", NULL);
    }
    #undef SEPA
    #undef STR1
    #undef STR2
    #undef STR3
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_build_path
 * Params: const gchar *separator, const gchar *first_element, ...
 * Returns: gchar*
 * Assertion: Creates a path from a series of elements using separator as the separator between elements. At the boundary between two elements, any trailing occurrences of separator in the first element, or leading occurrences of separator in the second element are removed and exactly one copy of the separator is inserted.
 * Empty elements are ignored. 
 *            separator : a string used to separator the elements of the path.
 *            first_element : the first element in the path
 *            ... : remaining elements in path, terminated by NULL
 *            Returns : a newly-allocated string that must be freed with g_free().
 * Params Values: ":", "x", "y", NULL
 * Expected: "x:y"  
 */
static void test_purpose_18()
{
    #define SEPA    ":"
    #define STR1    "x"
    #define STR2    "y"
    #define STR3    NULL
    #define STRS    "x:y"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_build_path(SEPA, STR1, STR2, STR3), STRS) != 0){
        TEST_FAIL("g_build_path: failed", NULL);
    }
    #undef SEPA
    #undef STR1
    #undef STR2
    #undef STR3
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_build_path
 * Params: const gchar *separator, const gchar *first_element, ...
 * Returns: gchar*
 * Assertion: Creates a path from a series of elements using separator as the separator between elements. At the boundary between two elements, any trailing occurrences of separator in the first element, or leading occurrences of separator in the second element are removed and exactly one copy of the separator is inserted.
 * Empty elements are ignored. 
 *            separator : a string used to separator the elements of the path.
 *            first_element : the first element in the path
 *            ... : remaining elements in path, terminated by NULL
 *            Returns : a newly-allocated string that must be freed with g_free().
 * Params Values: "::", "x", "y", NULL
 * Expected: "x::y"  
 */
static void test_purpose_19()
{
    #define SEPA    "::"
    #define STR1    "x"
    #define STR2    "y"
    #define STR3    NULL
    #define STRS    "x::y"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (strcmp(g_build_path(SEPA, STR1, STR2, STR3), STRS) != 0){
        TEST_FAIL("g_build_path: failed", NULL);
    }
    #undef SEPA
    #undef STR1
    #undef STR2
    #undef STR3
    #undef STRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_spaced_primes_closest
 * Params: guint num
 * Returns: guint
 * Assertion: Gets the smallest prime number from a built-in array of primes which is larger than num. This is used within GLib to calculate the optimum size of a GHashTable.
 * The built-in array of primes ranges from 11 to 13845163 such that each prime is approximately 1.5-2 times the previous prime.
 *            num : a guint.
 *            Returns : the smallest prime number from a built-in array of primes which is larger than num.
 * Params Values: 10
 * Expected: 11  
 */
static void test_purpose_20()
{
    #define NUM    10
    #define PRI    11
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_spaced_primes_closest(NUM) != PRI){
        TEST_FAIL("g_spaced_primes_closest: failed", NULL);
    }
    #undef NUM
    #undef PRI
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_spaced_primes_closest
 * Params: guint num
 * Returns: guint
 * Assertion: Gets the smallest prime number from a built-in array of primes which is larger than num. This is used within GLib to calculate the optimum size of a GHashTable.
 * The built-in array of primes ranges from 11 to 13845163 such that each prime is approximately 1.5-2 times the previous prime.
 *            num : a guint.
 *            Returns : the smallest prime number from a built-in array of primes which is larger than num.
 * Params Values: 10459
 * Expected: 14057  
 */
static void test_purpose_21()
{
    #define NUM    10459
    #define PRI    14057
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (g_spaced_primes_closest(NUM) != PRI){
        TEST_FAIL("g_spaced_primes_closest: failed", NULL);
    }
    #undef NUM
    #undef PRI
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GMisc ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {NULL,0}
};
