/*
 * GObject-GType methods tests
 * Testing GObject-GType methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
int struc_cmp (char *str1,char *str2,int size)
{
    int i,length;
    length = size - 1;
    for (i = 0;i < length;i++)
        if (str1[i] != str2[i])
            return 0;
    return 1;
}

/*-------------Test Interface Object-----------*/

#define TEST_TYPE_IFACE           (test_iface_get_type ())
typedef struct _TestIface      TestIface;
typedef struct _TestIfaceClass TestIfaceClass;

struct _TestIface
{
    int param1;
    gchar *str;
    void (*set_param)(TestIface *iface,int param);
};

struct _TestIfaceClass
{
  GTypeInterface base_iface;
  void	(*print_string)	(TestIface	*tiobj,
			 const gchar	*string);
};
static void	iface_base_init		(TestIfaceClass	*iface);
static void	iface_base_finalize	(TestIfaceClass	*iface);

GType
test_iface_get_type (void)
{
  static GType test_iface_type = 0;

  if (!test_iface_type)
    {
      static const GTypeInfo test_iface_info =
      {
	sizeof (TestIfaceClass),
	(GBaseInitFunc)	iface_base_init,		/* base_init */
	(GBaseFinalizeFunc) iface_base_finalize,	/* base_finalize */
      };

      test_iface_type = g_type_register_static (G_TYPE_INTERFACE, "TestIface", &test_iface_info, 0);
      g_type_interface_add_prerequisite (test_iface_type, G_TYPE_OBJECT);
    }

  return test_iface_type;
}

static void
iface_base_init (TestIfaceClass *iface)
{
}
static void
iface_base_finalize (TestIfaceClass *iface)
{
}

/*------------TestObject------------*/
#define TEST_TYPE_OBJECT            (test_object_get_type ())
#define TEST_OBJECT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TEST_TYPE_OBJECT, TestObjectClass))

typedef struct _TestObject        TestObject;
typedef struct _TestObjectClass   TestObjectClass;

static void test_object_test_iface_init (gpointer giface,gpointer iface_data);
static void     test_object_class_init  (TestObjectClass        *class);
/*
*static void     test_object_init        (TestObject             *tobject);
*
*static gboolean test_signal_accumulator (GSignalInvocationHint  *ihint,
*                                        GValue                 *return_accu,
*                                        const GValue           *handler_return,
*                                         gpointer                data);
*/
static gchar*   test_object_test_signal (TestObject             *tobject,
                                         TestIface              *iface_object,
                                         gpointer                tdata);



struct _TestObject
{
  GObject parent_instance;
};

struct _TestObjectClass
{
  GObjectClass parent_class;

  gchar* (*test_signal) (TestObject *tobject,
                         TestIface  *iface_object,
                         gpointer    tdata);
};

static const GTypeInfo test_object_info =
{
  sizeof (TestObjectClass),
  NULL,           /* base_init */
  NULL,           /* base_finalize */
  (GClassInitFunc) test_object_class_init,
  NULL,           /* class_finalize */
  NULL,           /* class_data */
  sizeof (TestObject),
  0,              /* n_preallocs */
  NULL,           /*(GInstanceInitFunc) test_object_init,*/
};

GType
test_object_get_type (void)
{
  static GType test_object_type = 0;

  if (!test_object_type)
    {
      GInterfaceInfo iface_info = { test_object_test_iface_init, NULL, GUINT_TO_POINTER (42) };

      test_object_type = g_type_register_static (G_TYPE_OBJECT, "TestObject", &test_object_info, 0);
      g_type_add_interface_static (test_object_type, TEST_TYPE_IFACE, &iface_info);
    }

  return test_object_type;
}

static void
test_object_test_iface_init (gpointer giface,
			     gpointer iface_data)
{
  TestIfaceClass *iface = giface;

  g_assert (iface_data == GUINT_TO_POINTER (42));
}

static void
test_object_class_init (TestObjectClass *class)
{
  /*  GObjectClass *gobject_class = G_OBJECT_CLASS (class); */

  class->test_signal = test_object_test_signal;

}

static gchar*
test_object_test_signal (TestObject *tobject,
                         TestIface  *iface_object,
                         gpointer    tdata)
{
  g_message ("::test_signal default_handler called");

  return g_strdup ("<default_handler>");
}

/*-------------DerivedObject--------------*/
#define DERIVED_TYPE_OBJECT            (derived_object_get_type ())
#define DERIVED_OBJECT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), DERIVED_TYPE_OBJECT, DerivedObjectClass))

typedef struct _DerivedObject        DerivedObject;
typedef struct _DerivedObjectClass      DerivedObjectClass;

struct _DerivedObject
{
  TestObject parent_instance;
  int  dummy1;
  int  dummy2;
};

struct _DerivedObjectClass
{
  TestObjectClass parent_class;
  char dummy;
};

static void derived_object_class_init (DerivedObjectClass *class);
static void derived_object_init       (DerivedObject      *dobject);

GType
derived_object_get_type (void)
{
  static GType derived_object_type = 0;

  if (!derived_object_type)
    {
      static const GTypeInfo derived_object_info =
      {
        sizeof (DerivedObjectClass),
        NULL,           /* base_init */
        NULL,           /* base_finalize */
        (GClassInitFunc) derived_object_class_init,
        NULL,           /* class_finalize */
        NULL,           /* class_data */
        sizeof (DerivedObject),
        0,              /* n_preallocs */
        NULL,           /*(GInstanceInitFunc) derived_object_init,*/
      };

      derived_object_type = g_type_register_static (TEST_TYPE_OBJECT, "DerivedObject", &derived_object_info, 0);
    }

  return derived_object_type;
}

static void
derived_object_class_init (DerivedObjectClass *class)
{
    
}



/*
 * Name: g_type_register_static
 * Params: GType parent_type,const gchar *type_name,const GTypeInfo *info,GTypeFlags flags
 * Returns: The new type identifier.
 * Assertion: Registers type_name as the name of a new static type derived from parent_type. The type system uses the information contained in the GTypeInfo structure pointed to by info to manage the type and its instances (if not abstract). The value of flags determines the nature (e.g. abstract or not) of the type.
 * Params Values: G_TYPE_OBJECT,"TestObject1",&test_object_info,0
 * Expected: register a new static type with name "TestObject1" derived from G_TYPE_OBJECT
 *   
 */
static void test_purpose_1()
{
    #define PARENT_TYPE G_TYPE_OBJECT
    #define TYPE_NAME "TestObject1"
    #define INFO &test_object_info
    #define FLAG 0
    
    GType test_object_type = 0;
    GType get_object_type;
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    /*Register a new static type derived from PARENT_TYPE.*/
    test_object_type = g_type_register_static (PARENT_TYPE,TYPE_NAME,INFO,FLAG);
    
    /*Get the new registered static type by name.*/
    get_object_type = g_type_from_name(TYPE_NAME);
    
    /*Check whether the type is registered correctly.*/
    if (test_object_type != get_object_type)
    {
        TEST_FAIL("ERROR! Type is not registered correctly!\n",NULL);
    }
    
    #undef PARENT_TYPE
    #undef TYPE_NAME
    #undef INFO
    #undef FLAG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_register_static
 * Params: GType parent_type,const gchar *type_name,const GTypeInfo *info,GTypeFlags flags
 * Returns: The new type identifier.
 * Assertion: Registers type_name as the name of a new static type derived from parent_type. The type system uses the information contained in the GTypeInfo structure pointed to by info to manage the type and its instances (if not abstract). The value of flags determines the nature (e.g. abstract or not) of the type.
 * Params Values: G_TYPE_OBJECT,"TestObject2",&test_object_info,0
 * Expected: register a new static type with name "TestObject2" derived from G_TYPE_OBJECT
 *   
 */
static void test_purpose_2()
{
    #define PARENT_TYPE G_TYPE_OBJECT
    #define TYPE_NAME "TestObject2"
    #define INFO &test_object_info
    #define FLAG 0
    
    GType test_object_type = 0;
    GType get_object_type;
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    /*Register a new static type derived from PARENT_TYPE.*/
    test_object_type = g_type_register_static (PARENT_TYPE,TYPE_NAME,INFO,FLAG);
    
    /*Get the new registered static type by name.*/
    get_object_type = g_type_from_name(TYPE_NAME);
    
    /*Check whether the type is registered correctly.*/
    if (test_object_type != get_object_type)
    {
        TEST_FAIL("ERROR! Type is not registered correctly!\n",NULL);
    }
    
    #undef PARENT_TYPE
    #undef TYPE_NAME
    #undef INFO
    #undef FLAG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_register_static
 * Params: GType parent_type,const gchar *type_name,const GTypeInfo *info,GTypeFlags flags
 * Returns: The new type identifier.
 * Assertion: Registers type_name as the name of a new static type derived from parent_type. The type system uses the information contained in the GTypeInfo structure pointed to by info to manage the type and its instances (if not abstract). The value of flags determines the nature (e.g. abstract or not) of the type.
 * Params Values: G_TYPE_OBJECT,"TestObject3",&test_object_info,0
 * Expected: register a new static type with name "TestObject3" derived from G_TYPE_OBJECT
 *   
 */
static void test_purpose_3()
{
    #define PARENT_TYPE G_TYPE_OBJECT
    #define TYPE_NAME "TestObject3"
    #define INFO &test_object_info
    #define FLAG 0
    
    GType test_object_type = 0;
    GType get_object_type;
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    /*Register a new static type derived from PARENT_TYPE.*/
    test_object_type = g_type_register_static (PARENT_TYPE,TYPE_NAME,INFO,FLAG);
    
    /*Get the new registered static type by name.*/
    get_object_type = g_type_from_name(TYPE_NAME);
    
    /*Check whether the type is registered correctly.*/
    if (test_object_type != get_object_type)
    {
        TEST_FAIL("ERROR! Type is not registered correctly!\n",NULL);
    }
    
    #undef PARENT_TYPE
    #undef TYPE_NAME
    #undef INFO
    #undef FLAG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_peek_parent
 * Params: gpointer g_class
 * Returns: The parent class of g_class.
 * Assertion: It essentially takes the immediate parent type of the class passed in, and returns the class structure thereof. Since derived classes hold a reference count on their parent classes as long as they are instantiated, the returned class will always exist.
 * Params Values: g_class
 * Expected: parent class of g_class
 *   
 */
static void test_purpose_4()
{
    #define GCLASS g_class
    
    TestObjectClass *g_class;
    DerivedObjectClass *parent_class;
    TestObjectClass *test_object_class;
    TestObject *test_object;
    DerivedObject *derived_object;
    GType derived_object_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a TestObject as parent object.*/
    test_object = g_object_new(TEST_TYPE_OBJECT,NULL);
    
    /*Get class of the TestObject.*/
    parent_class = TEST_OBJECT_GET_CLASS(test_object);
    
    /*Create a derived object.*/
    derived_object_type = derived_object_get_type();
    derived_object = g_object_new(derived_object_type,NULL);
    
    /*Get class of the derived object.*/
    g_class = DERIVED_OBJECT_GET_CLASS(derived_object);
    
    /*Get parent class of the derived object.*/
    parent_class = g_type_class_peek_parent(GCLASS);
    
    /*Check the parent class got.It's just the class of the object TestObject.*/
    if (!struc_cmp((char *)parent_class,(char *)parent_class,sizeof(TestObjectClass)))
    {
        TEST_FAIL("Parent class got uncorrectly!\n",NULL);
    }
    
    #undef GCLASS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_ref
 * Params: GType type
 * Returns: The GTypeClass structure for the given type ID.
 * Assertion: Increments the reference count of the class structure belonging to type. This function will demand-create the class if it doesn't exist already.
 * Params Values: g_type
 * Expected: GTypeClass structure of GType g_type.
 *   
 */
static void test_purpose_5()
{
    #define GTYPE g_type
    
    
    GType g_type = 0;
    TestObjectClass *g_class;
    /*TypeNode *node;*/
    guint ref_num;
    GObject *g_object;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    g_type = test_object_get_type();
    
    if (g_type == 0)
    {
        TEST_FAIL("Type creation error!\n",NULL);
    }
    g_class = g_type_class_ref(GTYPE);
    
    /*node = lookup_type_node_I(g_type);*/
    g_object = (GObject *)g_type;
    
    ref_num = g_object->ref_count;
    /*ref_num = node->data->common.ref_count;*/
    
    /*g_printf("Reference number is %d.\n",ref_num);*/
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_name
 * Params: GType type
 * Returns: Static type name or NULL.
 * Assertion: Returns the unique name that is assigned to a type ID (this is the preferred method to find out whether a specific type has been registered for the passed in ID yet).
 * Params Values: test_object_type
 * Expected: Name of GType test_object_type.
 *   
 */
static void test_purpose_6()
{
    #define TYPE test_object_type
    
    GType test_object_type = 0;
    const gchar *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    /*Get type ID of the registered static type.*/
    test_object_type = test_object_get_type();
    
    /*Get name of the static type.*/
    name = g_type_name(TYPE);
    
    /*Check the name of the type gotten.*/
    if (TYPE){
        if (strcmp(name,"TestObject"))
            TEST_FAIL("Get type name error!\n",NULL);
    
    }
    else if (name)
        TEST_FAIL("Get type name error!\n",NULL);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_name
 * Params: GType type
 * Returns: Static type name or NULL.
 * Assertion: Returns the unique name that is assigned to a type ID (this is the preferred method to find out whether a specific type has been registered for the passed in ID yet).
 * Params Values: 0
 * Expected: Name of GType 0.
 *   
 */
static void test_purpose_7()
{
    #define TYPE 0
    
    GType test_object_type = 0;
    const gchar *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    /*Get type ID of the registered static type.*/
    test_object_type = test_object_get_type();
    
    /*Get name of the static type.*/
    name = g_type_name(TYPE);
    
    /*Check the name of the type gotten.*/
    if (TYPE){
        if (strcmp(name,"TestObject"))
            TEST_FAIL("Get type name error!\n",NULL);
    
    }
    else if (name)
        TEST_FAIL("Get type name error!\n",NULL);
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_is_a
 * Params: GType type, GType is_a_type
 * Returns: TRUE if type is_a is_a_type holds true.
 * Assertion: If is_a_type is a derivable type, check whether type is a descendant of is_a_type. If is_a_type is an interface, check whether type conforms to it.
 * Params Values: DERIVED_TYPE_OBJECT,TEST_TYPE_OBJECT
 * Expected: TRUE if DERIVED_TYPE_OBJECT is derived from TEST_TYPE_OBJECT,FALSE otherwise.
 *   
 */
static void test_purpose_8()
{
    #define TYPE DERIVED_TYPE_OBJECT
    #define IS_A_TYPE TEST_TYPE_OBJECT
    
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Check whether TYPE is derived from IS_A_TYPE.*/
    rlt = g_type_is_a(TYPE,IS_A_TYPE);
    
    /*Verify the test result.*/
    if (TYPE != DERIVED_TYPE_OBJECT)
    {
        if (rlt)
        {
            TEST_FAIL("Type_is_a got wrong result!\n",NULL);
        }
    }
    else if (!rlt)
    {
        TEST_FAIL("Type_is_a got wrong result!\n",NULL);
    }
    
    #undef TYPE
    #undef IS_A_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_is_a
 * Params: GType type, GType is_a_type
 * Returns: TRUE if type is_a is_a_type holds true.
 * Assertion: If is_a_type is a derivable type, check whether type is a descendant of is_a_type. If is_a_type is an interface, check whether type conforms to it.
 * Params Values: TEST_TYPE_OBJECT,DERIVED_TYPE_OBJECT
 * Expected: TRUE if TEST_TYPE_OBJECT is derived from DERIVED_TYPE_OBJECT,FALSE otherwise.
 *   
 */
static void test_purpose_9()
{
    #define TYPE TEST_TYPE_OBJECT
    #define IS_A_TYPE DERIVED_TYPE_OBJECT
    
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Check whether TYPE is derived from IS_A_TYPE.*/
    rlt = g_type_is_a(TYPE,IS_A_TYPE);
    
    /*Verify the test result.*/
    if (TYPE != DERIVED_TYPE_OBJECT)
    {
        if (rlt)
        {
            TEST_FAIL("Type_is_a got wrong result!\n",NULL);
        }
    }
    else if (!rlt)
    {
        TEST_FAIL("Type_is_a got wrong result!\n",NULL);
    }
    
    #undef TYPE
    #undef IS_A_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_unref
 * Params: gpointer g_class
 * Returns: void
 * Assertion: Decrements the reference count of the class structure being passed in.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_10()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_unref
 * Params: gpointer g_class
 * Returns: void
 * Assertion: Decrements the reference count of the class structure being passed in.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_11()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_unref
 * Params: gpointer g_class
 * Returns: void
 * Assertion: Decrements the reference count of the class structure being passed in.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_12()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_peek
 * Params: GType type
 * Returns: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Assertion: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_13()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_peek
 * Params: GType type
 * Returns: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Assertion: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_14()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_class_peek
 * Params: GType type
 * Returns: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Assertion: The GTypeClass structure for the given type ID or NULL if the class does not currently exist.
 * Params Values: ,<%1%>
 * Expected: <%1%>
 *   
 */
static void test_purpose_15()
{
    
    
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_children
 * Params: GType type, guint *n_children
 * Returns: Newly allocated and 0-terminated array of child types.
 * Assertion: Return a newly allocated and 0-terminated array of type IDs, listing the child types of type. The return value has to be g_free()ed after use.
 * Params Values: test_object_type,n_children
 * Expected: Array of child types.
 *   
 */
static void test_purpose_16()
{
    #define TYPE test_object_type
    #define N_CHILDREN n_children
    
    GType *type_list;
    GType test_object_type;
    GType derived_object_type;
    guint *n_children;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    n_children = g_new0(guint,1);
    
    /*Get the test object type.*/
    test_object_type = test_object_get_type();
    
    /*Get the derived object type.*/
    derived_object_type = derived_object_get_type();
    
    /*Get children of the test object type.*/
    type_list = g_type_children(TYPE,N_CHILDREN);
    
    /*g_printf("Number of children is %d.\n",*n_children);*/
    
    /*g_printf("Children type ID is %d.\n",type_list[*n_children]);*/
    
    /*Check the number of the children object type got.*/
    if (N_CHILDREN != NULL)
    {
        if (*n_children != 1)
        {
            TEST_FAIL("Number of children is not correctly gotten!\n",NULL);
        } 
    
       if (type_list[*n_children] != 0)
        {
            TEST_FAIL("The last elment is not 0!\n",NULL);
        }
    }
    else if (type_list[0] == 0)
    {
       TEST_FAIL("Type ID got is not correct.\n",NULL);
    }
    
    g_free(n_children);
    
    #undef TYPE
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_children
 * Params: GType type, guint *n_children
 * Returns: Newly allocated and 0-terminated array of child types.
 * Assertion: Return a newly allocated and 0-terminated array of type IDs, listing the child types of type. The return value has to be g_free()ed after use.
 * Params Values: test_object_type,NULL
 * Expected: Array of child types.
 *   
 */
static void test_purpose_17()
{
    #define TYPE test_object_type
    #define N_CHILDREN NULL
    
    GType *type_list;
    GType test_object_type;
    GType derived_object_type;
    guint *n_children;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    n_children = g_new0(guint,1);
    
    /*Get the test object type.*/
    test_object_type = test_object_get_type();
    
    /*Get the derived object type.*/
    derived_object_type = derived_object_get_type();
    
    /*Get children of the test object type.*/
    type_list = g_type_children(TYPE,N_CHILDREN);
    
    /*g_printf("Number of children is %d.\n",*n_children);*/
    
    /*g_printf("Children type ID is %d.\n",type_list[*n_children]);*/
    
    /*Check the number of the children object type got.*/
    if (N_CHILDREN != NULL)
    {
        if (*n_children != 1)
        {
            TEST_FAIL("Number of children is not correctly gotten!\n",NULL);
        } 
    
       if (type_list[*n_children] != 0)
        {
            TEST_FAIL("The last elment is not 0!\n",NULL);
        }
    }
    else if (type_list[0] == 0)
    {
       TEST_FAIL("Type ID got is not correct.\n",NULL);
    }
    
    g_free(n_children);
    
    #undef TYPE
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_interface_peek
 * Params: gpointer instance_class, GType iface_type
 * Returns: The GTypeInterface structure of iface_type, or NULL if the class is not instantiated.
 * Assertion: Returns the GTypeInterface structure of an interface to which the passed in class conforms.
 * Params Values: instance_class,iface_type
 * Expected: Interface structure of type iface_type which instance_class conforms to.
 *   
 */
static void test_purpose_18()
{
    #define G_CLASS instance_class
    #define IFACE_TYPE iface_type
    
    TestIfaceClass  *g_class;
    gpointer instance_class;
    GType test_object_type;
    GType iface_type;
    
    TestIfaceClass *iface;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get test object type ID.*/
    test_object_type = test_object_get_type();
    
    /*Get class pointer of the test object.*/
    instance_class = g_type_class_ref(test_object_type);
    
    iface_type = test_iface_get_type();
    
    /*Get interface structure that the instance class conforms to.*/
    g_class = g_type_interface_peek(G_CLASS,IFACE_TYPE);
    
    /*Check the interface class point.*/
    
    //if (!struc_cmp((char *)g_class,(char *)&iface,sizeof(TestIface)))
    if (g_class == NULL)
    {
        TEST_FAIL("Iface structure is not equal!\n",NULL);
    }
    
    g_type_class_unref(instance_class);
    
    #undef G_CLASS
    #undef IFACE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_init
 * Params: void
 * Returns: void
 * Assertion: Prior to any use of the type system, g_type_init() has to be called to initialize the type system and assorted other code portions (such as the various fundamental type implementations or the signal system).
 * Params Values: void 
 * Expected: Initialize the type system.
 *   
 */
static void test_purpose_19()
{
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Initialize the type system.*/
    g_type_init();
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_from_name
 * Params: const gchar *name
 * Returns: Corresponding type ID or 0.
 * Assertion: Lookup the type ID from a given type name, returns 0 if no type has been registered under this name (this is the preferred method to find out by name whether a specific type has been registered yet).
 * Params Values: "TestObject"  
 * Expected: Type ID corresponding to "TestObject"   or 0.
 *   
 */
static void test_purpose_20()
{
    #define NAME "TestObject"  
    
    GType test_object_type;
    GType type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get the registered test object type ID.*/
    test_object_type = test_object_get_type();
    
    /*Get type ID from the name of it.*/
    type = g_type_from_name(NAME);
    
    /*Check whether the type ID got is correct.*/
    if (strcmp(NAME,"TestObject")&&type)
    {
        TEST_FAIL("Type ID should be zero!\n",NULL);
    }
    else if (!strcmp(NAME,"TestObject")&&(test_object_type != type))
    {
        TEST_FAIL("Type ID got error!\n",NULL);
    }
    
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_from_name
 * Params: const gchar *name
 * Returns: Corresponding type ID or 0.
 * Assertion: Lookup the type ID from a given type name, returns 0 if no type has been registered under this name (this is the preferred method to find out by name whether a specific type has been registered yet).
 * Params Values: "NoneExistObject"
 * Expected: Type ID corresponding to "NoneExistObject" or 0.
 *   
 */
static void test_purpose_21()
{
    #define NAME "NoneExistObject"
    
    GType test_object_type;
    GType type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get the registered test object type ID.*/
    test_object_type = test_object_get_type();
    
    /*Get type ID from the name of it.*/
    type = g_type_from_name(NAME);
    
    /*Check whether the type ID got is correct.*/
    if (strcmp(NAME,"TestObject")&&type)
    {
        TEST_FAIL("Type ID should be zero!\n",NULL);
    }
    else if (!strcmp(NAME,"TestObject")&&(test_object_type != type))
    {
        TEST_FAIL("Type ID got error!\n",NULL);
    }
    
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_query
 * Params: GType type, GTypeQuery *query
 * Returns: void
 * Assertion: Queries the type system for information about a specific type. This function will fill in a user-provided structure to hold type-specific information. If an invalid GType is passed in, the type member of the GTypeQuery is 0. All members filled into the GTypeQuery structure should be considered constant and have to be left untouched.
 * Params Values: Queries the type system for information about type test_object_type
 * Expected: Type information storeed in type_query
 *   
 */
static void test_purpose_22()
{
    #define TYPE test_object_type
    #define TYPE_QUERY type_query
    
    GType test_object_type;
    GTypeQuery *type_query;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    type_query = g_new(GTypeQuery,1);
    
    /*Get a new GType.*/
    test_object_type = test_object_get_type();
    
    /*Get type information and store it in structure TYPE_QUERY.*/
    g_type_query(TYPE,TYPE_QUERY);
    
    /*Check type ID of the queried type.*/
    if (type_query->type != test_object_type)
    {
        TEST_FAIL("Type ID query error!\n",NULL);
    }
    
    /*Check name of the type.*/
    if (strcmp(type_query->type_name,"TestObject"))
    {
        TEST_FAIL("Type name query error!\n",NULL);
    }
    
    g_free(type_query);
    
    #undef TYPE
    #undef TYPE_QUERY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_parent
 * Params: GType type
 * Returns: The parent type.
 * Assertion: Return the direct parent type of the passed in type. If the passed in type has no parent, i.e. is a fundamental type, 0 is returned.
 * Params Values: test_object_type
 * Expected: Parent type of test_object_type,or 0 if test_object_type is a fundamental type.
 *   
 */
static void test_purpose_23()
{
    #define TYPE test_object_type
    
    GType test_object_type;
    GType type;
    GType fundamental_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get type of the test object.*/
    test_object_type = test_object_get_type();
    
    type = g_type_parent(TYPE);
    
    /*Parent type of test_object_type is not fundamental type.*/
    if (!type)
    {
       TEST_FAIL("Error!Parent type is not fundamental type.\n",NULL);
    }
    
    fundamental_type = g_type_parent(type);
    
    /*Parent type of type is fundamental type,so fundamental_type is 0.*/
    if (fundamental_type)
    {
       TEST_FAIL("Error!Parent type is fundamental type.\n",NULL);
    }
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_type_fundamental
 * Params: GType type_id
 * Returns: Fundamental type ID.
 * Assertion: Internal function, used to extract the fundamental type ID portion. use G_TYPE_FUNDAMENTAL() instead.
 * Params Values: derived_object_type
 * Expected: Fundamental type ID of <%1%>
 *   
 */
static void test_purpose_24()
{
    #define TYPE derived_object_type
    
    GType test_object_type;
    GType derived_object_type;
    GType fundmtl_id;
    GType parent_id;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get type ID of the test object.*/
    test_object_type = test_object_get_type();
    
    /*Get the derived object type ID.*/
    derived_object_type = derived_object_get_type();
    
    /*Get fundamental type ID of TYPE.*/
    fundmtl_id = g_type_fundamental(TYPE);
    
    /*Get type ID of GObject type,the fundamental type ID of TYPE.*/
    parent_id = g_type_parent(test_object_type);
    
    /*Check the fundamental type ID.*/
    if (fundmtl_id != parent_id)
    {
        TEST_FAIL("Fundamental type ID got error!\n",NULL);
    }
    
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GObject-GType ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {NULL,0}
};
