/*
 * GdkImages methods tests
 * Testing GdkImages methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_image_new
 * Params: GdkImageType type, GdkVisual *visual, gint width, gint height
 * Returns: GdkImage*
 * Assertion: Creates a new GdkImage.
 *            type :   the type of the GdkImage, one of GDK_IMAGE_NORMAL, GDK_IMAGE_SHARED and GDK_IMAGE_FASTEST. GDK_IMAGE_FASTEST is probably the best choice, since it will try creating a GDK_IMAGE_SHARED image first and if that fails it will then use GDK_IMAGE_NORMAL.
 *            visual :    the GdkVisual to use for the image.
 *            width : the width of the image in pixels.
 *            height :    the height of the image in pixels.
 *            Returns :   a new GdkImage, or NULL if the image could not be created.
 * Params Values: GdkImageType type, GdkVisual *visual, gint width, gint height
 * Expected: GdkImage*  
 */
static void test_purpose_1()
{
    #define TYPE    GDK_IMAGE_NORMAL
    
    GdkVisual *pvisual = NULL;
    GdkImage *pimage = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pvisual = gdk_visual_get_system();
    pimage = gdk_image_new(TYPE, pvisual, 10, 10);
    if (!GDK_IS_IMAGE(pimage)){
        TEST_FAIL("gdk_image_new: it's not a GDK_TYPE_IMAGE", NULL);
    }
    g_object_unref(pimage);
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_image_new
 * Params: GdkImageType type, GdkVisual *visual, gint width, gint height
 * Returns: GdkImage*
 * Assertion: Creates a new GdkImage.
 *            type :   the type of the GdkImage, one of GDK_IMAGE_NORMAL, GDK_IMAGE_SHARED and GDK_IMAGE_FASTEST. GDK_IMAGE_FASTEST is probably the best choice, since it will try creating a GDK_IMAGE_SHARED image first and if that fails it will then use GDK_IMAGE_NORMAL.
 *            visual :    the GdkVisual to use for the image.
 *            width : the width of the image in pixels.
 *            height :    the height of the image in pixels.
 *            Returns :   a new GdkImage, or NULL if the image could not be created.
 * Params Values: GdkImageType type, GdkVisual *visual, gint width, gint height
 * Expected: GdkImage*  
 */
static void test_purpose_2()
{
    #define TYPE    GDK_IMAGE_FASTEST
    
    GdkVisual *pvisual = NULL;
    GdkImage *pimage = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pvisual = gdk_visual_get_system();
    pimage = gdk_image_new(TYPE, pvisual, 10, 10);
    if (!GDK_IS_IMAGE(pimage)){
        TEST_FAIL("gdk_image_new: it's not a GDK_TYPE_IMAGE", NULL);
    }
    g_object_unref(pimage);
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_image_get_pixel
 * Params: GdkImage *image, gint x, gint y
 * Returns: guint32
 * Assertion: Gets a pixel value at a specified position in a GdkImage.
 *            image :  a GdkImage.
 *            x : the x coordinate of the pixel to get.
 *            y : the y coordinate of the pixel to get.
 *            Returns :   the pixel value at the given position.
 * Params Values: GdkImage *image, gint x, gint y
 * Expected: guint32  
 */
static void test_purpose_3()
{
    GdkVisual *pvisual = NULL;
    GdkImage *pimage = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pvisual = gdk_visual_get_system();
    pimage = gdk_image_new(GDK_IMAGE_FASTEST, pvisual, 10, 10);
    guint32 pixel_val = gdk_image_get_pixel(pimage, 0, 0);
    if (pixel_val < 0){
        TEST_FAIL("gdk_image_get_pixel: failed", NULL);
    }
    g_object_unref(pimage);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkImages ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {NULL,0}
};
