/*
 * GdkPixbufStructure methods tests
 * Testing GdkPixbufStructure methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_pixbuf_get_height
 * Params: GdkPixbuf *
 * Return: gint
 * Assertion: Queries the height of a pixbuf.
 * Params Values:  
 * Expected: Height in pixels  
 */
static void test_purpose_1()
{
    #define HEIGHT 	      10
    GdkPixbuf * pixbuf = NULL;
    int heigth = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,HEIGHT);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_heigth\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_heigth\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    heigth = gdk_pixbuf_get_height(pixbuf);
    if(heigth != HEIGHT){
    	TEST_FAIL("\"gdk_pixbuf_get_heigth\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_width
 * Params: GdkPixbuf *
 * Return: gint
 * Assertion: Queries the width of a pixbuf.
 * Params Values:  
 * Expected: HWidth in pixels  
 */
static void test_purpose_2()
{
    #define WIDTH 	      10
    GdkPixbuf * pixbuf = NULL;
    int width = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,WIDTH,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_width\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_width\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    width = gdk_pixbuf_get_width(pixbuf);
    if(width != WIDTH){
    	TEST_FAIL("\"gdk_pixbuf_get_width\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_has_alpha
 * Params: GdkPixbuf *
 * Return: gboolean
 * Assertion:Queries whether a pixbuf has an alpha channel (opacity information).
 * Params Values:  
 * Expected: TRUE if it has an alpha channel, FALSE otherwise  
 */
static void test_purpose_3()
{
    #define HAS_ALPHA 	      TRUE
    GdkPixbuf * pixbuf = NULL;
    gboolean has_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    has_alpha = gdk_pixbuf_get_has_alpha(pixbuf);
    if(has_alpha != HAS_ALPHA){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    #undef HAS_ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_has_alpha
 * Params: GdkPixbuf *
 * Return: gboolean
 * Assertion:Queries whether a pixbuf has an alpha channel (opacity information).
 * Params Values:  
 * Expected: TRUE if it has an alpha channel, FALSE otherwise  
 */
static void test_purpose_4()
{
    #define HAS_ALPHA 	      FALSE
    GdkPixbuf * pixbuf = NULL;
    gboolean has_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    has_alpha = gdk_pixbuf_get_has_alpha(pixbuf);
    if(has_alpha != HAS_ALPHA){
    	TEST_FAIL("\"gdk_pixbuf_get_has_alpha\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    #undef HAS_ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_colorspace
 * Params: GdkPixbuf *
 * Return: GdkColorspace
 * Assertion: Queries the color space of a pixbuf.
 * Params Values:  
 * Expected: Color space  
 */
static void test_purpose_5()
{
    GdkPixbuf * pixbuf = NULL;
    GdkColorspace colorspace;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_colorspace\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_colorspace\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    colorspace = gdk_pixbuf_get_colorspace(pixbuf);
    if(colorspace != GDK_COLORSPACE_RGB){
    	TEST_FAIL("\"gdk_pixbuf_get_colorspace\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_pixels
 * Params: GdkPixbuf *
 * Return: guchar *
 * Assertion: Queries a pointer to the pixel data of a pixbuf.
 * Params Values:  
 * Expected: A pointer to the pixbuf's pixel data. Please see the section called Image Data for information about how the pixel data is stored in memory.    
 */
static void test_purpose_6()
{
    GdkPixbuf * pixbuf = NULL;
    guchar * pixel_raw;
    guchar * pixel_new;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixel_raw = (guchar *)malloc(100);
    memset(pixel_raw,0,100);
    strcpy(pixel_raw,"1234567890");
    pixbuf = gdk_pixbuf_new_from_data(pixel_raw,GDK_COLORSPACE_RGB,TRUE,8,10,10,10,NULL,NULL);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_pixels\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_pixels\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    pixel_new = gdk_pixbuf_get_pixels(pixbuf);
    if(pixel_new != pixel_raw){
    	TEST_FAIL("\"gdk_pixbuf_get_piexels\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_rowstride
 * Params: GdkPixbuf *
 * Return: int
 * Assertion: Queries the rowstride of a pixbuf, which is the number of bytes between the start of a row and the start of the next row.
 * Params Values:  
 * Expected: Distance between row starts.    
 */
static void test_purpose_7()
{
    #define STRIDE 10
    GdkPixbuf * pixbuf = NULL;
    guchar * pixel_raw;
    int stride;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixel_raw = (guchar *)malloc(100);
    memset(pixel_raw,0,100);
    strcpy(pixel_raw,"1234567890");
    pixbuf = gdk_pixbuf_new_from_data(pixel_raw,GDK_COLORSPACE_RGB,TRUE,8,10,10,STRIDE,NULL,NULL);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_pixels\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_pixels\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    stride = gdk_pixbuf_get_rowstride(pixbuf);
    if(stride != STRIDE){
    	TEST_FAIL("\"gdk_pixbuf_get_piexels\":result doesnt match expected!",NULL);
    	return;
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef STRIDE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_n_channels
 * Params: GdkPixbuf *
 * Return: int
 * Assertion: Queries the number of channels of a pixbuf.
 * Params Values:  
 * Expected: Number of channels.  
 */
static void test_purpose_8()
{
    #define HAS_ALPHA TRUE
    #define EXP_RES   	     4
    GdkPixbuf * pixbuf = NULL;
    guchar * pixel_raw = NULL;
    int channels;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixel_raw = (guchar *)malloc(100);
    memset(pixel_raw,0,100);
    strcpy(pixel_raw,"1234567890");
    pixbuf = gdk_pixbuf_new_from_data(pixel_raw,GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10,1,NULL,NULL);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    channels = gdk_pixbuf_get_n_channels(pixbuf);
    if(channels != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":result doesnt match expected!",NULL);
    	return;
    }
    #undef HAS_ALPHA
    #undef EXP_RES
    if(pixbuf)
    	g_object_unref(pixbuf);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_get_n_channels
 * Params: GdkPixbuf *
 * Return: int
 * Assertion: Queries the number of channels of a pixbuf.
 * Params Values:  
 * Expected: Number of channels.  
 */
static void test_purpose_9()
{
    #define HAS_ALPHA FALSE
    #define EXP_RES   	     3
    GdkPixbuf * pixbuf = NULL;
    guchar * pixel_raw = NULL;
    int channels;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixel_raw = (guchar *)malloc(100);
    memset(pixel_raw,0,100);
    strcpy(pixel_raw,"1234567890");
    pixbuf = gdk_pixbuf_new_from_data(pixel_raw,GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10,1,NULL,NULL);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    channels = gdk_pixbuf_get_n_channels(pixbuf);
    if(channels != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_get_n_channels\":result doesnt match expected!",NULL);
    	return;
    }
    #undef HAS_ALPHA
    #undef EXP_RES
    if(pixbuf)
    	g_object_unref(pixbuf);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufStructure ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {NULL,0}
};
