/*
 * GtkAlignment methods tests
 * Testing GtkAlignment methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0, 0, 0
 * Expected: GtkAlignment* with xalign = 0, yalign = 0, xscale = 0, yscale = 0  
 */
static void test_purpose_1()
{
    #define XALIGN 0
    #define YALIGN 0
    #define XSCALE 0
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0.5, 0, 0, 0
 * Expected: GtkAlignment* with xalign = 0.5, yalign = 0, xscale = 0, yscale = 0  
 */
static void test_purpose_2()
{
    #define XALIGN 0.5
    #define YALIGN 0
    #define XSCALE 0
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0.5
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 1, 0, 0, 0
 * Expected: GtkAlignment* with xalign = 1, yalign = 0, xscale = 0, yscale = 0  
 */
static void test_purpose_3()
{
    #define XALIGN 1
    #define YALIGN 0
    #define XSCALE 0
    #define YSCALE 0
    
    #define CORRECT_XALIGN 1
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0.5, 0, 0
 * Expected: GtkAlignment* with xalign = 0, yalign = 0.5, xscale = 0, yscale = 0  
 */
static void test_purpose_4()
{
    #define XALIGN 0
    #define YALIGN 0.5
    #define XSCALE 0
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0.5
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 1, 0, 0
 * Expected: GtkAlignment* with xalign = 0, yalign = 1, xscale = 0, yscale = 0  
 */
static void test_purpose_5()
{
    #define XALIGN 0
    #define YALIGN 1
    #define XSCALE 0
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 1
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0, 0.5, 0
 * Expected: GtkAlignment* with xalign = 0, yalign = 0, xscale = 0.5, yscale = 0  
 */
static void test_purpose_6()
{
    #define XALIGN 0
    #define YALIGN 0
    #define XSCALE 0.5
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0.5
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0, 1, 0
 * Expected: GtkAlignment* with xalign = 0, yalign = 0, xscale = 1, yscale = 0  
 */
static void test_purpose_7()
{
    #define XALIGN 0
    #define YALIGN 0
    #define XSCALE 1
    #define YSCALE 0
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 1
    #define CORRECT_YSCALE 0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0, 0, 0.5
 * Expected: GtkAlignment* with xalign = 0, yalign = 0, xscale = 0, yscale = 0.5  
 */
static void test_purpose_8()
{
    #define XALIGN 0
    #define YALIGN 0
    #define XSCALE 0
    #define YSCALE 0.5
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 0.5
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_new
 * Params: gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: GtkAlingment*
 * Assertion: Creates a new GtkAlignment.
 * Params Values: 0, 0, 0, 1
 * Expected: GtkAlignment* with xalign = 0, yalign = 0, xscale = 0, yscale = 1  
 */
static void test_purpose_9()
{
    #define XALIGN 0
    #define YALIGN 0
    #define XSCALE 0
    #define YSCALE 1
    
    #define CORRECT_XALIGN 0
    #define CORRECT_YALIGN 0
    #define CORRECT_XSCALE 0
    #define CORRECT_YSCALE 1
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_10()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 0.5
    #define CORRECT_YALIGN 0.5
    #define CORRECT_XSCALE 0.5
    #define CORRECT_YSCALE 0.5
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_11()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_XSCALE 0.0
    #define CORRECT_YSCALE 0.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_12()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 1.0
    #define CORRECT_YALIGN 1.0
    #define CORRECT_XSCALE 1.0
    #define CORRECT_YSCALE 1.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_13()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_XSCALE 0.0
    #define CORRECT_YSCALE 1.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_14()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_XSCALE 1.0
    #define CORRECT_YSCALE 0.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_15()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 1.0
    #define CORRECT_XSCALE 0.0
    #define CORRECT_YSCALE 0.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_alignment_set
 * Params: GtkAlignment *alignment,gfloat xalign, gfloat yalign, gfloat xscale, gfloat yscale
 * Returns: void
 * Assertion: Sets the GtkAlignment values.
 * Params Values: a newly created GtkAlignment*, 0.0, 0.0, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_16()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XSCALE 0.0
    #define YSCALE 0.0
    
    #define CORRECT_XALIGN 1.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_XSCALE 0.0
    #define CORRECT_YSCALE 0.0
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_xscale;
    gfloat real_yscale;
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_xscale_c;
    gfloat real_yscale_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_alignment_new (XALIGN, YALIGN, XSCALE, YSCALE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ALIGNMENT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign, NULL);
    if (real_xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign, NULL);
    if (real_yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale, NULL);
    if (real_xscale != XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale, XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale, NULL);
    if (real_yscale != YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale, YSCALE);
    }
    
    
    gtk_alignment_set(GTK_ALIGNMENT (widget), CORRECT_XALIGN, CORRECT_YALIGN, CORRECT_XSCALE, CORRECT_YSCALE);
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::xscale", &real_xscale_c, NULL);
    if (real_xscale_c != CORRECT_XSCALE)
    {
        TEST_FAIL ("xscale = %d, should be %d", 
                   real_xscale_c, CORRECT_XSCALE);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAlignment::yscale", &real_yscale_c, NULL);
    if (real_yscale_c != CORRECT_YSCALE)
    {
        TEST_FAIL ("yscale = %d, should be %d", 
                   real_yscale_c, CORRECT_YSCALE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef XSCALE
    #undef YSCALE
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_XSCALE
    #undef CORRECT_YSCALE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkAlignment ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {NULL,0}
};
