/*
 * GtkBox methods tests
 * Testing GtkBox methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_1()
{
    #define BOX gtk_hbutton_box_new ()
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_2()
{
    #define BOX gtk_hbutton_box_new ()
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_3()
{
    #define BOX gtk_vbutton_box_new ()
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_4()
{
    #define BOX gtk_vbutton_box_new ()
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_vbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_5()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_hbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_6()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_vbox_new (FALSE, 0)
 * Expected: void  
 */
static void test_purpose_7()
{
    #define BOX gtk_vbox_new (FALSE, 0)
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_homogeneous 
 * Params: GtkBox *box,gboolean homogeneous
 * Returns: void
 * Assertion: Sets the homogeneous field of GtkBox, controlling whether or not all children of box are given equal space in the box. 
 * Params Values: a newly created GtkBox*, gtk_hbox_new (FALSE, 0)
 * Expected: void  
 */
static void test_purpose_8()
{
    #define BOX gtk_hbox_new (FALSE, 0)
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_hbutton_box_new ();
    
    gtk_box_set_homogeneous (GTK_BOX (widget),HOMOGENEOUS);
    
    g_object_get(GTK_OBJECT (widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_hbutton_box_new ()  
 */
static void test_purpose_9()
{
    #define BOX gtk_hbutton_box_new ()
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_hbutton_box_new ()  
 */
static void test_purpose_10()
{
    #define BOX gtk_hbutton_box_new ()
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_vbutton_box_new ()  
 */
static void test_purpose_11()
{
    #define BOX gtk_vbutton_box_new ()
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_vbutton_box_new ()  
 */
static void test_purpose_12()
{
    #define BOX gtk_vbutton_box_new ()
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_vbox_new (TRUE, 10)  
 */
static void test_purpose_13()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_hbox_new (TRUE, 10)  
 */
static void test_purpose_14()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_vbox_new (FALSE, 0)  
 */
static void test_purpose_15()
{
    #define BOX gtk_vbox_new (FALSE, 0)
    #define HOMOGENEOUS TRUE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_homogeneous 
 * Params: GtkBox *box
 * Returns: gboolean
 * Assertion: Returns whether the box is homogeneous (all children are the same size).
 * Params Values: a newly created GtkBox*
 * Expected: gtk_hbox_new (FALSE, 0)  
 */
static void test_purpose_16()
{
    #define BOX gtk_hbox_new (FALSE, 0)
    #define HOMOGENEOUS FALSE
    
    GtkWidget* widget;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set(GTK_OBJECT (widget), "homogeneous", HOMOGENEOUS, NULL);
    
    homogeneous = gtk_box_get_homogeneous (GTK_BOX (widget));
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is '%s', should be '%s'", homogeneous,HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_17()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_18()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_19()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 1
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_20()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 100
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_21()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 1000
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_22()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_23()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_24()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_hbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_25()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define SPACING 1
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_vbox_new (FALSE, 0)
 * Expected: void  
 */
static void test_purpose_26()
{
    #define BOX gtk_vbox_new (FALSE, 0)
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_spacing 
 * Params: GtkBox *box,gint spacing
 * Returns: void
 * Assertion: Sets the spacing field of GtkBox, which is the number of pixels to place between children of box. 
 * Params Values: a newly created GtkBox*, gtk_hbox_new (FALSE, 0)
 * Expected: void  
 */
static void test_purpose_27()
{
    #define BOX gtk_hbox_new (FALSE, 0)
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    gtk_box_set_spacing (GTK_BOX (widget),SPACING);
    
    g_object_get(GTK_OBJECT (widget), "spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 1
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 100
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 1000
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define BOX gtk_hbutton_box_new ()
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_34()
{
    #define BOX gtk_vbutton_box_new ()
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_35()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define SPACING 0
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_36()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define SPACING 1
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_37()
{
    #define BOX gtk_vbox_new (FALSE, 0)
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_get_spacing 
 * Params: GtkBox *box
 * Returns: gint
 * Assertion:Gets the value set by gtk_box_set_spacing(). 
 * Params Values: a newly created GtkBox*
 * Expected: void  
 */
static void test_purpose_38()
{
    #define BOX gtk_hbox_new (FALSE, 0)
    #define SPACING 32767
    
    GtkWidget* widget;
    gint spacing;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = BOX;
    
    g_object_set (GTK_OBJECT (widget), "spacing", SPACING, NULL);
    
    spacing = gtk_box_get_spacing (GTK_BOX (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL ("spacing is '%s', should be '%s'", spacing,SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE,0
 * Expected: void  
 */
static void test_purpose_39()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 0
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE,1
 * Expected: void  
 */
static void test_purpose_40()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    #define PACK_TYPE GTK_PACK_END
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE,10
 * Expected: void  
 */
static void test_purpose_41()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE,100
 * Expected: void  
 */
static void test_purpose_42()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE,10000
 * Expected: void  
 */
static void test_purpose_43()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE,32767
 * Expected: void  
 */
static void test_purpose_44()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 32767
    #define PACK_TYPE GTK_PACK_END
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE,1
 * Expected: void  
 */
static void test_purpose_45()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    #define PACK_TYPE GTK_PACK_END
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_vbox_new (TRUE, 10),gtk_button_new_with_label ("Button"),TRUE,TRUE,10
 * Expected: void  
 */
static void test_purpose_46()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_hbox_new (TRUE, 10),gtk_radio_button_new_with_label (NULL, "Radio button"),TRUE,TRUE,100
 * Expected: void  
 */
static void test_purpose_47()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_radio_button_new_with_label (NULL, "Radio button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_set_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding,GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the way child is packed into box. 
 * Params Values: GtkBox*,gtk_vbox_new (FALSE, 10),gtk_check_button_new_with_label ("Check button"),TRUE,TRUE,10000
 * Expected: void  
 */
static void test_purpose_48()
{
    #define BOX gtk_vbox_new (FALSE, 10)
    #define WIDGET gtk_check_button_new_with_label ("Check button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,TRUE,TRUE,1);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_49()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 0
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE
 * Expected: void  
 */
static void test_purpose_50()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_51()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_52()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_53()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_54()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 32767
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE
 * Expected: void  
 */
static void test_purpose_55()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_vbox_new (TRUE, 10),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_56()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_hbox_new (TRUE, 10),gtk_radio_button_new_with_label (NULL, "Radio button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_57()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_radio_button_new_with_label (NULL, "Radio button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the start of box. 
 * Params Values: a newly created GtkBox*,gtk_vbox_new (FALSE, 10),gtk_check_button_new_with_label ("Check button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_58()
{
    #define BOX gtk_vbox_new (FALSE, 10)
    #define WIDGET gtk_check_button_new_with_label ("Check button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_59()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 0
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE
 * Expected: void  
 */
static void test_purpose_60()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_61()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_62()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_63()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_64()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 32767
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new (),gtk_button_new_with_label ("Button"),FALSE,FALSE
 * Expected: void  
 */
static void test_purpose_65()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_vbox_new (TRUE, 10),gtk_radio_button_new_with_label (NULL, "Radio button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_66()
{
    #define BOX gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_radio_button_new_with_label (NULL, "Radio button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_hbox_new (TRUE, 10),gtk_button_new_with_label ("Button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_67()
{
    #define BOX gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end
 * Params: GtkBox *box,GtkWidget *child,gboolean expand,gboolean fill,guint padding
 * Returns: void
 * Assertion: Adds child to box, packed with reference to the end of box. 
 * Params Values: a newly created GtkBox*,gtk_vbox_new (FALSE, 10),gtk_check_button_new_with_label ("Check button"),TRUE,TRUE
 * Expected: void  
 */
static void test_purpose_68()
{
    #define BOX gtk_vbox_new (FALSE, 10)
    #define WIDGET gtk_check_button_new_with_label ("Check button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end (GTK_BOX (box),widget,EXPAND,FILL,PADDING);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Adds widget to box, packed with reference to the start of box.
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_69()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Adds widget to box, packed with reference to the start of box.
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_70()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Parameters for how to pack the child widget, expand, fill, and padding in GtkBoxChild, are given their default values, TRUE, TRUE, and 0, respectively. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_71()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != TRUE)
    {
        TEST_FAIL ("expand is FALSE, should be TRUE",NULL);
    }
    if (fill != TRUE)
    {
        TEST_FAIL ("fill is FALSE, should be TRUE",NULL);
    }
    if (padding != 0)
    {
        TEST_FAIL ("padding is '%d', should be 0", padding);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_start_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Parameters for how to pack the child widget, expand, fill, and padding in GtkBoxChild, are given their default values, TRUE, TRUE, and 0, respectively. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_72()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = WIDGET;
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != TRUE)
    {
        TEST_FAIL ("expand is FALSE, should be TRUE",NULL);
    }
    if (fill != TRUE)
    {
        TEST_FAIL ("fill is FALSE, should be TRUE",NULL);
    }
    if (padding != 0)
    {
        TEST_FAIL ("padding is '%d', should be 0", padding);
    }
    if (pack != 0)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,0);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Adds widget to box, packed with reference to the end of box.
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_73()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (pack != GTK_PACK_END)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Adds widget to box, packed with reference to the end of box.
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_74()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (pack != GTK_PACK_END)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Parameters for how to pack the child widget, expand, fill, and padding in GtkBoxChild, are given their default values, TRUE, TRUE, and 0, respectively. 
 * Params Values: a newly created GtkBox*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_75()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != TRUE)
    {
        TEST_FAIL ("expand is FALSE, should be TRUE",NULL);
    }
    if (fill != TRUE)
    {
        TEST_FAIL ("fill is FALSE, should be TRUE",NULL);
    }
    if (padding != 0)
    {
        TEST_FAIL ("padding is '%d', should be 0", padding);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_pack_end_defaults
 * Params: GtkBox *box,GtkWidget *child
 * Returns: void
 * Assertion: Parameters for how to pack the child widget, expand, fill, and padding in GtkBoxChild, are given their default values, TRUE, TRUE, and 0, respectively. 
 * Params Values: a newly created GtkBox*,gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_76()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_check_button_new_with_label ("Check button")
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_end_defaults (GTK_BOX (box),widget);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != TRUE)
    {
        TEST_FAIL ("expand is FALSE, should be TRUE",NULL);
    }
    if (fill != TRUE)
    {
        TEST_FAIL ("fill is FALSE, should be TRUE",NULL);
    }
    if (padding != 0)
    {
        TEST_FAIL ("padding is '%d', should be 0", padding);
    }
    if (pack != 1)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_query_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean *expand,gboolean *fill,guint *padding,GtkPackType *pack_type
 * Returns: void
 * Assertion: Returns information about how child is packed into box. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gboolean*,gboolean*,guint*,GtkPackType*
 * Expected: void  
 */
static void test_purpose_77()
{
    #define BOX gtk_hbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 0
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_query_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean *expand,gboolean *fill,guint *padding,GtkPackType *pack_type
 * Returns: void
 * Assertion: Returns information about how child is packed into box. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gboolean*,gboolean*,guint*,GtkPackType*
 * Expected: void  
 */
static void test_purpose_78()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND FALSE
    #define FILL FALSE
    #define PADDING 1
    #define PACK_TYPE GTK_PACK_END
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_query_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean *expand,gboolean *fill,guint *padding,GtkPackType *pack_type
 * Returns: void
 * Assertion: Returns information about how child is packed into box. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gboolean*,gboolean*,guint*,GtkPackType*
 * Expected: void  
 */
static void test_purpose_79()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_query_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean *expand,gboolean *fill,guint *padding,GtkPackType *pack_type
 * Returns: void
 * Assertion: Returns information about how child is packed into box. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gboolean*,gboolean*,guint*,GtkPackType*
 * Expected: void  
 */
static void test_purpose_80()
{
    #define BOX gtk_vbutton_box_new ()
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 100
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_query_child_packing
 * Params: GtkBox *box,GtkWidget *child,gboolean *expand,gboolean *fill,guint *padding,GtkPackType *pack_type
 * Returns: void
 * Assertion: Returns information about how child is packed into box. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gboolean*,gboolean*,guint*,GtkPackType*
 * Expected: void  
 */
static void test_purpose_81()
{
    #define BOX gtk_hbox_new (FALSE, 10)
    #define WIDGET gtk_button_new_with_label ("Button")
    #define EXPAND TRUE
    #define FILL TRUE
    #define PADDING 10000
    #define PACK_TYPE GTK_PACK_START
    
    GtkWidget* widget;
    GtkWidget* box;
    GtkWidget* parent;
    guint padding;
    guint fill;
    guint expand;
    guint pack;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    
    widget = WIDGET;
    
    gtk_box_pack_start_defaults (GTK_BOX (box),widget);
    
    gtk_box_set_child_packing (GTK_BOX (box),widget,EXPAND,FILL,PADDING,PACK_TYPE);
    
    gtk_box_query_child_packing (GTK_BOX (box),widget,&expand,&fill,&padding,&pack);
    
    parent = gtk_widget_get_parent (widget);
    if (box != parent)
    {
        TEST_FAIL ("Widget is not added to GtkBox container",NULL);
    }
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand is '%d', should be '%d'",expand,EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill is '%d', should be '%d'",fill,FILL);
    }
    if (padding != PADDING)
    {
        TEST_FAIL ("padding is '%d', should be '%d'", padding,PADDING);
    }
    if (pack != PACK_TYPE)
    {
        TEST_FAIL ("pack_type is '%d', should be '%d'", pack,PACK_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef WIDGET
    #undef EXPAND
    #undef FILL
    #undef PADDING
    #undef PACK_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_82()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM 1
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_83()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM 3
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_84()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM 4
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_85()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM 10
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_86()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM G_MAXINT
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_87()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM -1
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_box_reorder_child
 * Params: GtkBox *box,GtkWidget *child,gint position
 * Returns: void
 * Assertion: Moves child to a new position in the list of box children. 
 * Params Values: a newly created GtkBox*,GtkWidget*,gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_88()
{
    #define BOX gtk_hbutton_box_new ()
    #define NUM -10
    
    GtkWidget* widget;
    GtkWidget* box;
    GList* children;
    gint num;
    gint real_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = BOX;
    widget = gtk_button_new_with_label ("Button");
    gtk_box_pack_start_defaults (GTK_BOX (box), widget);
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    gtk_box_pack_start_defaults (GTK_BOX (box), gtk_button_new ());
    
    gtk_box_reorder_child (GTK_BOX (box),widget,NUM);
    
    children = gtk_container_get_children (GTK_CONTAINER (box));
    
    num = g_list_index (children,widget);
    if(num == g_list_length (children) - 1)
      real_num = g_list_length (children) - 1;
    else
      real_num = NUM;
    
    if (NUM < 0)
      real_num = g_list_length (children) - 1;
    
    if (num != real_num)
    {
        TEST_FAIL ("position is '%d',should be is '%d'",num,real_num);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef BOX
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkBox ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {NULL,0}
};
