/*
 * GtkCellRendererText methods tests
 * Testing GtkCellRendererText methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:  gtk_cell_renderer_text_new
 * Params: void
 * Returns: GtkCellRenderer* 
 * Assertion: Creates a new GtkCellRendererText.
 * Params Values: void
 * Expected: GtkCellRendererText*  
 */
static void test_purpose_1()
{
    GtkCellRenderer* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: Sets the height of a renderer to explicitly be determined by the "font" and "y_pad" property set on it.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_2()
{
    #define ROW 1
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: Sets the height of a renderer to explicitly be determined by the "font" and "y_pad" property set on it.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_3()
{
    #define ROW 5
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: Sets the height of a renderer to explicitly be determined by the "font" and "y_pad" property set on it.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_4()
{
    #define ROW 10
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: Sets the height of a renderer to explicitly be determined by the "font" and "y_pad" property set on it.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_5()
{
    #define ROW 100
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: Sets the height of a renderer to explicitly be determined by the "font" and "y_pad" property set on it.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_6()
{
    #define ROW G_MAXINT
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: If number_of_rows is -1, then the fixed height is unset, and the height is determined by the properties again.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_7()
{
    #define ROW -1
    #define WIDTH 10
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (widget, WIDTH, WIDTH);
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    gtk_cell_renderer_get_fixed_size (widget, &width, &height);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("widht = %i, should be %i", width, WIDTH); 
    }
    
    if (height != ROW)
    {
        TEST_FAIL ("height = %i, should be %i", height, ROW); 
    }
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: If number_of_rows is -1, then the fixed height is unset, and the height is determined by the properties again.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_8()
{
    #define ROW -1
    #define WIDTH -1
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (widget, WIDTH, WIDTH);
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    gtk_cell_renderer_get_fixed_size (widget, &width, &height);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("widht = %i, should be %i", width, WIDTH); 
    }
    
    if (height != ROW)
    {
        TEST_FAIL ("height = %i, should be %i", height, ROW); 
    }
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: If number_of_rows is -1, then the fixed height is unset, and the height is determined by the properties again.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_9()
{
    #define ROW -1
    #define WIDTH 1
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (widget, WIDTH, WIDTH);
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    gtk_cell_renderer_get_fixed_size (widget, &width, &height);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("widht = %i, should be %i", width, WIDTH); 
    }
    
    if (height != ROW)
    {
        TEST_FAIL ("height = %i, should be %i", height, ROW); 
    }
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_text_set_fixed_height_from_font
 * Params: GtkCellRendererText *renderer,gint number_of_rows
 * Returns: void
 * Assertion: If number_of_rows is -1, then the fixed height is unset, and the height is determined by the properties again.
 * Params Values: GtkCellRendererText,gint
 * Expected: void  
 */
static void test_purpose_10()
{
    #define ROW -1
    #define WIDTH G_MAXINT
    
    GtkCellRenderer* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_cell_renderer_text_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER_TEXT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (widget, WIDTH, WIDTH);
    
    gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT(widget),ROW);
    
    gtk_cell_renderer_get_fixed_size (widget, &width, &height);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("widht = %i, should be %i", width, WIDTH); 
    }
    
    if (height != ROW)
    {
        TEST_FAIL ("height = %i, should be %i", height, ROW); 
    }
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef ROW
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCellRendererText ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {NULL,0}
};
