/*
 * GtkFontSelectionDialog methods tests
 * Testing GtkFontSelectionDialog methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
void  
global_activate (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    robot_activate (GTK_WIDGET (data));
}  

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: NULL
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_1()
{
    #define TITLE NULL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: ""
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_2()
{
    #define TITLE ""
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: " "
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_3()
{
    #define TITLE " "
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: "Label"
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_4()
{
    #define TITLE "Label"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: "\b\t\n"
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_5()
{
    #define TITLE "\b\t\n"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: "!@#$%^&*"
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_6()
{
    #define TITLE "!@#$%^&*"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_new 
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelectionDialog.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkFontSelectionDialog*  
 */
static void test_purpose_7()
{
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new (TITLE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef TITLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_font_name
 * Params: GtkFontSelectionDialog *fontsel, const gchar *fontname
 * Returns: void
 * Assertion: Sets the currently-selected font.
 * Params Values:  GtkFontSelectionDialog *fontsel, "Sans 12"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_font_name
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: gchar*
 * Assertion: Gets the currently-selected font name.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: gchar*  
 */
static void test_purpose_8()
{
    GtkWidget* widget;
    gchar* real_font_name;
    char **p;
    char *fonts[] = {"Sans 12", "Courier 10", "Fixed 10", NULL};
    int status = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (p = fonts; *p != NULL; p++){
        if (gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (widget), *p))
        {
            status ++;
        }
    }
    if ( status == 0){
        TEST_FAIL ("The fonts not found", NULL);
        return;
    }
    
    real_font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (widget));
    if (!real_font_name)
    {
        TEST_FAIL ("real_font_name is NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, ""
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_9()
{
    #define PREVIEW_TEXT ""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, " "
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_10()
{
    #define PREVIEW_TEXT " "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "   "
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_11()
{
    #define PREVIEW_TEXT "   "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "Label String"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_12()
{
    #define PREVIEW_TEXT "Label String"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_13()
{
    #define PREVIEW_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_14()
{
    #define PREVIEW_TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "_a_b"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_15()
{
    #define PREVIEW_TEXT "_a_b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "\n\t\""
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_16()
{
    #define PREVIEW_TEXT "\n\t\""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "_\n\t\""
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_17()
{
    #define PREVIEW_TEXT "_\n\t\""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "\b"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_18()
{
    #define PREVIEW_TEXT "\b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_dialog_set_preview_text
 * Params: GtkFontSelectionDialog *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel, "_\b"
 * Expected: void
 * 
 * Name: gtk_font_selection_dialog_get_preview_text
 * Params: GtkFontSelectionDialog *fontsel
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelectionDialog *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_19()
{
    #define PREVIEW_TEXT "_\b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_dialog_new ("Title");
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_dialog_set_preview_text (GTK_FONT_SELECTION_DIALOG (widget), PREVIEW_TEXT);
    if (strcmp (preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_dialog_get_preview_text (GTK_FONT_SELECTION_DIALOG (widget)));
    }
    
    /******* VISUALISATION *******/
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), (GTK_FONT_SELECTION_DIALOG (widget))->ok_button);
    gtk_window_set_position (GTK_WINDOW (widget), GTK_WIN_POS_CENTER_ALWAYS);
    gtk_widget_show (widget);
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkFontSelectionDialog ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {NULL,0}
};
