/*
 * GtkFrame methods tests
 * Testing GtkFrame methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: ""
 * Expected: GtkFrame*  
 */
static void test_purpose_1()
{
    #define LABEL ""
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: " "
 * Expected: GtkFrame*  
 */
static void test_purpose_2()
{
    #define LABEL " "
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: "Label"
 * Expected: GtkFrame*  
 */
static void test_purpose_3()
{
    #define LABEL "Label"
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: "\b\t\n"
 * Expected: GtkFrame*  
 */
static void test_purpose_4()
{
    #define LABEL "\b\t\n"
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: "!@#$%^&*"
 * Expected: GtkFrame*  
 */
static void test_purpose_5()
{
    #define LABEL "!@#$%^&*"
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: Create a new Frame, with optional label label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkFrame*  
 */
static void test_purpose_6()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    gchararray label;
    gfloat label_xalign;
    gfloat label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (strcmp (label, (char*) LABEL))
    {
        TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0)
    {
        TEST_FAIL ("label-xalign is '%s', should be '%d'", label_xalign, 0.0);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5)
    {
        TEST_FAIL ("label-yalign is '%s', should be '%d'", label_yalign, 0.5);
    }
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_ETCHED_IN)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,GTK_SHADOW_ETCHED_IN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget == NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_new
 * Params: const gchar *title
 * Returns: GtkWidget*
 * Assertion: If label is NULL, the label is omitted.
 * Params Values: <%0%>
 * Expected: GtkFrame*  
 */
static void test_purpose_7()
{
    gchararray label;
    gdouble label_xalign;
    gdouble label_yalign;
    GtkShadowType shadow;
    GtkWidget* label_widget;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label", &label, NULL);
    if (label != NULL)
    {
        TEST_FAIL ("label is '%s', should be NULL", label);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
    if (label_widget != NULL)
    {
        TEST_FAIL ("label-widget is '%s', should be NULL", label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, NULL
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_8()
{
    #define LABEL NULL
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, ""
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_9()
{
    #define LABEL ""
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, " "
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_10()
{
    #define LABEL " "
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "Label"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_11()
{
    #define LABEL "Label"
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "\b\t\n"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_12()
{
    #define LABEL "\b\t\n"
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "!@#$%^&*"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_13()
{
    #define LABEL "!@#$%^&*"
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_14()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define LABEL_WIDGET gtk_label_new ("")
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "qwerty"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_15()
{
    #define LABEL "qwerty"
    #define LABEL_WIDGET NULL
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion:Set the text of the label.
 * Params Values: a newly created GtkFrame*, "qwerty"
 * Expected: void
 * 
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: If the frame's label widget is a GtkLabel, return the text in the label widget.'
 * Params Values: a newly created GtkFrame*
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_16()
{
    #define LABEL "qwerty"
    #define LABEL_WIDGET gtk_combo_box_new()
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (GTK_IS_LABEL (LABEL_WIDGET))
    {
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        gtk_frame_set_label (GTK_FRAME (widget), LABEL);
        
        label = gtk_frame_get_label (GTK_FRAME (widget));
        if (LABEL) 
        {
            if (strcmp (label, (char*) LABEL))
            {
                TEST_FAIL ("label is '%s', should be '%s'", label, (gchar*) LABEL);
            }
            
        } else {
            if (label)
            {
                TEST_FAIL ("label is '%s', should be not NULL ", label, NULL);
            }
        }
        
        g_object_get(GTK_OBJECT (widget), "label-widget", &label_widget, NULL);
        if (LABEL)
        {
            if (label_widget == NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be not NULL", label_widget,NULL);
            }
        } else {
            if (label_widget != NULL)
            {
                TEST_FAIL ("label-widget is '%s', should be  NULL", label_widget,NULL);
            }
        }
    } else {
        gtk_frame_set_label_widget (GTK_FRAME (widget), LABEL_WIDGET);
        label = gtk_frame_get_label (GTK_FRAME (widget));
    
        if (label != NULL)
        {
            TEST_FAIL ("label is '%s', should be NULL", label, NULL);
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion: If label is NULL, the current label, if any, is removed.
 * Params Values: a newly created GtkFrame*, NULL
 * Expected: void  
 */
static void test_purpose_17()
{
    #define LABEL NULL
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label (GTK_FRAME (widget), LABEL);
    gtk_frame_set_label (GTK_FRAME (widget), NULL);
    
    label = gtk_frame_get_label (GTK_FRAME (widget));
    if (label) 
    {
        TEST_FAIL ("label is '%s', should be NULL", label);
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget)
    {
        TEST_FAIL ("label_widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion: If label is NULL, the current label, if any, is removed.
 * Params Values: a newly created GtkFrame*, ""
 * Expected: void  
 */
static void test_purpose_18()
{
    #define LABEL ""
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label (GTK_FRAME (widget), LABEL);
    gtk_frame_set_label (GTK_FRAME (widget), NULL);
    
    label = gtk_frame_get_label (GTK_FRAME (widget));
    if (label) 
    {
        TEST_FAIL ("label is '%s', should be NULL", label);
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget)
    {
        TEST_FAIL ("label_widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label
 * Params: GtkFrame *frame,const gchar *label
 * Returns: void
 * Assertion: If label is NULL, the current label, if any, is removed.
 * Params Values: a newly created GtkFrame*, "ftrusdait "
 * Expected: void  
 */
static void test_purpose_19()
{
    #define LABEL "ftrusdait "
    
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label (GTK_FRAME (widget), LABEL);
    gtk_frame_set_label (GTK_FRAME (widget), NULL);
    
    label = gtk_frame_get_label (GTK_FRAME (widget));
    if (label) 
    {
        TEST_FAIL ("label is '%s', should be NULL", label);
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget)
    {
        TEST_FAIL ("label_widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: (The frame will have a GtkLabel for the label widget if a non-NULL
 *  argument was passed to gtk_frame_new().)
 * Params Values: a newly created GtkFrame* with GtkLabel as the label widget
 * Expected: NULL  
 */
static void test_purpose_20()
{
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    GtkWidget* widget;
    
    #define  LABEL "label1"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL ("label_widget should be of type GtkLabel", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: (The frame will have a GtkLabel for the label widget if a non-NULL
 *  argument was passed to gtk_frame_new().)
 * Params Values: a newly created GtkFrame* with GtkLabel as the label widget
 * Expected: NULL  
 */
static void test_purpose_21()
{
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    GtkWidget* widget;
    
    #define  LABEL ""
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL ("label_widget should be of type GtkLabel", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label
 * Params: GtkFrame *frame,
 * Returns: G_CONST_RETURN gchar*
 * Assertion: (The frame will have a GtkLabel for the label widget if a non-NULL
 *  argument was passed to gtk_frame_new().)
 * Params Values: a newly created GtkFrame* with GtkLabel as the label widget
 * Expected: NULL  
 */
static void test_purpose_22()
{
    GtkWidget* label_widget;
    G_CONST_RETURN gchar* label;
    GtkWidget* widget;
    
    #define  LABEL "\n\n\\"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL ("label_widget should be of type GtkLabel", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_23()
{
    #define LABEL NULL
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_24()
{
    #define LABEL ""
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_25()
{
    #define LABEL " "
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_26()
{
    #define LABEL "Label"
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_27()
{
    #define LABEL "\b\t\n"
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define LABEL "!@#$%^&*"
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_widget
 * Params: GtkFrame *frame,GtkWidget *label_widget
 * Returns: void
 * Assertion: Set the label widget for the frame. 
 * Params Values: a newly created GtkFrame*,GtkWidget*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    label_widget = gtk_label_new (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (label_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_widget (GTK_FRAME (widget), label_widget);
    
    g_object_get(GTK_OBJECT (widget), "label-widget", &real_label_widget, NULL);
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget is '%s', should be '%s'", label_widget,real_label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_widget
 * Params: GtkFrame *frame
 * Returns: GtkWidget *label_widget
 * Assertion: Retrieves the label widget for the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GtkWidget*  
 */
static void test_purpose_30()
{
    #define LABEL_WIDGET NULL
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    label_widget = LABEL_WIDGET;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-widget", label_widget, NULL);
    
    real_label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget != real_label_widget", NULL);
    }
    
    if (label_widget)
    {
        gtk_widget_destroy (label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_widget
 * Params: GtkFrame *frame
 * Returns: GtkWidget *label_widget
 * Assertion: Retrieves the label widget for the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GtkWidget*  
 */
static void test_purpose_31()
{
    #define LABEL_WIDGET gtk_label_new ("text")
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    label_widget = LABEL_WIDGET;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-widget", label_widget, NULL);
    
    real_label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget != real_label_widget", NULL);
    }
    
    if (label_widget)
    {
        gtk_widget_destroy (label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_widget
 * Params: GtkFrame *frame
 * Returns: GtkWidget *label_widget
 * Assertion: Retrieves the label widget for the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GtkWidget*  
 */
static void test_purpose_32()
{
    #define LABEL_WIDGET gtk_combo_box_new ()
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    label_widget = LABEL_WIDGET;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-widget", label_widget, NULL);
    
    real_label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget != real_label_widget", NULL);
    }
    
    if (label_widget)
    {
        gtk_widget_destroy (label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_widget
 * Params: GtkFrame *frame
 * Returns: GtkWidget *label_widget
 * Assertion: Retrieves the label widget for the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GtkWidget*  
 */
static void test_purpose_33()
{
    #define LABEL_WIDGET gtk_frame_new (NULL)
    
    GtkWidget* label_widget;
    GtkWidget* real_label_widget;
    G_CONST_RETURN gchar* label;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    label_widget = LABEL_WIDGET;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-widget", label_widget, NULL);
    
    real_label_widget = gtk_frame_get_label_widget (GTK_FRAME (widget));
    if (label_widget != real_label_widget)
    {
        TEST_FAIL ("label-widget != real_label_widget", NULL);
    }
    
    if (label_widget)
    {
        gtk_widget_destroy (label_widget);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 0.0, 0.0
 * Expected: void  
 */
static void test_purpose_34()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 1.0, 0.0
 * Expected: void  
 */
static void test_purpose_35()
{
    #define XALIGN 1.0
    #define YALIGN 0.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 1.0, 1.0
 * Expected: void  
 */
static void test_purpose_36()
{
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 0.0, 1.0
 * Expected: void  
 */
static void test_purpose_37()
{
    #define XALIGN 0.0
    #define YALIGN 1.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 0.5, 1.0
 * Expected: void  
 */
static void test_purpose_38()
{
    #define XALIGN 0.5
    #define YALIGN 1.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 1.0, 0.5
 * Expected: void  
 */
static void test_purpose_39()
{
    #define XALIGN 1.0
    #define YALIGN 0.5
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 0.0, 0.5
 * Expected: void  
 */
static void test_purpose_40()
{
    #define XALIGN 0.0
    #define YALIGN 0.5
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: Set the alignment of the Frame widget's label.'
 * Params Values: a newly created GtkFrame*, 0.5, 0.0
 * Expected: void  
 */
static void test_purpose_41()
{
    #define XALIGN 0.5
    #define YALIGN 0.0
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_label_align (GTK_FRAME (widget),XALIGN,YALIGN);
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != XALIGN)
    {
        TEST_FAIL ("label-xalign is '%f', should be '%f'", label_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != YALIGN )
    {
        TEST_FAIL ("label-yalign is '%f', should be '%f'", label_yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,NULL
 * Expected: void  
 */
static void test_purpose_42()
{
    #define LABEL NULL
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,""
 * Expected: void  
 */
static void test_purpose_43()
{
    #define LABEL ""
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*," "
 * Expected: void  
 */
static void test_purpose_44()
{
    #define LABEL " "
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,"Label"
 * Expected: void  
 */
static void test_purpose_45()
{
    #define LABEL "Label"
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,"\b\t\n"
 * Expected: void  
 */
static void test_purpose_46()
{
    #define LABEL "\b\t\n"
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,"!@#$%^&*"
 * Expected: void  
 */
static void test_purpose_47()
{
    #define LABEL "!@#$%^&*"
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_label_align
 * Params: GtkFrame *frame, gfloat xalign, gfloat yalign 
 * Returns: void
 * Assertion: The default value for a newly created Frame is 0.0.
 * Params Values: a newly created GtkFrame*,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void  
 */
static void test_purpose_48()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    gfloat label_xalign;
    gfloat label_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT (widget), "label-xalign", &label_xalign, NULL);
    if (label_xalign != 0.0 )
    {
        TEST_FAIL ("label-xalign is '%f', should be 0.0", label_xalign, NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "label-yalign", &label_yalign, NULL);
    if (label_yalign != 0.5 )
    {
        TEST_FAIL ("label-yalign is '%f', should be 0.5'", label_yalign, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_49()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_50()
{
    #define XALIGN 1.0
    #define YALIGN 0.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_51()
{
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_52()
{
    #define XALIGN 0.0
    #define YALIGN 1.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_53()
{
    #define XALIGN 0.5
    #define YALIGN 1.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_54()
{
    #define XALIGN 1.0
    #define YALIGN 0.5
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_55()
{
    #define XALIGN 0.0
    #define YALIGN 0.5
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_label_align
 * Params: GtkFrame *frame, gfloat *xalign, gfloat *yalign 
 * Returns: void
 * Assertion: Retrieves the X and Y alignment of the frame's label.'
 * Params Values: a newly created GtkFrame*, gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_56()
{
    #define XALIGN 0.5
    #define YALIGN 0.0
    
    gdouble xalign;
    gdouble yalign;
    gfloat real_xalign;
    gfloat real_yalign;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    xalign = XALIGN;
    yalign = YALIGN;
    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "label-xalign", xalign, NULL);
    g_object_set(GTK_OBJECT (widget), "label-yalign", yalign, NULL);
    
    gtk_frame_get_label_align (GTK_FRAME (widget), &real_xalign, &real_yalign);
    
    if (real_xalign != xalign)
    {
        TEST_FAIL ("real_xalign is '%f', should be '%f'", real_xalign, xalign);
    }
    
    if (real_yalign != YALIGN )
    {
        TEST_FAIL ("real_yalign is '%f', should be '%f'", real_yalign, yalign);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN 
    #undef YALIGN 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_shadow_type 
 * Params: GtkFrame *frame,GtkShadowType type
 * Returns: void
 * Assertion: Set the shadow type for the Frame widget.
 * Params Values: a newly created GtkFrame*,GTK_SHADOW_NONE
 * Expected: void  
 */
static void test_purpose_57()
{
    #define SHADOW GTK_SHADOW_NONE
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_shadow_type (GTK_FRAME (widget),SHADOW);
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_shadow_type 
 * Params: GtkFrame *frame,GtkShadowType type
 * Returns: void
 * Assertion: Set the shadow type for the Frame widget.
 * Params Values: a newly created GtkFrame*,GTK_SHADOW_IN
 * Expected: void  
 */
static void test_purpose_58()
{
    #define SHADOW GTK_SHADOW_IN
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_shadow_type (GTK_FRAME (widget),SHADOW);
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_shadow_type 
 * Params: GtkFrame *frame,GtkShadowType type
 * Returns: void
 * Assertion: Set the shadow type for the Frame widget.
 * Params Values: a newly created GtkFrame*,GTK_SHADOW_OUT
 * Expected: void  
 */
static void test_purpose_59()
{
    #define SHADOW GTK_SHADOW_OUT
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_shadow_type (GTK_FRAME (widget),SHADOW);
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_shadow_type 
 * Params: GtkFrame *frame,GtkShadowType type
 * Returns: void
 * Assertion: Set the shadow type for the Frame widget.
 * Params Values: a newly created GtkFrame*,GTK_SHADOW_ETCHED_IN
 * Expected: void  
 */
static void test_purpose_60()
{
    #define SHADOW GTK_SHADOW_ETCHED_IN
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_shadow_type (GTK_FRAME (widget),SHADOW);
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_set_shadow_type 
 * Params: GtkFrame *frame,GtkShadowType type
 * Returns: void
 * Assertion: Set the shadow type for the Frame widget.
 * Params Values: a newly created GtkFrame*,GTK_SHADOW_ETCHED_OUT
 * Expected: void  
 */
static void test_purpose_61()
{
    #define SHADOW GTK_SHADOW_ETCHED_OUT
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_frame_set_shadow_type (GTK_FRAME (widget),SHADOW);
    
    g_object_get(GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_shadow_type 
 * Params: GtkFrame *frame
 * Returns: GtkShadowType type
 * Assertion: Retrieves the shadow type of the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GTK_SHADOW_NONE  
 */
static void test_purpose_62()
{
    #define SHADOW GTK_SHADOW_NONE
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set(GTK_OBJECT (widget), "shadow", SHADOW, NULL);
    shadow = gtk_frame_get_shadow_type (GTK_FRAME (widget));
    
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_shadow_type 
 * Params: GtkFrame *frame
 * Returns: GtkShadowType type
 * Assertion: Retrieves the shadow type of the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GTK_SHADOW_IN  
 */
static void test_purpose_63()
{
    #define SHADOW GTK_SHADOW_IN
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set(GTK_OBJECT (widget), "shadow", SHADOW, NULL);
    shadow = gtk_frame_get_shadow_type (GTK_FRAME (widget));
    
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_shadow_type 
 * Params: GtkFrame *frame
 * Returns: GtkShadowType type
 * Assertion: Retrieves the shadow type of the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GTK_SHADOW_OUT  
 */
static void test_purpose_64()
{
    #define SHADOW GTK_SHADOW_OUT
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set(GTK_OBJECT (widget), "shadow", SHADOW, NULL);
    shadow = gtk_frame_get_shadow_type (GTK_FRAME (widget));
    
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_shadow_type 
 * Params: GtkFrame *frame
 * Returns: GtkShadowType type
 * Assertion: Retrieves the shadow type of the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GTK_SHADOW_ETCHED_IN  
 */
static void test_purpose_65()
{
    #define SHADOW GTK_SHADOW_ETCHED_IN
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set(GTK_OBJECT (widget), "shadow", SHADOW, NULL);
    shadow = gtk_frame_get_shadow_type (GTK_FRAME (widget));
    
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_frame_get_shadow_type 
 * Params: GtkFrame *frame
 * Returns: GtkShadowType type
 * Assertion: Retrieves the shadow type of the frame.
 * Params Values: a newly created GtkFrame*
 * Expected: GTK_SHADOW_ETCHED_OUT  
 */
static void test_purpose_66()
{
    #define SHADOW GTK_SHADOW_ETCHED_OUT
    
    GtkShadowType shadow;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_frame_new ("");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_set(GTK_OBJECT (widget), "shadow", SHADOW, NULL);
    shadow = gtk_frame_get_shadow_type (GTK_FRAME (widget));
    
    if (shadow != SHADOW)
    {
        TEST_FAIL ("shadow is '%s', should be '%s'", shadow,SHADOW);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkFrame ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {NULL,0}
};
