/*
 * GtkMessageDialog methods tests
 * Testing GtkMessageDialog methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include "librobot.h"

static gint global_count;

void  
global_response (GtkWidget *widget, gint arg1, gpointer data)
{
    global_count++;
}  

void  
global_click (GtkWidget *widget, gpointer data)
{
    GList* list = NULL;

    if (!GTK_WIDGET_REALIZED (widget)) return;
    
    list = gtk_container_get_children (GTK_CONTAINER (GTK_DIALOG (widget)->action_area));
    if (!list)
    {
        gtk_dialog_response (GTK_DIALOG (widget), 0);
        return;
    }
    while (list)
    {
        if (GTK_IS_BUTTON (list->data)) 
        {
            gtk_button_clicked (GTK_BUTTON (list->data));
        }
        list = list->next;
    }
    g_list_free (list);
}  




/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , "Info"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , "Info"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_1()
{
    #define  PARENT   NULL 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK 
    #define  FORMAT   "Info"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , NULL
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , NULL
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_2()
{
    #define  PARENT   NULL 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK 
    #define  FORMAT   NULL
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_ERROR , GTK_BUTTONS_OK  , "Error loading file  xxx.err" 
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_ERROR , GTK_BUTTONS_OK  , "Error loading file  xxx.err" 
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_3()
{
    #define  PARENT   NULL 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_ERROR 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Error loading file  xxx.err" 
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_WARNING , GTK_BUTTONS_OK  , "Warning"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: NULL , GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_WARNING , GTK_BUTTONS_OK  , "Warning"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_4()
{
    #define  PARENT   NULL 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_WARNING 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Warning"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_QUESTION , GTK_BUTTONS_OK  , "Is it question ?"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_QUESTION , GTK_BUTTONS_OK  , "Is it question ?"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_5()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_QUESTION 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Is it question ?"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "None"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "None"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_6()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO
    #define  BUTTONS  GTK_BUTTONS_NONE
    #define  FORMAT   "None"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO  , GTK_BUTTONS_CLOSE , "Close"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO  , GTK_BUTTONS_CLOSE , "Close"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_7()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO  
    #define  BUTTONS  GTK_BUTTONS_CLOSE 
    #define  FORMAT   "Close"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_CANCEL , "Cancel"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_CANCEL , "Cancel"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_8()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_CANCEL 
    #define  FORMAT   "Cancel"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_YES_NO , "YesNo"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_YES_NO , "YesNo"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_9()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_YES_NO 
    #define  FORMAT   "YesNo"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK_CANCEL , "OkCancel"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_DESTROY_WITH_PARENT , GTK_MESSAGE_INFO , GTK_BUTTONS_OK_CANCEL , "OkCancel"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_10()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK_CANCEL 
    #define  FORMAT   "OkCancel"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , "Info"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , "Info"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_11()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK 
    #define  FORMAT   "Info"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , NULL
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK , NULL
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_12()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK 
    #define  FORMAT   NULL
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_ERROR , GTK_BUTTONS_OK  , "Error loading file" 
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_ERROR , GTK_BUTTONS_OK  , "Error loading file" 
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_13()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_ERROR 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Error loading file" 
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_WARNING , GTK_BUTTONS_OK  , "Warning"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_WARNING , GTK_BUTTONS_OK  , "Warning"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_14()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_WARNING 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Warning"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_QUESTION , GTK_BUTTONS_OK  , "Is it question ?"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_QUESTION , GTK_BUTTONS_OK  , "Is it question ?"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_15()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_QUESTION 
    #define  BUTTONS  GTK_BUTTONS_OK  
    #define  FORMAT   "Is it question ?"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_NONE  , "None"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_NONE  , "None"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_16()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_NONE  
    #define  FORMAT   "None"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE , "Close"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE , "Close"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_17()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL
    #define  TYPE     GTK_MESSAGE_INFO
    #define  BUTTONS  GTK_BUTTONS_CLOSE 
    #define  FORMAT   "Close"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_CANCEL  , "Cancel"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_CANCEL  , "Cancel"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_18()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_CANCEL  
    #define  FORMAT   "Cancel"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_YES_NO , "YesNo"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_YES_NO , "YesNo"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_19()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_YES_NO 
    #define  FORMAT   "YesNo"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion: Creates a new message dialog, which is a simple dialog with an icon indicating the dialog type (error, warning, etc.) and some text the user may want to see.
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK_CANCEL , "OkCancel"
 * Expected: GtkMessageDialog*
 * 
 * Name: gtk_message_dialog_new
 * Params: GtkWindow *parent, GtkDialogFlags flags, GtkMessageType type, GtkButtonsType buttons,  const gchar *message_format
 * Returns: GtkWidget*
 * Assertion:  When the user clicks a button a "response" signal is emitted with response IDs from GtkResponseType. 
 * Params Values: gtk_window_new(GTK_WINDOW_TOPLEVEL), GTK_DIALOG_MODAL , GTK_MESSAGE_INFO , GTK_BUTTONS_OK_CANCEL , "OkCancel"
 * Expected: GtkMessageDialog*  
 */
static void test_purpose_20()
{
    #define  PARENT   gtk_window_new(GTK_WINDOW_TOPLEVEL)
    #define  FLAGS    GTK_DIALOG_MODAL 
    #define  TYPE     GTK_MESSAGE_INFO 
    #define  BUTTONS  GTK_BUTTONS_OK_CANCEL 
    #define  FORMAT   "OkCancel"
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    } else {
        parent_window = NULL;
    }
    
    widget = gtk_message_dialog_new (
        parent_window, 
        FLAGS, 
        TYPE, 
        BUTTONS, 
        FORMAT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MESSAGE_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);  
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_click);   
    /******* -------------  *******/ 
    
    if (!global_count)
    {
        TEST_FAIL ("global_count = %i", global_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  TYPE
    #undef  FORMAT 
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkMessageDialog ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {NULL,0}
};
