/*
 * GtkMisc methods tests
 * Testing GtkMisc methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_label_new ("Label"), 0, 0 
 * Expected: void  
 */
static void test_purpose_1()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0
    #define YALIGN 0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_label_new ("Label"), 0, 1.0 
 * Expected: void  
 */
static void test_purpose_2()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_label_new ("Label"), 1.0, 0 
 * Expected: void  
 */
static void test_purpose_3()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 1.0
    #define YALIGN 0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_label_new ("Label"), 1.0, 1.0 
 * Expected: void  
 */
static void test_purpose_4()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_label_new ("Label"), 0.5, 0.5 
 * Expected: void  
 */
static void test_purpose_5()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0.5
    #define YALIGN 0.5
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_alignment
 * Params: GtkMisc *misc, gfloat xalign, gfloat yalign
 * Returns: void
 * Assertion: Sets the alignment of the widget
 * Params Values: gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN), 1.0, 1.0 
 * Expected: void  
 */
static void test_purpose_6()
{
    #define MISC gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN)
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_alignment (GTK_MISC (widget), XALIGN, YALIGN);
    
    g_object_get (GTK_OBJECT (widget), "xalign", &xalign, NULL);
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    g_object_get (GTK_OBJECT (widget), "yalign", &yalign, NULL);
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_label_new ("Label"), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_7()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0
    #define YALIGN 0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_label_new ("Label"), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_8()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_label_new ("Label"), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_9()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 1.0
    #define YALIGN 0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_label_new ("Label"), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_10()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_label_new ("Label"), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_11()
{
    #define MISC gtk_label_new ("Label")
    #define XALIGN 0.5
    #define YALIGN 0.5
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_alignment
 * Params: GtkMisc *misc, gfloat *xalign, gfloat *yalign
 * Returns: void
 * Assertion: Gets the X and Y alignment of the widget within its allocation.
 * Params Values: gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN), gfloat *xalign, gfloat *yalign
 * Expected: void  
 */
static void test_purpose_12()
{
    #define MISC gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN)
    #define XALIGN 1.0
    #define YALIGN 1.0
    
    GtkWidget *widget;
    gfloat xalign;
    gfloat yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xalign = XALIGN;
    yalign = YALIGN;
    
    g_object_set (GTK_OBJECT (widget), "xalign", xalign, NULL);
    g_object_set (GTK_OBJECT (widget), "yalign", yalign, NULL);
    
    gtk_misc_get_alignment (GTK_MISC (widget), &xalign, &yalign);
    
    if (xalign != XALIGN)
    {
        TEST_FAIL ("xalign = %f, should be %f", xalign, XALIGN);
    }
    
    if (yalign != YALIGN)
    {
        TEST_FAIL ("yalign = %f, should be %f", yalign, YALIGN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XALIGN 
    #undef YALIGN 
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_padding
 * Params: GtkMisc *misc, gint xpad, gint ypad
 * Returns: void
 * Assertion: Sets the amount of space to add around the widget
 * Params Values: gtk_label_new ("Label"), 0, 0 
 * Expected: void  
 */
static void test_purpose_13()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 0
    #define YPAD 0
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_padding (GTK_MISC (widget), XPAD, YPAD);
    
    g_object_get (GTK_OBJECT (widget), "xpad", &xpad, NULL);
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    g_object_get (GTK_OBJECT (widget), "ypad", &ypad, NULL);
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_padding
 * Params: GtkMisc *misc, gint xpad, gint ypad
 * Returns: void
 * Assertion: Sets the amount of space to add around the widget
 * Params Values: gtk_label_new ("Label"), 0, 1 
 * Expected: void  
 */
static void test_purpose_14()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 0
    #define YPAD 1
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_padding (GTK_MISC (widget), XPAD, YPAD);
    
    g_object_get (GTK_OBJECT (widget), "xpad", &xpad, NULL);
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    g_object_get (GTK_OBJECT (widget), "ypad", &ypad, NULL);
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_padding
 * Params: GtkMisc *misc, gint xpad, gint ypad
 * Returns: void
 * Assertion: Sets the amount of space to add around the widget
 * Params Values: gtk_label_new ("Label"), 1, 0 
 * Expected: void  
 */
static void test_purpose_15()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 1
    #define YPAD 0
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_padding (GTK_MISC (widget), XPAD, YPAD);
    
    g_object_get (GTK_OBJECT (widget), "xpad", &xpad, NULL);
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    g_object_get (GTK_OBJECT (widget), "ypad", &ypad, NULL);
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_padding
 * Params: GtkMisc *misc, gint xpad, gint ypad
 * Returns: void
 * Assertion: Sets the amount of space to add around the widget
 * Params Values: gtk_label_new ("Label"), 1, 1 
 * Expected: void  
 */
static void test_purpose_16()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 1
    #define YPAD 1
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_padding (GTK_MISC (widget), XPAD, YPAD);
    
    g_object_get (GTK_OBJECT (widget), "xpad", &xpad, NULL);
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    g_object_get (GTK_OBJECT (widget), "ypad", &ypad, NULL);
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_set_padding
 * Params: GtkMisc *misc, gint xpad, gint ypad
 * Returns: void
 * Assertion: Sets the amount of space to add around the widget
 * Params Values: gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN), 100, 100 
 * Expected: void  
 */
static void test_purpose_17()
{
    #define MISC gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN)
    #define XPAD 100
    #define YPAD 100
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_misc_set_padding (GTK_MISC (widget), XPAD, YPAD);
    
    g_object_get (GTK_OBJECT (widget), "xpad", &xpad, NULL);
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    g_object_get (GTK_OBJECT (widget), "ypad", &ypad, NULL);
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_label_new ("Label"), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_18()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 0
    #define YPAD 0
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_label_new ("Label"), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_19()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 0
    #define YPAD 1
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_label_new ("Label"), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_20()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 1
    #define YPAD 0
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_label_new ("Label"), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_21()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 1
    #define YPAD 1
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_label_new ("Label"), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_22()
{
    #define MISC gtk_label_new ("Label")
    #define XPAD 100
    #define YPAD 200
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_misc_get_padding
 * Params: GtkMisc *misc, gint *xpad, gint *ypad
 * Returns: void
 * Assertion: Gets the padding in the X and Y directions of the widget.
 * Params Values: gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN), gint *xpad, gint *ypad
 * Expected: void  
 */
static void test_purpose_23()
{
    #define MISC gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN)
    #define XPAD 200
    #define YPAD 100
    
    GtkWidget *widget;
    gint xpad;
    gint ypad;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = MISC;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    xpad = XPAD;
    ypad = YPAD;
    
    g_object_set (GTK_OBJECT (widget), "xpad", xpad, NULL);
    g_object_set (GTK_OBJECT (widget), "ypad", ypad, NULL);
    
    gtk_misc_get_padding (GTK_MISC (widget), &xpad, &ypad);
    
    if (xpad != XPAD)
    {
        TEST_FAIL ("xpad = %i, %i", xpad, XPAD);
    }
    
    if (ypad != YPAD)
    {
        TEST_FAIL ("ypad = %i, %i", ypad, YPAD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MISC 
    #undef XPAD
    #undef YPAD
    
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkMisc ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {NULL,0}
};
