/*
 * GtkObject methods tests
 * Testing GtkObject methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;

void global_destroy_event_handler (GtkWidget* widget, GdkEvent *event, 
                                     gpointer user_data)
{
    global_counter++;
}

/*
 * Name:  gtk_object_sink
 * Params: GtkObject *object
 * Returns: void
 * Assertion: Removes the floating reference from a GtkObject, if it exists; otherwise does nothing.
 * Params Values: a newly created GtkObject*
 * Expected: void  
 */
static void test_purpose_1()
{
    #define    TYPE GTK_TYPE_LABEL
    #define    PROP "label", "Hello World", "xalign", 0.0, NULL
    
    GtkObject* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = g_object_new (TYPE, PROP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_OBJECT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_ref (G_OBJECT(widget));
    g_object_ref (G_OBJECT(widget));
    gtk_object_sink (widget);
    
    if (GTK_OBJECT_FLOATING (widget))
    {
        TEST_FAIL ("gtk_object_sink() didn't remove the floating reference", NULL);
    }
    
    gtk_object_sink (widget);
    if (GTK_OBJECT_FLOATING (widget))
    {
        TEST_FAIL ("gtk_object_sink() didn't remove the floating reference after it was called two times", NULL);
    }
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_object_sink
 * Params: GtkObject *object
 * Returns: void
 * Assertion: Removes the floating reference from a GtkObject, if it exists; otherwise does nothing.
 * Params Values: a newly created GtkObject*
 * Expected: void  
 */
static void test_purpose_2()
{
    #define    TYPE GTK_TYPE_LABEL
    #define    PROP "label", "Hello World", "xalign", 0.0, "xalign", 0.0, NULL
    
    GtkObject* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = g_object_new (TYPE, PROP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_OBJECT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_ref (G_OBJECT(widget));
    g_object_ref (G_OBJECT(widget));
    gtk_object_sink (widget);
    
    if (GTK_OBJECT_FLOATING (widget))
    {
        TEST_FAIL ("gtk_object_sink() didn't remove the floating reference", NULL);
    }
    
    gtk_object_sink (widget);
    if (GTK_OBJECT_FLOATING (widget))
    {
        TEST_FAIL ("gtk_object_sink() didn't remove the floating reference after it was called two times", NULL);
    }
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_object_destroy
 * Params: GtkObject *object
 * Returns: void
 * Assertion: Emits the "destroy" signal notifying all reference holders that they should release the GtkObject.
 * Params Values: a newly created GtkObject*
 * Expected: void  
 */
static void test_purpose_3()
{
    #define    TYPE GTK_TYPE_LABEL
    #define    PROP "label", "Hello World", "xalign", 0.0, NULL
    
    GtkObject* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = g_object_new (TYPE, PROP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_OBJECT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "destroy",
                      GTK_SIGNAL_FUNC (global_destroy_event_handler), NULL);
    gtk_object_destroy (widget);
    
    if (global_counter != 1)
    {
        TEST_FAIL ("\"destroy\" signal has not been emitted", NULL);
    }
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_object_destroy
 * Params: GtkObject *object
 * Returns: void
 * Assertion: Emits the "destroy" signal notifying all reference holders that they should release the GtkObject.
 * Params Values: a newly created GtkObject*
 * Expected: void  
 */
static void test_purpose_4()
{
    #define    TYPE GTK_TYPE_LABEL
    #define    PROP "label", "Hello World", "xalign", 0.0, "xalign", 0.0, NULL
    
    GtkObject* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = g_object_new (TYPE, PROP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_OBJECT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "destroy",
                      GTK_SIGNAL_FUNC (global_destroy_event_handler), NULL);
    gtk_object_destroy (widget);
    
    if (global_counter != 1)
    {
        TEST_FAIL ("\"destroy\" signal has not been emitted", NULL);
    }
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkObject ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {NULL,0}
};
