/*
 * GtkPaned methods tests
 * Testing GtkPaned methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_paned_set_position 
 * Params: GtkPaned *paned,gint position
 * Returns: void
 * Assertion: Sets the position of the divider between the two panes.
 * Params Values: GtkPaned*, 0
 * Expected: void  
 */
static void test_purpose_1()
{
    #define WIDGET gtk_hpaned_new ()  
    #define POSITION 0
    
    GtkWidget *widget;
    gint position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_set_position (GTK_PANED (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "position", &position, NULL);
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_set_position 
 * Params: GtkPaned *paned,gint position
 * Returns: void
 * Assertion: Sets the position of the divider between the two panes.
 * Params Values: GtkPaned*, 1
 * Expected: void  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_vpaned_new ()  
    #define POSITION 1
    
    GtkWidget *widget;
    gint position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_set_position (GTK_PANED (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "position", &position, NULL);
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_set_position 
 * Params: GtkPaned *paned,gint position
 * Returns: void
 * Assertion: Sets the position of the divider between the two panes.
 * Params Values: GtkPaned*, 1000
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_hpaned_new ()  
    #define POSITION 1000
    
    GtkWidget *widget;
    gint position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_set_position (GTK_PANED (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "position", &position, NULL);
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_set_position 
 * Params: GtkPaned *paned,gint position
 * Returns: void
 * Assertion: Sets the position of the divider between the two panes.
 * Params Values: GtkPaned*, G_MAXINT
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_vpaned_new ()  
    #define POSITION G_MAXINT
    
    GtkWidget *widget;
    gint position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_set_position (GTK_PANED (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "position", &position, NULL);
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_get_position 
 * Params: GtkPaned *paned
 * Returns: qint
 * Assertion: Obtains the position of the divider between the two panes.
 * Params Values: GtkPaned*
 * Expected: qint  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_hpaned_new ()  
    #define POSITION 0
    
    GtkWidget *widget;
    gint position;
    gboolean position_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "position", POSITION, NULL);
    position = gtk_paned_get_position (GTK_PANED (widget));
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_get_position 
 * Params: GtkPaned *paned
 * Returns: qint
 * Assertion: Obtains the position of the divider between the two panes.
 * Params Values: GtkPaned*
 * Expected: qint  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_vpaned_new ()  
    #define POSITION 1
    
    GtkWidget *widget;
    gint position;
    gboolean position_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "position", POSITION, NULL);
    position = gtk_paned_get_position (GTK_PANED (widget));
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_get_position 
 * Params: GtkPaned *paned
 * Returns: qint
 * Assertion: Obtains the position of the divider between the two panes.
 * Params Values: GtkPaned*
 * Expected: qint  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_hpaned_new ()  
    #define POSITION 1000
    
    GtkWidget *widget;
    gint position;
    gboolean position_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "position", POSITION, NULL);
    position = gtk_paned_get_position (GTK_PANED (widget));
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_get_position 
 * Params: GtkPaned *paned
 * Returns: qint
 * Assertion: Obtains the position of the divider between the two panes.
 * Params Values: GtkPaned*
 * Expected: qint  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_vpaned_new ()  
    #define POSITION G_MAXINT
    
    GtkWidget *widget;
    gint position;
    gboolean position_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "position", POSITION, NULL);
    position = gtk_paned_get_position (GTK_PANED (widget));
    
    if (POSITION >= 0)
    {
        if (position != POSITION) 
        {
            TEST_FAIL ("position = %d, should be %d", position, POSITION);
        }
    }
    else
    {
        if (position != 0) 
        {
            TEST_FAIL ("position = %d, should be 0", position,NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
    #undef WIDGET
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the top or left pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack1 (paned, child, FALSE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_button_new ()
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add2 (GTK_PANED (widget), child2);
    gtk_paned_add1 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the top or left pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack1 (paned, child, FALSE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_10()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_entry_new ()
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add2 (GTK_PANED (widget), child2);
    gtk_paned_add1 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the top or left pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add1
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack1 (paned, child, FALSE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_11()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add2 (GTK_PANED (widget), child2);
    gtk_paned_add1 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack2 (paned, child, TRUE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_12()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_button_new ()
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add1 (GTK_PANED (widget), child2);
    gtk_paned_add2 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack2 (paned, child, TRUE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_entry_new ()
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add1 (GTK_PANED (widget), child2);
    gtk_paned_add2 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane with default parameters.
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void
 * 
 * Name: gtk_paned_add2
 * Params: GtkPaned *paned, GtkWidget *child
 * Returns: void
 * Assertion: This is equivalent to gtk_paned_pack2 (paned, child, TRUE, TRUE).
 * Params Values: GtkPaned*, GtkWidget *child
 * Expected: void  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_add1 (GTK_PANED (widget), child2);
    gtk_paned_add2 (GTK_PANED (widget), child1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack1
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the top or left pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_button_new ()
    #define RESIZE TRUE
    #define SHRINK TRUE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack2 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack1 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack1
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the top or left pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_button_new ()
    #define RESIZE FALSE
    #define SHRINK TRUE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack2 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack1 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack1
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the top or left pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_entry_new ()
    #define RESIZE TRUE
    #define SHRINK FALSE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack2 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack1 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack1
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the top or left pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_label_new ("Label")
    #define RESIZE FALSE
    #define SHRINK FALSE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack2 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack1 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x > child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y > child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack2
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_button_new ()
    #define RESIZE TRUE
    #define SHRINK TRUE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack1 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack2 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack2
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_button_new ()
    #define RESIZE FALSE
    #define SHRINK TRUE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack1 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack2 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack2
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_21()
{
    #define WIDGET gtk_hpaned_new ()  
    #define CHILD gtk_entry_new ()
    #define RESIZE TRUE
    #define SHRINK FALSE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack1 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack2 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paned_pack2
 * Params: GtkPaned *paned, GtkWidget *child, gboolean resize, gboolean shrink
 * Returns: void
 * Assertion: Adds a child to the bottom or right pane.
 * Params Values: GtkPaned*, GtkWidget *child, gboolean resize, gboolean shrink
 * Expected: void  
 */
static void test_purpose_22()
{
    #define WIDGET gtk_vpaned_new ()  
    #define CHILD gtk_label_new ("Label")
    #define RESIZE FALSE
    #define SHRINK FALSE
    
    GtkWidget *window;
    GtkWidget *widget;
    GtkWidget *child1;
    GtkWidget *child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child1 = CHILD;
    if (!child1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child2 = CHILD;
    if (!child2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_paned_pack1 (GTK_PANED (widget), child2, RESIZE, SHRINK);
    gtk_paned_pack2 (GTK_PANED (widget), child1, RESIZE, SHRINK);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((GTK_IS_HPANED (widget)) && (child1->allocation.x < child2->allocation.x))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    if ((GTK_IS_VPANED (widget)) && (child1->allocation.y < child2->allocation.y))
    {
        TEST_FAIL ("children are not in order", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef CHILD
    #undef RESIZE
    #undef SHRINK
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkPaned ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {NULL,0}
};
