/*
 * GtkStatusbar methods tests
 * Testing GtkStatusbar methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_statusbar_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkStatusbar ready for messages.
 * Params Values: void 
 * Expected: GtkStatusBar*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_set_has_resize_grip
 * Params: GtkStatusBar *statusbar, gboolean setting
 * Returns: void
 * Assertion: Sets whether the statusbar has a resize grip.
 * Params Values: newly created GtkStatusBar*, TRUE
 * Expected: void
 * 
 * Name: gtk_statusbar_get_has_resize_grip
 * Params: GtkStatusBar *statusbar
 * Returns: gboolean
 * Assertion: Returns whether the statusbar has a resize grip.
 * Params Values: newly created GtkStatusBar*
 * Expected: TRUE  
 */
static void test_purpose_2()
{
    #define SETTING TRUE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), SETTING);
    
    if (gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)) != SETTING)
    {
        TEST_FAIL("Setting =  %d, should be %d\n", gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_set_has_resize_grip
 * Params: GtkStatusBar *statusbar, gboolean setting
 * Returns: void
 * Assertion: Sets whether the statusbar has a resize grip.
 * Params Values: newly created GtkStatusBar*, FALSE
 * Expected: void
 * 
 * Name: gtk_statusbar_get_has_resize_grip
 * Params: GtkStatusBar *statusbar
 * Returns: gboolean
 * Assertion: Returns whether the statusbar has a resize grip.
 * Params Values: newly created GtkStatusBar*
 * Expected: FALSE  
 */
static void test_purpose_3()
{
    #define SETTING FALSE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (widget), SETTING);
    
    if (gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)) != SETTING)
    {
        TEST_FAIL("Setting =  %d, should be %d\n", gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_set_has_resize_grip
 * Params: GtkStatusBar *statusbar, gboolean setting
 * Returns: void
 * Assertion: TRUE by default.
 * Params Values: newly created GtkStatusBar*, <%0%>
 * Expected: void  
 */
static void test_purpose_4()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)) != TRUE)
    {
        TEST_FAIL("default setting =  %d, should be %d\n", gtk_statusbar_get_has_resize_grip(GTK_STATUSBAR (widget)), TRUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_get_context_id
 * Params: GtkStatusbar *statusbar, const gchar *context_description
 * Returns:guint
 * Assertion: Returns a new context identifier, given a description of the actual context.
 * Params Values: newly created GtkStatusbar*, "" 
 * Expected: new context identifier  
 */
static void test_purpose_5()
{
    #define CONTEXT_DESCRIPTION ""
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_get_context_id
 * Params: GtkStatusbar *statusbar, const gchar *context_description
 * Returns:guint
 * Assertion: Returns a new context identifier, given a description of the actual context.
 * Params Values: newly created GtkStatusbar*, " " 
 * Expected: new context identifier  
 */
static void test_purpose_6()
{
    #define CONTEXT_DESCRIPTION " "
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_get_context_id
 * Params: GtkStatusbar *statusbar, const gchar *context_description
 * Returns:guint
 * Assertion: Returns a new context identifier, given a description of the actual context.
 * Params Values: newly created GtkStatusbar*, "   " 
 * Expected: new context identifier  
 */
static void test_purpose_7()
{
    #define CONTEXT_DESCRIPTION "   "
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_get_context_id
 * Params: GtkStatusbar *statusbar, const gchar *context_description
 * Returns:guint
 * Assertion: Returns a new context identifier, given a description of the actual context.
 * Params Values: newly created GtkStatusbar*, "Label String" 
 * Expected: new context identifier  
 */
static void test_purpose_8()
{
    #define CONTEXT_DESCRIPTION "Label String"
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_push
 * Params: GtkStatusbar *statusbar, guint context_id, const gchar *text
 * Returns:guint
 * Assertion: Pushes a new message onto a statusbar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id(),"" 
 * Expected: new message identifier  
 */
static void test_purpose_9()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 1
    
    GtkWidget *widget;
    guint context_id;
    guint message_id = 0;
    guint save_message_id = 0;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id; 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_push
 * Params: GtkStatusbar *statusbar, guint context_id, const gchar *text
 * Returns:guint
 * Assertion: Pushes a new message onto a statusbar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id(),"" 
 * Expected: new message identifier  
 */
static void test_purpose_10()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 2
    
    GtkWidget *widget;
    guint context_id;
    guint message_id = 0;
    guint save_message_id = 0;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id; 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_push
 * Params: GtkStatusbar *statusbar, guint context_id, const gchar *text
 * Returns:guint
 * Assertion: Pushes a new message onto a statusbar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id()," " 
 * Expected: new message identifier  
 */
static void test_purpose_11()
{
    #define CONTEXT_DESCRIPTION " "
    #define TEXT " "
    #define N_MESSAGES 10 
    
    GtkWidget *widget;
    guint context_id;
    guint message_id = 0;
    guint save_message_id = 0;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id; 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_push
 * Params: GtkStatusbar *statusbar, guint context_id, const gchar *text
 * Returns:guint
 * Assertion: Pushes a new message onto a statusbar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id(),"   " 
 * Expected: new message identifier  
 */
static void test_purpose_12()
{
    #define CONTEXT_DESCRIPTION "   "
    #define TEXT "   "
    #define N_MESSAGES 1000
    
    GtkWidget *widget;
    guint context_id;
    guint message_id = 0;
    guint save_message_id = 0;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id; 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_pop
 * Params: GtkStatusbar *statusbar, guint context_id
 * Returns: void
 * Assertion: Removes the message at the top of a GtkStatusBar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_13()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 1
    #define N_POPS 1
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id;
    }
    
    for (i=0; i<N_POPS; i++)
    {
        gtk_statusbar_pop (GTK_STATUSBAR (widget), context_id);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef N_POPS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_pop
 * Params: GtkStatusbar *statusbar, guint context_id
 * Returns: void
 * Assertion: Removes the message at the top of a GtkStatusBar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_14()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 2
    #define N_POPS 3
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id;
    }
    
    for (i=0; i<N_POPS; i++)
    {
        gtk_statusbar_pop (GTK_STATUSBAR (widget), context_id);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef N_POPS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_pop
 * Params: GtkStatusbar *statusbar, guint context_id
 * Returns: void
 * Assertion: Removes the message at the top of a GtkStatusBar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_15()
{
    #define CONTEXT_DESCRIPTION " "
    #define TEXT " "
    #define N_MESSAGES 10 
    #define N_POPS 7
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id;
    }
    
    for (i=0; i<N_POPS; i++)
    {
        gtk_statusbar_pop (GTK_STATUSBAR (widget), context_id);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef N_POPS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_pop
 * Params: GtkStatusbar *statusbar, guint context_id
 * Returns: void
 * Assertion: Removes the message at the top of a GtkStatusBar`s stack.
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_16()
{
    #define CONTEXT_DESCRIPTION "   "
    #define TEXT "   "
    #define N_MESSAGES 1000
    #define N_POPS 1010
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    save_message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (save_message_id == message_id)
        {
            TEST_FAIL("i = %i, message_id = save_message_id = %i\n", i, message_id);
        }
        save_message_id = message_id;
    }
    
    for (i=0; i<N_POPS; i++)
    {
        gtk_statusbar_pop (GTK_STATUSBAR (widget), context_id);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef N_POPS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_remove
 * Params: GtkStatusbar *statusbar, guint context_id, guint message_id
 * Returns: void
 * Assertion: Forces the removal of a message from a statusbar`s stack. 
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_17()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 1
    #define REMOVE_MESSAGE_INDEX 0
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (i == REMOVE_MESSAGE_INDEX)
        {
            save_message_id = message_id;
        }
    }
    
    gtk_statusbar_remove (GTK_STATUSBAR (widget), context_id, save_message_id);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef REMOVE_MESSAGE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_remove
 * Params: GtkStatusbar *statusbar, guint context_id, guint message_id
 * Returns: void
 * Assertion: Forces the removal of a message from a statusbar`s stack. 
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_18()
{
    #define CONTEXT_DESCRIPTION ""
    #define TEXT ""
    #define N_MESSAGES 2
    #define REMOVE_MESSAGE_INDEX 1
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (i == REMOVE_MESSAGE_INDEX)
        {
            save_message_id = message_id;
        }
    }
    
    gtk_statusbar_remove (GTK_STATUSBAR (widget), context_id, save_message_id);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef REMOVE_MESSAGE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_remove
 * Params: GtkStatusbar *statusbar, guint context_id, guint message_id
 * Returns: void
 * Assertion: Forces the removal of a message from a statusbar`s stack. 
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_19()
{
    #define CONTEXT_DESCRIPTION " "
    #define TEXT " "
    #define N_MESSAGES 10 
    #define REMOVE_MESSAGE_INDEX 7
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (i == REMOVE_MESSAGE_INDEX)
        {
            save_message_id = message_id;
        }
    }
    
    gtk_statusbar_remove (GTK_STATUSBAR (widget), context_id, save_message_id);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef REMOVE_MESSAGE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_statusbar_remove
 * Params: GtkStatusbar *statusbar, guint context_id, guint message_id
 * Returns: void
 * Assertion: Forces the removal of a message from a statusbar`s stack. 
 * Params Values: newly created GtkStatusbar*, the message`s context id, as returned by gkt_statusbar_get_context_id() 
 * Expected: void  
 */
static void test_purpose_20()
{
    #define CONTEXT_DESCRIPTION "   "
    #define TEXT "   "
    #define N_MESSAGES 1000
    #define REMOVE_MESSAGE_INDEX 999
    
    GtkWidget *widget;
    guint context_id, message_id, save_message_id;
    guint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_statusbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_STATUSBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), CONTEXT_DESCRIPTION);
    
    for (i=0; i<N_MESSAGES; i++)
    {
        message_id = gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, TEXT);
        if (i == REMOVE_MESSAGE_INDEX)
        {
            save_message_id = message_id;
        }
    }
    
    gtk_statusbar_remove (GTK_STATUSBAR (widget), context_id, save_message_id);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTEXT_DESCRIPTION
    #undef TEXT
    #undef N_MESSAGES
    #undef REMOVE_MESSAGE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkStatusbar ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {NULL,0}
};
