/*
 * LexScan methods tests
 * Testing LexScan methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <fcntl.h>

typedef enum{
  GLIB_TOKEN_INVALID = G_TOKEN_LAST,
  GLIB_TEST_INCLUDE,
  GLIB_TEST_NAME,
  GLIB_TEST_LAST
} GlibTokenType;

static GScannerConfig g_scanner_config_template =
{
  (
   " \t\r\n"
   )                    /* cset_skip_characters */,
  (
   G_CSET_a_2_z
   "_"
   G_CSET_A_2_Z
   )                    /* cset_identifier_first */,
  (
   G_CSET_a_2_z
   "_"
   G_CSET_A_2_Z
   G_CSET_DIGITS
   G_CSET_LATINS
   G_CSET_LATINC
   )                    /* cset_identifier_nth */,
  ( "#\n" )             /* cpair_comment_single */,

  FALSE                 /* case_sensitive */,

  TRUE                  /* skip_comment_multi */,
  TRUE                  /* skip_comment_single */,
  TRUE                  /* scan_comment_multi */,
  TRUE                  /* scan_identifier */,
  FALSE                 /* scan_identifier_1char */,
  FALSE                 /* scan_identifier_NULL */,
  TRUE                  /* scan_symbols */,
  FALSE                 /* scan_binary */,
  TRUE                  /* scan_octal */,
  TRUE                  /* scan_float */,
  TRUE                  /* scan_hex */,
  FALSE                 /* scan_hex_dollar */,
  TRUE                  /* scan_string_sq */,
  TRUE                  /* scan_string_dq */,
  TRUE                  /* numbers_2_int */,
  FALSE                 /* int_2_float */,
  FALSE                 /* identifier_2_string */,
  TRUE                  /* char_2_token */,
  FALSE                 /* symbol_2_token */,
  FALSE                 /* scope_0_fallback */,
  FALSE                 /* store_int64 */,
};

static const struct
{
  gchar *name;
  guint token;
} symbols[] = {
  {"include", GLIB_TEST_INCLUDE},
  {"name", GLIB_TEST_NAME}
};

/*
 * Name: g_scanner_new
 * Params: const GScannerConfig *config_templ
 * Returns: GScanner*
 * Assertion: Creates a new GScanner. The config_templ structure specifies the initial settings of the scanner, which are copied into the GScanner config field. If you pass NULL then the default settings are used.
 *            config_templ : the initial scanner settings.
 *            Returns : the new GScanner. 
 * Params Values: const GScannerConfig *config_templ
 * Expected: GScanner*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GScannerConfig scanconf;
    GScanner *g_scanner;
    
    g_scanner = g_scanner_new(NULL);
    if (g_scanner->config->case_sensitive != g_scanner_config_template.case_sensitive){
        TEST_FAIL("g_scanner_new: case_sensitive", NULL);
    }
    if (strcmp(g_scanner->config->cset_identifier_first, g_scanner_config_template.cset_identifier_first) != 0){
        TEST_FAIL("g_scanner_new: cset_identifier_first", NULL);
    }
    if (strcmp(g_scanner->config->cset_identifier_nth, g_scanner_config_template.cset_identifier_nth) != 0){
        TEST_FAIL("g_scanner_new: cset_identifier_nth", NULL);
    }
    if (strcmp(g_scanner->config->cpair_comment_single, g_scanner_config_template.cpair_comment_single) != 0){
        TEST_FAIL("g_scanner_new: cpair_comment_single", NULL);
    }
    if (g_scanner->config->skip_comment_multi != g_scanner_config_template.skip_comment_multi){
        TEST_FAIL("g_scanner_new: skip_comment_multi", NULL);
    }
    if (g_scanner->config->skip_comment_single != g_scanner_config_template.skip_comment_single){
        TEST_FAIL("g_scanner_new: skip_comment_single", NULL);
    }
    if (g_scanner->config->scan_comment_multi != g_scanner_config_template.scan_comment_multi){
        TEST_FAIL("g_scanner_new: scan_comment_multi", NULL);
    }
    if (g_scanner->config->scan_identifier != g_scanner_config_template.scan_identifier){
        TEST_FAIL("g_scanner_new: scan_identifier", NULL);
    }
    if (g_scanner->config->scan_identifier_1char != g_scanner_config_template.scan_identifier_1char){
        TEST_FAIL("g_scanner_new: scan_identifier_1char", NULL);
    }
    if (g_scanner->config->scan_identifier_NULL != g_scanner_config_template.scan_identifier_NULL){
        TEST_FAIL("g_scanner_new: scan_identifier_NULL", NULL);
    }
    if (g_scanner->config->scan_symbols != g_scanner_config_template.scan_symbols){
        TEST_FAIL("g_scanner_new: scan_symbols", NULL);
    }
    if (g_scanner->config->scan_binary != g_scanner_config_template.scan_binary){
        TEST_FAIL("g_scanner_new: scan_binary", NULL);
    }
    if (g_scanner->config->scan_octal != g_scanner_config_template.scan_octal){
        TEST_FAIL("g_scanner_new: scan_octal", NULL);
    }
    if (g_scanner->config->scan_float != g_scanner_config_template.scan_float){
        TEST_FAIL("g_scanner_new: scan_float", NULL);
    }
    if (g_scanner->config->scan_hex != g_scanner_config_template.scan_hex){
        TEST_FAIL("g_scanner_new: scan_hex", NULL);
    }
    if (g_scanner->config->scan_hex_dollar != g_scanner_config_template.scan_hex_dollar){
        TEST_FAIL("g_scanner_new: scan_hex_dollar", NULL);
    }
    if (g_scanner->config->scan_string_sq != g_scanner_config_template.scan_string_sq){
        TEST_FAIL("g_scanner_new: scan_string_sq", NULL);
    }
    if (g_scanner->config->scan_string_dq != g_scanner_config_template.scan_string_dq){
        TEST_FAIL("g_scanner_new: scan_string_dq", NULL);
    }
    if (g_scanner->config->numbers_2_int != g_scanner_config_template.numbers_2_int){
        TEST_FAIL("g_scanner_new: numbers_2_int", NULL);
    }
    if (g_scanner->config->int_2_float != g_scanner_config_template.int_2_float){
        TEST_FAIL("g_scanner_new: int_2_float", NULL);
    }
    if (g_scanner->config->identifier_2_string != g_scanner_config_template.identifier_2_string){
        TEST_FAIL("g_scanner_new: identifier_2_string", NULL);
    }
    if (g_scanner->config->char_2_token != g_scanner_config_template.char_2_token){
        TEST_FAIL("g_scanner_new: char_2_token", NULL);
    }
    if (g_scanner->config->symbol_2_token != g_scanner_config_template.symbol_2_token){
        TEST_FAIL("g_scanner_new: symbol_2_token", NULL);
    }
    if (g_scanner->config->scope_0_fallback != g_scanner_config_template.scope_0_fallback){
        TEST_FAIL("g_scanner_new: scope_0_fallback", NULL);
    }
    if (g_scanner->config->store_int64 != g_scanner_config_template.store_int64){
        TEST_FAIL("g_scanner_new: store_int64", NULL);
    }
    if (strcmp(g_scanner->config->cset_skip_characters, g_scanner_config_template.cset_skip_characters) != 0){
        TEST_FAIL("g_scanner_new: cset_skip_characters", NULL);
    }
    
    g_scanner_destroy(g_scanner);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_input_file
 * Params: GScanner *scanner, gint input_fd 
 * Returns: void
 * Assertion: Prepares to scan a file.
 *            scanner : a GScanner.
 *            input_fd : a file descriptor. 
 * Params Values: GScanner *scanner, gint input_fd
 * Expected: void  
 */
static void test_purpose_2()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint fd;
    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    
    g_scanner = g_scanner_new(NULL);
    fd = g_open("LexScan.c", O_RDONLY, 0);
    g_scanner_input_file(g_scanner, fd);
    g_scanner->input_name = "LexScan.c";
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    g_scanner_destroy(g_scanner);
    close(fd);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_input_text
 * Params: GScanner *scanner, const gchar *text, guint text_len
 * Returns: void
 * Assertion: Prepares to scan a text buffer
 *            scanner : a GScanner.
 *            text : the text buffer to scan.
 *            text_len : the length of the text buffer.
 * Params Values: GScanner *scanner, const gchar *text, guint text_len
 * Expected: void  
 */
static void test_purpose_3()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    gchar text[] = "the file name are integrated include test cases";
    
    g_scanner = g_scanner_new(NULL);
    g_scanner_input_text(g_scanner, text, sizeof(text));
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    while ((tokentype = g_scanner_get_next_token(g_scanner)) != G_TOKEN_EOF){
        if (tokentype == G_TOKEN_SYMBOL){
            gint cur_token = GPOINTER_TO_INT(g_scanner_cur_value(g_scanner).v_symbol);
            if ((cur_token != GLIB_TEST_INCLUDE) && (cur_token != GLIB_TEST_NAME)){
                TEST_FAIL("g_scanner_get_next_token: failed", NULL);
            }
        }
    }
    g_scanner_destroy(g_scanner);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_set_scope
 * Params: GScanner *scanner, guint scope_id
 * Returns: guint
 * Assertion: Sets the current scope.
 *            scanner : a GScanner.
 *            scope_id : the new scope id.
 *            Returns : the old scope id.
 * Params Values: GScanner *scanner, guint scope_id
 * Expected: guint  
 */
static void test_purpose_4()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    guint old_scope;
    gchar text[] = "the file name are integrated include test cases";
    
    g_scanner = g_scanner_new(NULL);
    g_scanner_input_text(g_scanner, text, sizeof(text));
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    old_scope = g_scanner_set_scope(g_scanner, 10);
    if (old_scope != 0){
        TEST_FAIL("g_scanner_set_scope: old scope should be 0", NULL);
    }
    else{
        if (g_scanner->scope_id != 10){
             TEST_FAIL("g_scanner_set_scope: new scope should be 10", NULL);
        }
    }
    g_scanner_destroy(g_scanner);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_lookup_symbol
 * Params: GScanner *scanner, const gchar *symbol
 * Returns: gpointer
 * Assertion: Looks up a symbol in the current scope and return its value. If the symbol is not bound in the current scope, NULL is returned.
 *            scanner : a GScanner.
 *            symbol : the symbol to look up.
 *            Returns : the value of symbol in the current scope, or NULL if symbol is not bound in the current scope.
 * Params Values: "name"
 * Expected: GLIB_TEST_NAME  
 */
static void test_purpose_5()
{
    #define SYM    "name"
    #define RETP   GLIB_TEST_NAME
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    guint old_scope;
    gchar text[] = "the file name are integrated include test cases";
    
    g_scanner = g_scanner_new(NULL);
    g_scanner_input_text(g_scanner, text, sizeof(text));
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    {
        gpointer p = g_scanner_lookup_symbol(g_scanner, SYM);
        if (p == NULL){
            if (RETP != NULL){
                TEST_FAIL("g_scanner_lookup_symbol: failed", NULL);
            }
        }
        else{
            if (GPOINTER_TO_INT(p) != RETP){
                TEST_FAIL("g_scanner_lookup_symbol: failed", NULL);
            }
        }
    }
    g_scanner_destroy(g_scanner);
    
    #undef SYM
    #undef RETP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_lookup_symbol
 * Params: GScanner *scanner, const gchar *symbol
 * Returns: gpointer
 * Assertion: Looks up a symbol in the current scope and return its value. If the symbol is not bound in the current scope, NULL is returned.
 *            scanner : a GScanner.
 *            symbol : the symbol to look up.
 *            Returns : the value of symbol in the current scope, or NULL if symbol is not bound in the current scope.
 * Params Values: "static"
 * Expected: NULL  
 */
static void test_purpose_6()
{
    #define SYM    "static"
    #define RETP   NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    guint old_scope;
    gchar text[] = "the file name are integrated include test cases";
    
    g_scanner = g_scanner_new(NULL);
    g_scanner_input_text(g_scanner, text, sizeof(text));
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    {
        gpointer p = g_scanner_lookup_symbol(g_scanner, SYM);
        if (p == NULL){
            if (RETP != NULL){
                TEST_FAIL("g_scanner_lookup_symbol: failed", NULL);
            }
        }
        else{
            if (GPOINTER_TO_INT(p) != RETP){
                TEST_FAIL("g_scanner_lookup_symbol: failed", NULL);
            }
        }
    }
    g_scanner_destroy(g_scanner);
    
    #undef SYM
    #undef RETP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_scanner_unexp_token
 * Params: GScanner *scanner, GTokenType expected_token, const gchar *identifier_spec, const gchar *symbol_spec, const gchar *symbol_name, const gchar *message, gint is_error
 * Returns: void
 * Assertion: Outputs a message through the scanner's msg_handler, resulting from an unexpected token in the input stream. Note that you should not call g_scanner_peek_next_token() followed by g_scanner_unexp_token() without an intermediate call to g_scanner_get_next_token(), as g_scanner_unexp_token() evaluates the scanner's current token (not the peeked token) to construct part of the message.
 *            scanner : a GScanner.
 *            expected_token : the expected token.
 *            identifier_spec :   a string describing how the scanner's user refers to identifiers (NULL defaults to "identifier"). This is used if expected_token is G_TOKEN_IDENTIFIER or G_TOKEN_IDENTIFIER_NULL.
 *            symbol_spec :   a string describing how the scanner's user refers to symbols (NULL defaults to "symbol"). This is used if expected_token is G_TOKEN_SYMBOL or any token value greater than G_TOKEN_LAST.
 *            symbol_name :   the name of the symbol, if the scanner's current token is a symbol.
 * message :   a message string to output at the end of the warning/error, or NULL.
 *            is_error :  if TRUE it is output as an error. If FALSE it is output as a warning.
 * Params Values: GScanner *scanner, GTokenType expected_token, const gchar *identifier_spec, const gchar *symbol_spec, const gchar *symbol_name, const gchar *message, gint is_error
 * Expected: void  
 */
static void test_purpose_7()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    GScannerConfig scanconf;
    GScanner *g_scanner;
    GTokenType tokentype;
    guint old_scope;
    gchar text[] = "the file name are integrated include test cases";
    
    g_scanner = g_scanner_new(NULL);
    g_scanner_input_text(g_scanner, text, sizeof(text));
    for (i = 0; i < G_N_ELEMENTS(symbols); i++){
        g_scanner_scope_add_symbol(g_scanner, 0,  symbols[i].name, GINT_TO_POINTER (symbols[i].token));
    }
    tokentype = g_scanner_get_next_token(g_scanner);
    g_scanner_unexp_token(g_scanner, GLIB_TEST_INCLUDE, NULL, "Error", "include", "My God", FALSE);
    g_scanner_destroy(g_scanner);
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for LexScan ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {NULL,0}
};
