/*
 * MainLoop methods tests
 * Testing MainLoop methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static quit_flag = 0;

GMainLoop *mainloop;
GMainContext *gcontext;

static gboolean gtimeout(gpointer data)
{
    quit_flag = 1;
    g_main_loop_quit(mainloop);
    return FALSE;
}

static gboolean rerecurser(gpointer data)
{
    quit_flag ++;
    g_main_context_unref(gcontext);
    g_main_loop_quit(mainloop);
    return TRUE;
}

static gboolean recurser_start(gpointer data)
{
    quit_flag ++;
    gcontext = g_main_context_new();
    g_timeout_add (10, rerecurser, NULL);
    g_main_context_iteration(gcontext, FALSE);
}

static gboolean test_idle(gpointer data)
{
    g_main_loop_quit(mainloop);
}

static gboolean idle_func1(gpointer data)
{
    quit_flag ++;
    if (quit_flag == 10){
        g_main_loop_quit(mainloop);
    }
    return TRUE;
}

static gboolean idle_func2(gpointer data)
{
    quit_flag ++;
    return FALSE;
}


/*
 * Name: g_main_loop_new
 * Params: GMainContext *context, gboolean is_running
 * Returns: GMainLoop*
 * Assertion: Creates a new GMainLoop structure.
 *            context : a GMainContext (if NULL, the default context will be used).
 *            is_running : set to TRUE to indicate that the loop is running. This is not very important since calling g_main_loop_run() will set this to TRUE anyway.
 *            Returns : a new GMainLoop. 
 * Params Values: GMainContext *context, gboolean is_running
 * Expected: GMainLoop*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    mainloop = g_main_loop_new(NULL, FALSE);
    if (mainloop == NULL){
        TEST_FAIL("g_main_loop_new: failed", NULL);
        g_main_loop_unref(mainloop);
        return;
    }
    mainloop = g_main_loop_new(NULL, TRUE);
    if (!g_main_loop_is_running(mainloop)){
        TEST_FAIL("g_main_loop_new: should be running", NULL);
        g_main_loop_unref(mainloop);
        return;
    }
    {
        GMainContext* maincontext = g_main_context_new();
        if (maincontext == NULL){
             TEST_FAIL("g_main_loop_new: g_main_context_new", NULL);
        }
        else{
            mainloop = g_main_loop_new(maincontext, FALSE);
            if (mainloop == NULL){
                TEST_FAIL("g_main_loop_new: failed", NULL);
                g_main_loop_unref(mainloop);
            }
        }
        g_main_context_unref(maincontext);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_main_loop_run
 * Params: GMainLoop *loop
 * Returns: void
 * Assertion: Runs a main loop until g_main_loop_quit() is called on the loop. If this is called for the thread of the loop's GMainContext, it will process events from the loop, otherwise it will simply wait.
 *            loop : a GMainLoop
 * Params Values: GMainLoop *loop
 * Expected: void
 * 
 * Name: g_main_loop_quit
 * Params: GMainLoop *loop
 * Returns: void
 * Assertion: Runs a main loop until g_main_loop_quit() is called on the loop. If this is called for the thread of the loop's GMainContext, it will process events from the loop, otherwise it will simply wait.
 *            loop : a GMainLoop
 * Params Values: GMainLoop *loop
 * Expected: void
 * 
 * Name: g_timeout_add
 * Params: guint interval, GSourceFunc function, gpointer data
 * Returns: guint
 * Assertion: Sets a function to be called at regular intervals, with the default priority, G_PRIORITY_DEFAULT. The function is called repeatedly until it returns FALSE, at which point the timeout is automatically destroyed and the function will not be called again. The first call to the function will be at the end of the first interval.
 * Note that timeout functions may be delayed, due to the processing of other event sources. Thus they should not be relied on for precise timing. After each call to the timeout function, the time of the next timeout is recalculated based on the current time and the given interval (it does not try to 'catch up' time lost in delays).
 *            interval : the time between calls to the function, in milliseconds (1/1000ths of a second)
 *            function : function to call
 *            data : data to pass to function
 *            Returns : the id of event source.
 * 
 * Name: g_main_context_pending
 * Params: GMainContext *context
 * Returns: gboolean
 * Assertion: Checks if any sources have pending events for the given context.
 *            context : a GMainContext (if NULL, the default context will be used)
 *            Returns : TRUE if events are pending.
 * Params Values: GMainContext *context
 * Expected: gboolean  
 */
static void test_purpose_2()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    guint src_id;
    gboolean pending = FALSE;
    gint timer = 0;
    
    quit_flag = 0;
    mainloop = g_main_loop_new(NULL, FALSE);
    while (timer < 1000000){
        if (g_main_context_pending(NULL)){
            pending = TRUE;
            break;
        }
        timer ++;
    }
    src_id = g_timeout_add(50, gtimeout, NULL);
    g_main_loop_run(mainloop);
    g_main_loop_unref(mainloop);
    if (quit_flag != 1){
        TEST_FAIL("g_main_loop_run: g_timeout_add failed", NULL);
    }
    if (!pending){
        TEST_FAIL("g_main_loop_run: g_main_context_pending", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_main_context_iteration
 * Params: GMainContext *context, gboolean may_block
 * Returns: gboolean
 * Assertion: Runs a single iteration for the given main loop. This involves checking to see if any event sources are ready to be processed, then if no events sources are ready and may_block is TRUE, waiting for a source to become ready, then dispatching the highest priority events sources that are ready. Note that even when may_block is TRUE, it is still possible for g_main_context_iteration() to return FALSE, since the the wait may be interrupted for other reasons than an event source becoming ready.
 *            context : a GMainContext (if NULL, the default context will be used)
 *            may_block : whether the call may block.
 *            Returns : TRUE if events were dispatched.
 * Params Values: GMainContext *context, gboolean may_block
 * Expected: gboolean
 *   
 */
static void test_purpose_3()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    quit_flag = 0;
    
    mainloop = g_main_loop_new(NULL, FALSE);
    g_timeout_add (50, recurser_start, NULL);
    g_main_loop_run(mainloop);
    g_main_loop_unref(mainloop);
    if (quit_flag != 2){
        TEST_FAIL("g_main_context_iteration: failed", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_source_set_can_recurse
 * Params: GSource *source, gboolean can_recurse
 * Returns: void
 * Assertion: Sets whether a source can be called recursively. If can_recurse is TRUE, then while the source is being dispatched then this source will be processed normally. Otherwise, all processing of this source is blocked until the dispatch function returns.
 *            source : a GSource
 *            can_recurse : whether recursion is allowed for this source
 * Params Values: TRUE
 * Expected: TRUE
 *   
 */
static void test_purpose_4()
{
    #define RECURSE TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSource *source = g_timeout_source_new(50);
    g_source_set_can_recurse(source, RECURSE);
    if (g_source_get_can_recurse(source) != RECURSE){
        TEST_FAIL("g_source_set_can_recurse: failed", NULL);
    }
    g_source_unref(source);
    #undef RECURSE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_source_set_can_recurse
 * Params: GSource *source, gboolean can_recurse
 * Returns: void
 * Assertion: Sets whether a source can be called recursively. If can_recurse is TRUE, then while the source is being dispatched then this source will be processed normally. Otherwise, all processing of this source is blocked until the dispatch function returns.
 *            source : a GSource
 *            can_recurse : whether recursion is allowed for this source
 * Params Values: FALSE
 * Expected: FALSE
 *   
 */
static void test_purpose_5()
{
    #define RECURSE FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSource *source = g_timeout_source_new(50);
    g_source_set_can_recurse(source, RECURSE);
    if (g_source_get_can_recurse(source) != RECURSE){
        TEST_FAIL("g_source_set_can_recurse: failed", NULL);
    }
    g_source_unref(source);
    #undef RECURSE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for MainLoop ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
