/*
 * pango_text methods tests
 * Testing pango_text methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

struct _PangoAttrList
{
  guint ref_count;
  GSList *attributes;
  GSList *attributes_tail;
};

static PangoAttribute *
at (unsigned s, unsigned e, PangoAttribute *a)
{
    a->start_index = s;
    a->end_index = e;
    return a;
}

int struc_cmp (char *str1,char *str2,int size)
{
    int i;
    for (i = 0;i < size;i++)
        if (str1[i] != str2[i])
            return 0;    
    return 1;
}
/* ------------------------------------------------------------------------- */

static const char *
color_to_string (PangoColor color)
{
    return g_strdup_printf ("%04x:%04x:%04x", color.red, color.green, color.blue);
}


static gboolean
cb_gnm_pango_attr_dump (PangoAttribute *attr, gpointer user_data)
{
    g_print ("  start=%u; end=%u\n", attr->start_index, attr->end_index);
    switch (attr->klass->type) {
    case PANGO_ATTR_FAMILY: g_print ("    family=\"%s\"\n", ((PangoAttrString *)attr)->value); break;
    case PANGO_ATTR_LANGUAGE: g_print ("    language=\"%s\"\n", pango_language_to_string (((PangoAttrLanguage *)attr)->value)); break;
    case PANGO_ATTR_STYLE: g_print ("    style=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_WEIGHT: g_print ("    weight=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_VARIANT: g_print ("    variant=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_STRETCH: g_print ("    stretch=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_UNDERLINE: g_print ("    underline=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_STRIKETHROUGH: g_print ("    strikethrough=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_RISE: g_print ("    rise=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_FALLBACK: g_print ("    fallback=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_LETTER_SPACING: g_print ("    letter_spacing=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_SIZE: g_print ("    size=%d%s\n",
                       ((PangoAttrSize *)attr)->size,
                       ((PangoAttrSize *)attr)->absolute ? " abs" : ""); break;
    case PANGO_ATTR_SCALE: g_print ("    scale=%g\n", ((PangoAttrFloat *)attr)->value); break;
    case PANGO_ATTR_FOREGROUND: g_print ("    foreground=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_BACKGROUND: g_print ("    background=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_UNDERLINE_COLOR: g_print ("    underline_color=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_STRIKETHROUGH_COLOR: g_print ("    strikethrough_color=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    default: g_print ("    type=%d\n", attr->klass->type);
    }

    return FALSE;
}

/*Function for pango_attr_list_filter() test.*/
static gboolean
filter_func(PangoAttribute *attr, gpointer user_data)
{
    g_print ("  start=%u; end=%u\n", attr->start_index, attr->end_index);
    switch (attr->klass->type) {
    case PANGO_ATTR_FAMILY: g_print ("    family=\"%s\"\n", ((PangoAttrString *)attr)->value); break;
    case PANGO_ATTR_LANGUAGE: g_print ("    language=\"%s\"\n", pango_language_to_string (((PangoAttrLanguage *)attr)->value)); break;
    case PANGO_ATTR_STYLE: g_print ("    style=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_WEIGHT: g_print ("    weight=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_VARIANT: g_print ("    variant=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_STRETCH: g_print ("    stretch=%d\n", ((PangoAttrInt *)attr)->value); break;
/*    case PANGO_ATTR_UNDERLINE: g_print ("    underline=%d\n", ((PangoAttrInt *)attr)->value); break;*/
    case PANGO_ATTR_STRIKETHROUGH: g_print ("    strikethrough=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_RISE: g_print ("    rise=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_FALLBACK: g_print ("    fallback=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_LETTER_SPACING: g_print ("    letter_spacing=%d\n", ((PangoAttrInt *)attr)->value); break;
    case PANGO_ATTR_SIZE: g_print ("    size=%d%s\n",
                       ((PangoAttrSize *)attr)->size,
                       ((PangoAttrSize *)attr)->absolute ? " abs" : ""); break;
    case PANGO_ATTR_SCALE: g_print ("    scale=%g\n", ((PangoAttrFloat *)attr)->value); break;
    case PANGO_ATTR_FOREGROUND: g_print ("    foreground=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_BACKGROUND: g_print ("    background=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_UNDERLINE_COLOR: g_print ("    underline_color=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    case PANGO_ATTR_STRIKETHROUGH_COLOR: g_print ("    strikethrough_color=%s\n", color_to_string (((PangoAttrColor *)attr)->color)); break;
    default: g_print ("    type=%d\n", attr->klass->type);
    return FALSE;
    }

    return TRUE;
}

static void
gnm_pango_attr_dump (PangoAttrList *list)
{
    g_print ("PangoAttrList at %p\n", list);
    pango_attr_list_filter (list, cb_gnm_pango_attr_dump, NULL);
}




/*
 * Name: pango_attr_list_unref
 * Params: PangoAttrList *list
 * Returns: void
 * Assertion: Decrease the reference count of the given attribute list by one. If the result is zero, free the attribute list and the attributes it contains.
 * Params Values: attrs
 * Expected: decrease the reference number of attr list by 1
 *   
 */
static void test_purpose_1()
{
    #define ATTRS attrs
    
    PangoAttrList *attrs = pango_attr_list_new ();
    PangoAttribute *attr;
    GSList *tmp_list;
    guint ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Increase the reference count number by 1.*/
    pango_attr_list_ref (attrs);
    ref_num = attrs->ref_count;
    /*g_printf ("\n Before unref the reference num is %d\n",ref_num);*/
    
    /*Decrease the reference count number by 1.*/
    pango_attr_list_unref (ATTRS);
    /*g_printf ("After unref the reference num is %d\n",attrs->ref_count);*/
    
    /*Verify that the reference count number is changed correctly.*/
    if (ref_num != attrs->ref_count + 1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        pango_attr_list_unref (attrs);
        return;
    }
    
    if (attrs->ref_count == 1)
    {
        tmp_list = attrs->attributes;
        if (tmp_list != NULL)
        {
            attr = tmp_list->data;
            pango_attr_list_unref(attrs);
            if (attr->klass != NULL)
            {
                TEST_FAIL(get_wrong_type_msg(),NULL);
            }
        }
    }
    
    #undef ATTRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_new
 * Params: void
 * Returns: the newly allocated PangoAttrList.  
 * Assertion: Create a new empty attribute list with a reference count of 1.
 * Params Values: void
 * Expected: a new created attr list
 *   
 */
static void test_purpose_2()
{
    
    PangoAttrList *attrs = NULL;
    guint ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Check whether the attr list is created.*/
    if (attrs == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    ref_num = attrs->ref_count;
    /*g_printf("Reference count of attr list is %d.\n",ref_num);*/
    
    /*Check the reference count of the attr list.*/
    if (ref_num != 1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_list_unref(attrs);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_insert
 * Params: PangoAttrList *list, PangoAttribute *attr
 * Returns: void
 * Assertion: Insert the given attribute into the PangoAttrList. It will be inserted after all other attributes with a matching start_index.
 * Params Values: attrs,weight
 * Expected: insert attribute weight into the attr list attrs
 *   
 */
static void test_purpose_3()
{
    #define ATTR_LIST attrs
    #define ATTR weight 
    
    PangoAttrList *attrs;
    PangoAttribute *weight;
    PangoAttrIterator *iterator;
    PangoAttrInt *tmp_attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create a new attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_NORMAL);
    weight->start_index = 0;
    weight->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(ATTR_LIST,ATTR);
    
    /*Another attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_BOLD);
    weight->start_index = 3;
    weight->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(ATTR_LIST,ATTR);
    
    /*Get first iterator from the attr list.*/
    iterator = pango_attr_list_get_iterator (attrs);
    tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
    
    /*The value of the first weight attribute is PANGO_WEIGHT_NORMAL.*/
    if (tmp_attr->value != PANGO_WEIGHT_NORMAL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*Iterator next.*/
    pango_attr_iterator_next(iterator);
    
    tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
    
    /*The value of the second weight attribute is PANGO_WEIGHT_BOLD.*/
    if (tmp_attr->value != PANGO_WEIGHT_BOLD)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    
    pango_attr_list_unref(attrs);
    
    #undef ATTR_LIST
    #undef ATTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_weight_new
 * Params: PangoWeight weight
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font weight attribute.
 * Params Values: PANGO_WEIGHT_ULTRALIGHT  
 * Expected: a new created weight attribute with weight PANGO_WEIGHT_ULTRALIGHT 
 *   
 */
static void test_purpose_4()
{
    #define FONT_WEIGHT PANGO_WEIGHT_ULTRALIGHT 
    
    PangoAttribute *weight;
    PangoAttrInt *weightInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new weight attribute.*/
    weight = pango_attr_weight_new(FONT_WEIGHT);
    weightInt = (PangoAttrInt *)weight;
    
    /*Verify the weight of the attribute.*/
    if (weightInt->value != FONT_WEIGHT)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(weight);
        return;
    }
    
    pango_attribute_destroy(weight);
    
    
    #undef FONT_WEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_weight_new
 * Params: PangoWeight weight
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font weight attribute.
 * Params Values: PANGO_WEIGHT_NORMAL  
 * Expected: a new created weight attribute with weight PANGO_WEIGHT_NORMAL 
 *   
 */
static void test_purpose_5()
{
    #define FONT_WEIGHT PANGO_WEIGHT_NORMAL 
    
    PangoAttribute *weight;
    PangoAttrInt *weightInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new weight attribute.*/
    weight = pango_attr_weight_new(FONT_WEIGHT);
    weightInt = (PangoAttrInt *)weight;
    
    /*Verify the weight of the attribute.*/
    if (weightInt->value != FONT_WEIGHT)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(weight);
        return;
    }
    
    pango_attribute_destroy(weight);
    
    
    #undef FONT_WEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_weight_new
 * Params: PangoWeight weight
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font weight attribute.
 * Params Values: PANGO_WEIGHT_BOLD  
 * Expected: a new created weight attribute with weight PANGO_WEIGHT_BOLD 
 *   
 */
static void test_purpose_6()
{
    #define FONT_WEIGHT PANGO_WEIGHT_BOLD 
    
    PangoAttribute *weight;
    PangoAttrInt *weightInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new weight attribute.*/
    weight = pango_attr_weight_new(FONT_WEIGHT);
    weightInt = (PangoAttrInt *)weight;
    
    /*Verify the weight of the attribute.*/
    if (weightInt->value != FONT_WEIGHT)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(weight);
        return;
    }
    
    pango_attribute_destroy(weight);
    
    
    #undef FONT_WEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_foreground_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute.
 * Assertion: Create a new foreground color attribute.
 * Params Values: 0,0,0
 * Expected: a new foreground color attribute with R:0 G:0 B:0
 *   
 */
static void test_purpose_7()
{
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    
    PangoAttribute *foregrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new foreground color attribute.*/
    foregrd_color = pango_attr_foreground_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)foregrd_color;
    
    /*Verify the color of the foreground color attribute.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(foregrd_color);
        return;
    }
    
    pango_attribute_destroy(foregrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_foreground_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute.
 * Assertion: Create a new foreground color attribute.
 * Params Values: 255,255,65535
 * Expected: a new foreground color attribute with R:255 G:255 B:65535
 *   
 */
static void test_purpose_8()
{
    #define RED 255
    #define GREEN 255
    #define BLUE 65535
    
    PangoAttribute *foregrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new foreground color attribute.*/
    foregrd_color = pango_attr_foreground_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)foregrd_color;
    
    /*Verify the color of the foreground color attribute.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(foregrd_color);
        return;
    }
    
    pango_attribute_destroy(foregrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_foreground_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute.
 * Assertion: Create a new foreground color attribute.
 * Params Values: 65535,65535,65535
 * Expected: a new foreground color attribute with R:65535 G:65535 B:65535
 *   
 */
static void test_purpose_9()
{
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    
    PangoAttribute *foregrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new foreground color attribute.*/
    foregrd_color = pango_attr_foreground_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)foregrd_color;
    
    /*Verify the color of the foreground color attribute.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(foregrd_color);
        return;
    }
    
    pango_attribute_destroy(foregrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_scale_new
 * Params: double scale_factor
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font size scale attribute. The base font for the affected text will have its size multiplied by scale_factor.
 * Params Values: 0.4 
 * Expected: a new font size scale with factor 0.4 
 *   
 */
static void test_purpose_10()
{
    #define FONT_SCALE 0.4 
    
    
    PangoAttribute *scale;
    PangoAttrFloat *scaleFloat;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font size scale attribute.*/
    scale = pango_attr_scale_new(FONT_SCALE);
    scaleFloat = (PangoAttrFloat *)scale;
    
    /*Verify the font size scale of the attribute.*/
    if (scaleFloat->value != FONT_SCALE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(scale);
        return;
    }
    
    pango_attribute_destroy(scale);
    
    #undef FONT_SCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_scale_new
 * Params: double scale_factor
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font size scale attribute. The base font for the affected text will have its size multiplied by scale_factor.
 * Params Values: 1.5
 * Expected: a new font size scale with factor 1.5
 *   
 */
static void test_purpose_11()
{
    #define FONT_SCALE 1.5
    
    
    PangoAttribute *scale;
    PangoAttrFloat *scaleFloat;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font size scale attribute.*/
    scale = pango_attr_scale_new(FONT_SCALE);
    scaleFloat = (PangoAttrFloat *)scale;
    
    /*Verify the font size scale of the attribute.*/
    if (scaleFloat->value != FONT_SCALE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(scale);
        return;
    }
    
    pango_attribute_destroy(scale);
    
    #undef FONT_SCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_scale_new
 * Params: double scale_factor
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font size scale attribute. The base font for the affected text will have its size multiplied by scale_factor.
 * Params Values: 2.5
 * Expected: a new font size scale with factor 2.5
 *   
 */
static void test_purpose_12()
{
    #define FONT_SCALE 2.5
    
    
    PangoAttribute *scale;
    PangoAttrFloat *scaleFloat;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font size scale attribute.*/
    scale = pango_attr_scale_new(FONT_SCALE);
    scaleFloat = (PangoAttrFloat *)scale;
    
    /*Verify the font size scale of the attribute.*/
    if (scaleFloat->value != FONT_SCALE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(scale);
        return;
    }
    
    pango_attribute_destroy(scale);
    
    #undef FONT_SCALE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_parse_markup
 * Params: const char *markup_text, int length, gunichar accel_marker, PangoAttrList **attr_list, char **text, gunichar *accel_char, GError **error
 * Returns: FALSE if error is set, otherwise TRUE.
 * Assertion: Parses marked-up text (see markup format) to create a plaintext string and an attribute list. If accel_marker is nonzero, the given character will mark the character following it as an accelerator. For example, the accel marker might be an ampersand or underscore. All characters marked as an accelerator will receive a PANGO_UNDERLINE_LOW attribute, and the first character so marked will be returned in accel_char. Two accel_marker characters following each other produce a single literal accel_marker character.
 * Params Values: markup_text,-1,0,NULL,NULL,NULL,&error 
 * Expected: TRUE
 *   
 */
static void test_purpose_13()
{
    #define MARKUP_TEXT markup_text 
    
    GError *error = NULL;
    gboolean parse_rlt;
    const char *markup_text ="\"<span foreground=\"blue\" size=\"x-large\">Blue text</span> is <i>cool</i>!\"";
    
        
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Parse the markup text.*/
    parse_rlt = pango_parse_markup(MARKUP_TEXT,-1,0,NULL,NULL,NULL,&error);
    
    /*Verify the parse result.*/
    if ((error != NULL)&&(parse_rlt) || ((error == NULL)&&(!parse_rlt)))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    
    #undef MARKUP_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_parse_markup
 * Params: const char *markup_text, int length, gunichar accel_marker, PangoAttrList **attr_list, char **text, gunichar *accel_char, GError **error
 * Returns: FALSE if error is set, otherwise TRUE.
 * Assertion: Parses marked-up text (see markup format) to create a plaintext string and an attribute list. If accel_marker is nonzero, the given character will mark the character following it as an accelerator. For example, the accel marker might be an ampersand or underscore. All characters marked as an accelerator will receive a PANGO_UNDERLINE_LOW attribute, and the first character so marked will be returned in accel_char. Two accel_marker characters following each other produce a single literal accel_marker character.
 * Params Values: "test string.",-1,0,NULL,NULL,NULL,&error 
 * Expected: FALSE
 *   
 */
static void test_purpose_14()
{
    #define MARKUP_TEXT "test string." 
    
    GError *error = NULL;
    gboolean parse_rlt;
    const char *markup_text ="\"<span foreground=\"blue\" size=\"x-large\">Blue text</span> is <i>cool</i>!\"";
    
        
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Parse the markup text.*/
    parse_rlt = pango_parse_markup(MARKUP_TEXT,-1,0,NULL,NULL,NULL,&error);
    
    /*Verify the parse result.*/
    if ((error != NULL)&&(parse_rlt) || ((error == NULL)&&(!parse_rlt)))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    
    #undef MARKUP_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_style_new
 * Params: PangoStyle style
 * Returns: the new PangoAttribute.  
 * Assertion: Create a new font slant style attribute.
 * Params Values: PANGO_STYLE_NORMAL 
 * Expected: a new font slant style attribute with style PANGO_STYLE_NORMAL
 *   
 */
static void test_purpose_15()
{
    #define FONT_STYLE PANGO_STYLE_NORMAL
    
    PangoAttribute *style;
    PangoAttrInt *styleInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font slan style attribute.*/
    style = pango_attr_style_new(FONT_STYLE);
    styleInt = (PangoAttrInt *)style;
    
    /*Verify the slan style of the attribute.*/
    if (styleInt->value != FONT_STYLE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(style);
        return;
    }
    
    pango_attribute_destroy(style);
    
    #undef FONT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_style_new
 * Params: PangoStyle style
 * Returns: the new PangoAttribute.  
 * Assertion: Create a new font slant style attribute.
 * Params Values: PANGO_STYLE_OBLIQUE 
 * Expected: a new font slant style attribute with style PANGO_STYLE_OBLIQUE
 *   
 */
static void test_purpose_16()
{
    #define FONT_STYLE PANGO_STYLE_OBLIQUE
    
    PangoAttribute *style;
    PangoAttrInt *styleInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font slan style attribute.*/
    style = pango_attr_style_new(FONT_STYLE);
    styleInt = (PangoAttrInt *)style;
    
    /*Verify the slan style of the attribute.*/
    if (styleInt->value != FONT_STYLE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(style);
        return;
    }
    
    pango_attribute_destroy(style);
    
    #undef FONT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_style_new
 * Params: PangoStyle style
 * Returns: the new PangoAttribute.  
 * Assertion: Create a new font slant style attribute.
 * Params Values: PANGO_STYLE_ITALIC 
 * Expected: a new font slant style attribute with style PANGO_STYLE_ITALIC
 *   
 */
static void test_purpose_17()
{
    #define FONT_STYLE PANGO_STYLE_ITALIC
    
    PangoAttribute *style;
    PangoAttrInt *styleInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font slan style attribute.*/
    style = pango_attr_style_new(FONT_STYLE);
    styleInt = (PangoAttrInt *)style;
    
    /*Verify the slan style of the attribute.*/
    if (styleInt->value != FONT_STYLE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        pango_attribute_destroy(style);
        return;
    }
    
    pango_attribute_destroy(style);
    
    #undef FONT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_rise_new
 * Params: int rise
 * Returns: the new PangoAttribute.
 * Assertion: Create a new baseline displacement attribute.
 * Params Values: 10 
 * Expected: a new baseline displacement attribute with vertically displacement 10
 *   
 */
static void test_purpose_18()
{
    #define FONT_RISE 10
    
    PangoAttribute *rise;
    PangoAttrInt *riseInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new baseline attribute.*/
    rise = pango_attr_rise_new(FONT_RISE);
    riseInt = (PangoAttrInt *)rise;
    
    /*Verify the vertically displacement value of the attribute.*/
    if (riseInt->value != FONT_RISE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    pango_attribute_destroy(rise);
        return;
    }
    
    pango_attribute_destroy(rise);
    
    #undef FONT_RISE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_rise_new
 * Params: int rise
 * Returns: the new PangoAttribute.
 * Assertion: Create a new baseline displacement attribute.
 * Params Values: -10 
 * Expected: a new baseline displacement attribute with vertically displacement -10
 *   
 */
static void test_purpose_19()
{
    #define FONT_RISE -10
    
    PangoAttribute *rise;
    PangoAttrInt *riseInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new baseline attribute.*/
    rise = pango_attr_rise_new(FONT_RISE);
    riseInt = (PangoAttrInt *)rise;
    
    /*Verify the vertically displacement value of the attribute.*/
    if (riseInt->value != FONT_RISE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    pango_attribute_destroy(rise);
        return;
    }
    
    pango_attribute_destroy(rise);
    
    #undef FONT_RISE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_rise_new
 * Params: int rise
 * Returns: the new PangoAttribute.
 * Assertion: Create a new baseline displacement attribute.
 * Params Values: 0 
 * Expected: a new baseline displacement attribute with vertically displacement 0
 *   
 */
static void test_purpose_20()
{
    #define FONT_RISE 0
    
    PangoAttribute *rise;
    PangoAttrInt *riseInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new baseline attribute.*/
    rise = pango_attr_rise_new(FONT_RISE);
    riseInt = (PangoAttrInt *)rise;
    
    /*Verify the vertically displacement value of the attribute.*/
    if (riseInt->value != FONT_RISE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    pango_attribute_destroy(rise);
        return;
    }
    
    pango_attribute_destroy(rise);
    
    #undef FONT_RISE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_change
 * Params: PangoAttrList *list, PangoAttribute *attr
 * Returns: void
 * Assertion: Insert the given attribute into the PangoAttrList. 
 * It will replace any attributes of the same type on that segment and be merged with any adjoining attributes that are identical. 
 * Params Values: 
 * Expected: 
 *   
 */
static void test_purpose_21()
{
    #define ATTR_LIST attrs
    #define ATTR weight 
    
    PangoAttrList *attrs;
    PangoAttribute *weight;
    PangoAttrIterator *iterator;
    PangoAttrInt *tmp_attr;
    PangoAttribute *tmp;
    gboolean iter_next = TRUE;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create a new attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_NORMAL);
    weight->start_index = 0;
    weight->end_index = G_MAXINT;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(ATTR_LIST,ATTR);
    
    /*Another attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_BOLD);
    weight->start_index = 3;
    weight->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(ATTR_LIST,ATTR);
    
    /*Another attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_HEAVY);
    weight->start_index = 5;
    weight->end_index = 6;
    
    /*Insert the attribute via pango_attr_list_change().*/
    pango_attr_list_change(ATTR_LIST,ATTR);
    
    iterator = pango_attr_list_get_iterator(attrs);
    
    /*Iterator to range 5~6.*/
    iter_next = pango_attr_iterator_next(iterator);
    iter_next = pango_attr_iterator_next(iterator);
    
    tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
    
    if (tmp_attr->value != PANGO_WEIGHT_HEAVY)
    {
    /*    g_printf("pango_attr_list_change() test fail!\n");*/
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*
    for (;iter_next;)
    {
        tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
        tmp = (PangoAttribute *)tmp_attr;
    
        g_printf("Start index of the attribute is %d,end index is %d.\n",tmp->start_index,tmp->end_index);
    
        g_printf("The value of the attribute is %d.\n",tmp_attr->value);
        iter_next = pango_attr_iterator_next(iterator);
    }
    */
    
    pango_attr_iterator_destroy(iterator);
    pango_attr_list_unref(attrs);
    
    #undef ATTR_LIST
    #undef ATTR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_iterator_range
 * Params: PangoAttrIterator *iterator, gint *start, gint *end
 * Returns: void
 * Assertion: Get the range of the current segment.
 * Params Values: iterator,start,end
 * Expected: start of iterator is 0,end of iterator is min(6 ,8 )
 *   
 */
static void test_purpose_22()
{
    #define START 6 
    #define END 8 
    
    PangoAttrList *attrs;
    PangoAttribute *underline;
    GSList *run_attrs;
    PangoAttrInt *tmp_attr;
    PangoAttrIterator *iterator;
    gint *start,*end;
    gint iter_end;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    start = g_new(gint,1);
    end = g_new(gint,1);
    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create attributes and insert them into the new attr list.*/
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = 0;
    underline->end_index = START;
    pango_attr_list_insert (attrs, underline);
    
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = END;
    underline->end_index = G_MAXINT;
    pango_attr_list_insert (attrs, underline);
    
    /*The start index of the iterator is SATART, and if the attr list is not empty,the end index of the last iterator is G_MAXINT.*/
    iterator = pango_attr_list_get_iterator (attrs);
    
    /*Get the range of current iterator.*/
    pango_attr_iterator_range (iterator,start,end);
    /*g_printf("Start of iterator is %d ,end of iteratot is %d .\n",*start,*end);*/
    
    /*Get the end of the first iterator.*/
    iter_end = (END > START)? START : END;
    
    /*Check the range of the iterator.*/
    if (*end != iter_end)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_iterator_destroy(iterator);
    pango_attr_list_unref(attrs);
    g_free(start);
    g_free(end);
    
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_iterator_range
 * Params: PangoAttrIterator *iterator, gint *start, gint *end
 * Returns: void
 * Assertion: Get the range of the current segment.
 * Params Values: iterator,start,end
 * Expected: start of iterator is 0,end of iterator is min(12 ,15 )
 *   
 */
static void test_purpose_23()
{
    #define START 12 
    #define END 15 
    
    PangoAttrList *attrs;
    PangoAttribute *underline;
    GSList *run_attrs;
    PangoAttrInt *tmp_attr;
    PangoAttrIterator *iterator;
    gint *start,*end;
    gint iter_end;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    start = g_new(gint,1);
    end = g_new(gint,1);
    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create attributes and insert them into the new attr list.*/
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = 0;
    underline->end_index = START;
    pango_attr_list_insert (attrs, underline);
    
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = END;
    underline->end_index = G_MAXINT;
    pango_attr_list_insert (attrs, underline);
    
    /*The start index of the iterator is SATART, and if the attr list is not empty,the end index of the last iterator is G_MAXINT.*/
    iterator = pango_attr_list_get_iterator (attrs);
    
    /*Get the range of current iterator.*/
    pango_attr_iterator_range (iterator,start,end);
    /*g_printf("Start of iterator is %d ,end of iteratot is %d .\n",*start,*end);*/
    
    /*Get the end of the first iterator.*/
    iter_end = (END > START)? START : END;
    
    /*Check the range of the iterator.*/
    if (*end != iter_end)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_iterator_destroy(iterator);
    pango_attr_list_unref(attrs);
    g_free(start);
    g_free(end);
    
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_iterator_range
 * Params: PangoAttrIterator *iterator, gint *start, gint *end
 * Returns: void
 * Assertion: Get the range of the current segment.
 * Params Values: iterator,start,end
 * Expected: start of iterator is 0,end of iterator is min(15 ,12 )
 *   
 */
static void test_purpose_24()
{
    #define START 15 
    #define END 12 
    
    PangoAttrList *attrs;
    PangoAttribute *underline;
    GSList *run_attrs;
    PangoAttrInt *tmp_attr;
    PangoAttrIterator *iterator;
    gint *start,*end;
    gint iter_end;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    start = g_new(gint,1);
    end = g_new(gint,1);
    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create attributes and insert them into the new attr list.*/
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = 0;
    underline->end_index = START;
    pango_attr_list_insert (attrs, underline);
    
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = END;
    underline->end_index = G_MAXINT;
    pango_attr_list_insert (attrs, underline);
    
    /*The start index of the iterator is SATART, and if the attr list is not empty,the end index of the last iterator is G_MAXINT.*/
    iterator = pango_attr_list_get_iterator (attrs);
    
    /*Get the range of current iterator.*/
    pango_attr_iterator_range (iterator,start,end);
    /*g_printf("Start of iterator is %d ,end of iteratot is %d .\n",*start,*end);*/
    
    /*Get the end of the first iterator.*/
    iter_end = (END > START)? START : END;
    
    /*Check the range of the iterator.*/
    if (*end != iter_end)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_iterator_destroy(iterator);
    pango_attr_list_unref(attrs);
    g_free(start);
    g_free(end);
    
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_iterator_next
 * Params: PangoAttrIterator *iterator
 * Returns: FALSE if the iterator is at the end of the list, otherwise TRUE
 * Assertion: Advance the iterator until the next change of style.
 * Params Values: iterator 
 * Expected: next iterator of attr list
 *   
 */
static void test_purpose_25()
{
    #define ITERATOR iterator
    
    PangoAttrList *attrs;
    PangoAttribute *underline;
    PangoAttrIterator *iterator;
    PangoAttribute *weight;
    gboolean iter_next;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create attributes and insert them into the attr list.*/
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = 0;
    underline->end_index = 6;
    pango_attr_list_insert (attrs, underline);
    
    
    weight = pango_attr_weight_new (PANGO_WEIGHT_NORMAL);
    weight->start_index = 6;
    weight->end_index = G_MAXINT;
    pango_attr_list_insert (attrs,weight);
    
    /*The start index of the iterator is 0, and if the attr list is not empty,the end index of the last iterator is G_MAXINT.*/
    iterator = pango_attr_list_get_iterator (attrs);
    
    /*Get next iterator of attr list.*/
    iter_next = pango_attr_iterator_next (ITERATOR);
    
    /* Current position is not the end of attr list.The value returned is TURE.*/
    if (!iter_next)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    iter_next = pango_attr_iterator_next (ITERATOR);
    
    /* Current position is not the end of attr list.The value returned is TURE.*/
    if (!iter_next)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    iter_next = pango_attr_iterator_next (ITERATOR);
    
    /* Current position is at the end of attr list.The value returned is FALSE.*/
    if (iter_next)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_list_unref(attrs);
    pango_attr_iterator_destroy(iterator);
    
    #undef ITERATOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_underline_new
 * Params: PangoUnderline underline
 * Returns: the new PangoAttribute.
 * Assertion: Create a new underline-style object.
 * Params Values: PANGO_UNDERLINE_NONE 
 * Expected: a new underline-style object with style PANGO_UNDERLINE_NONE 
 *   
 */
static void test_purpose_26()
{
    #define FONT_UNDERLINE PANGO_UNDERLINE_NONE 
    
    PangoAttribute *underline;
    PangoAttrInt *underlineInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new underlien attribute.*/
    underline = pango_attr_underline_new(FONT_UNDERLINE);
    underlineInt = (PangoAttrInt *)underline;
    
    /*Verify the underline style of the new created attribute.*/
    if (underlineInt->value != FONT_UNDERLINE)
    {
            TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(underline);
    
    #undef FONT_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_underline_new
 * Params: PangoUnderline underline
 * Returns: the new PangoAttribute.
 * Assertion: Create a new underline-style object.
 * Params Values: PANGO_UNDERLINE_SINGLE 
 * Expected: a new underline-style object with style PANGO_UNDERLINE_SINGLE 
 *   
 */
static void test_purpose_27()
{
    #define FONT_UNDERLINE PANGO_UNDERLINE_SINGLE 
    
    PangoAttribute *underline;
    PangoAttrInt *underlineInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new underlien attribute.*/
    underline = pango_attr_underline_new(FONT_UNDERLINE);
    underlineInt = (PangoAttrInt *)underline;
    
    /*Verify the underline style of the new created attribute.*/
    if (underlineInt->value != FONT_UNDERLINE)
    {
            TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(underline);
    
    #undef FONT_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_underline_new
 * Params: PangoUnderline underline
 * Returns: the new PangoAttribute.
 * Assertion: Create a new underline-style object.
 * Params Values: PANGO_UNDERLINE_ERROR 
 * Expected: a new underline-style object with style PANGO_UNDERLINE_ERROR 
 *   
 */
static void test_purpose_28()
{
    #define FONT_UNDERLINE PANGO_UNDERLINE_ERROR 
    
    PangoAttribute *underline;
    PangoAttrInt *underlineInt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new underlien attribute.*/
    underline = pango_attr_underline_new(FONT_UNDERLINE);
    underlineInt = (PangoAttrInt *)underline;
    
    /*Verify the underline style of the new created attribute.*/
    if (underlineInt->value != FONT_UNDERLINE)
    {
            TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(underline);
    
    #undef FONT_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_size_new
 * Params: int size
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font-size attribute in fractional points.
 * Params Values: 10 
 * Expected: new font size attribute with 10/PANGO_SCALEth of a point
 *   
 */
static void test_purpose_29()
{
    #define FONT_SIZE 10
    
    PangoAttribute *size;
    PangoAttrSize *size_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font-size attribute with size FONT_SIZE.*/
    size = pango_attr_size_new(FONT_SIZE);
    size_attr = (PangoAttrSize *)size;
    
    /*Verify the font size of the new created attribute.*/
    if (size_attr->size != FONT_SIZE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(size);
    
    #undef FONT_SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_size_new
 * Params: int size
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font-size attribute in fractional points.
 * Params Values: 1000 
 * Expected: new font size attribute with 1000/PANGO_SCALEth of a point
 *   
 */
static void test_purpose_30()
{
    #define FONT_SIZE 1000
    
    PangoAttribute *size;
    PangoAttrSize *size_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font-size attribute with size FONT_SIZE.*/
    size = pango_attr_size_new(FONT_SIZE);
    size_attr = (PangoAttrSize *)size;
    
    /*Verify the font size of the new created attribute.*/
    if (size_attr->size != FONT_SIZE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(size);
    
    #undef FONT_SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_size_new
 * Params: int size
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font-size attribute in fractional points.
 * Params Values: 10000 
 * Expected: new font size attribute with 10000/PANGO_SCALEth of a point
 *   
 */
static void test_purpose_31()
{
    #define FONT_SIZE 10000
    
    PangoAttribute *size;
    PangoAttrSize *size_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font-size attribute with size FONT_SIZE.*/
    size = pango_attr_size_new(FONT_SIZE);
    size_attr = (PangoAttrSize *)size;
    
    /*Verify the font size of the new created attribute.*/
    if (size_attr->size != FONT_SIZE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(size);
    
    #undef FONT_SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_splice
 * Params: PangoAttrList *list,PangoAttrList *other, gint pos, gint len
 * Returns: void
 * Assertion: This function splices attribute list other into list. This operation is equivalent to stretching every attribute that applies at position pos in list by an amount len, and then calling pango_attr_list_change() with a copy of each attribute in other in sequence (offset in position by pos). This operation proves useful for, for instance, inserting a preedit string in the middle of an edit buffer.
 * Params Values: 
 * Expected: 
 *   
 */
static void test_purpose_32()
{
    
    gboolean func;
    PangoAttrIterator *iterator;
    gboolean iter_next = TRUE;
    PangoAttribute *tmp;
    PangoAttrInt *tmp_attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create two attr lists.*/
    PangoAttrList *al = pango_attr_list_new ();
    PangoAttrList *al2 = pango_attr_list_new ();
    
    /*Insert attributes into the attr list.*/
    pango_attr_list_insert (al, at (6, 9, pango_attr_weight_new (700)));
    pango_attr_list_insert (al, at (8, 9, pango_attr_weight_new (400)));
    
    g_print ("Original list: ");
    gnm_pango_attr_dump (al);
    
    pango_attr_list_insert (al2, at (0, 1, pango_attr_weight_new (900)));
    g_print ("Other list: ");
    gnm_pango_attr_dump (al2);
    
    pango_attr_list_splice (al, al2, 8, 1);
    g_print ("After splice: ");
    
    /*iterator = pango_attr_list_get_iterator (al);
    iter_next = pango_attr_iterator_next(iterator);
    for (;iter_next;)
    {
        tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
        tmp = (PangoAttribute *)tmp_attr;
    
        g_printf("Start index of the attribute is %d,end index is %d.\n",tmp->start_index,tmp->end_index);
    
        g_printf("The value of the attribute is %d.\n",tmp_attr->value);
        iter_next = pango_attr_iterator_next(iterator);
    }
    */
    gnm_pango_attr_dump (al);
    
    pango_attr_list_change (al, at (8, 9, pango_attr_weight_new (700)));
    g_print ("After change: ");
    gnm_pango_attr_dump (al);
    
    
    pango_attr_list_unref(al);
    pango_attr_list_unref(al2);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_ref
 * Params: PangoAttrList *list
 * Returns: void
 * Assertion: Increase the reference count of the given attribute list by one.
 * Params Values: attrs 
 * Expected: increase the reference count number of attrs by 1
 *   
 */
static void test_purpose_33()
{
    #define ATTRS attrs
    
    PangoAttrList *attrs;
    guint ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new();
    /*ref_num = attrs->ref_count;*/
    /*g_printf("The reference number of the created attrs is %u.\n",ref_num);*/
    
    /*Increase the reference count number by 1.*/
    pango_attr_list_ref(ATTRS);
    ref_num = attrs->ref_count;
    /*g_printf("After ref the reference number of the attrs is %u.\n",ref_num);*/
    
    /*Decrease the refernce count number by 1.*/
    pango_attr_list_unref(attrs);
    
    /*Verify the reference number is increased and decreased correctly.*/
    if (ref_num != attrs->ref_count +1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*ref_num = attrs->ref_count;*/
    /*g_printf("After unref the reference number of the attrs is %u.\n",ref_num);*/
    
    pango_attr_list_unref(attrs);
    
    #undef ATTRS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_filter
 * Params: PangoAttrList *list, PangoAttrFilterFunc func, gpointer data
 * Returns: a newly allocated PangoAttrList or NULL if no attributes of the given types were found.
 * Assertion: Given a PangoAttrList and callback function, removes any elements of list for which func returns TRUE and inserts them into a new list.
 * Params Values: attrs,filter_func,NULL
 * Expected: removes weight attributes in attrs use filter function filter_func,store the removed attributes in a new attr list attrs_new
 *   
 */
static void test_purpose_34()
{
    #define ATTR_LIST attrs
    #define FILTER_FUNC filter_func
    #define DATA NULL
    
    PangoAttrList *attrs;
    PangoAttribute *weight;
    PangoAttribute *underline;
    PangoAttrIterator *iterator;
    PangoAttrInt *tmp_attr;
    PangoAttribute *tmp;
    gboolean iter_next = TRUE;
    PangoAttrList *attrs_new;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create a new attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_NORMAL);
    weight->start_index = 0;
    weight->end_index = G_MAXINT;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(attrs,weight);
    
    /*Another attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_BOLD);
    weight->start_index = 3;
    weight->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(attrs,weight);
    
    /*Another attribute to be inserted into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_HEAVY);
    weight->start_index = 5;
    weight->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(attrs,weight);
    
    /*Create an underline attribute to be inserted into the attr list,the underline attribute can't be filtered out by the filter function.*/
    underline = pango_attr_underline_new(PANGO_UNDERLINE_LOW);
    underline->start_index = 5;
    underline->end_index = 6;
    
    /*Insert the attribute into the attr list.*/
    pango_attr_list_insert(attrs,underline);
    
    /*Filter out weight attribute from the attr list,store the filtered attrs in the new attr list.*/
    attrs_new = pango_attr_list_filter(ATTR_LIST,FILTER_FUNC,DATA);
    
    iterator = pango_attr_list_get_iterator(attrs);
    
    /*Iterator to range 5~6,where the underline attribute is located.*/
    iter_next = pango_attr_iterator_next(iterator);
    
    tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_UNDERLINE);
    
    if (tmp_attr->value != PANGO_UNDERLINE_LOW)
    {
    /*    g_printf("pango_attr_list_change() test fail!\n");*/
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*Check whether the new attributes in the new attr list is correct.*/
    iterator = pango_attr_list_get_iterator(attrs_new);
    
    /*Iterator to range 5~6.*/
    iter_next = pango_attr_iterator_next(iterator);
    iter_next = pango_attr_iterator_next(iterator);
    
    tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
    
    if (tmp_attr->value != PANGO_WEIGHT_HEAVY)
    {
    /*    g_printf("pango_attr_list_change() test fail!\n");*/
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*
    for (;iter_next;)
    {
        tmp_attr = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
        tmp = (PangoAttribute *)tmp_attr;
    
        g_printf("Start index of the attribute is %d,end index is %d.\n",tmp->start_index,tmp->end_index);
    
        g_printf("The value of the attribute is %d.\n",tmp_attr->value);
        iter_next = pango_attr_iterator_next(iterator);
    }
    */
    
    pango_attr_list_unref(attrs);
    
    #undef ATTR_LIST
    #undef FILTER_FUNC
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_list_copy
 * Params: PangoAttrList *list
 * Returns: new attribute list.
 * Assertion: Copy list and return an identical, new list.
 * Params Values: attrs 
 * Expected: an identical attr list as attrs
 *   
 */
static void test_purpose_35()
{
    #define ATTR_LIST attrs
    
    PangoAttrList *attrs;
    PangoAttrList *attrs_cp;
    PangoAttribute *weight;
    PangoAttribute *weight_cp;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new();
    
    /*Create a new attribute and insert it into the attr list.*/
    weight = pango_attr_weight_new(PANGO_WEIGHT_BOLD);
    weight->start_index = 0;
    weight->end_index = 6;
    pango_attr_list_insert(attrs, weight);
    
    /*Make a copy of the attr list.*/
    attrs_cp = pango_attr_list_copy(ATTR_LIST);
    
    /* Compare whether the value is copied correctly.*/
    if (attrs_cp->ref_count != attrs->ref_count)
    {
        TEST_FAIL("List was not copied correctly!\n",NULL);
    }
    
    weight_cp = attrs_cp->attributes->data;
    if (!struc_cmp((char *)weight,(char *)weight_cp,sizeof(PangoAttribute)))
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attr_list_unref(attrs);
    pango_attr_list_unref(attrs_cp);
     
    #undef ATTR_LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attribute_copy
 * Params: const PangoAttribute *attr
 * Returns: a newly allocated PangoAttribute.  
 * Assertion: Make a copy of an attribute.
 * Params Values: underline
 * Expected: a copy of underline
 *   
 */
static void test_purpose_36()
{
    #define ATTR underline
    #define FONT_UNDERLINE PANGO_UNDERLINE_LOW
    
    PangoAttribute *underline;
    PangoAttrInt *underlineInt;
    PangoAttribute *underline_cp;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new underline attribute.*/
    underline = pango_attr_underline_new(FONT_UNDERLINE);
    
    /*Make a copy of the attribute.*/
    underline_cp = pango_attribute_copy(ATTR);
    underlineInt = (PangoAttrInt *)underline_cp;
    
    /*Verify that the copy is the same as the original.*/
    if (!struc_cmp((char *)underline_cp,(char *)ATTR,sizeof(PangoAttribute)))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    pango_attribute_destroy(underline);
    pango_attribute_destroy(underline_cp);
    
    #undef ATTR
    #undef FONT_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attribute_copy
 * Params: const PangoAttribute *attr
 * Returns: a newly allocated PangoAttribute.  
 * Assertion: Make a copy of an attribute.
 * Params Values: underline
 * Expected: a copy of underline
 *   
 */
static void test_purpose_37()
{
    #define ATTR underline
    #define FONT_UNDERLINE PANGO_UNDERLINE_SINGLE
    
    PangoAttribute *underline;
    PangoAttrInt *underlineInt;
    PangoAttribute *underline_cp;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new underline attribute.*/
    underline = pango_attr_underline_new(FONT_UNDERLINE);
    
    /*Make a copy of the attribute.*/
    underline_cp = pango_attribute_copy(ATTR);
    underlineInt = (PangoAttrInt *)underline_cp;
    
    /*Verify that the copy is the same as the original.*/
    if (!struc_cmp((char *)underline_cp,(char *)ATTR,sizeof(PangoAttribute)))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    pango_attribute_destroy(underline);
    pango_attribute_destroy(underline_cp);
    
    #undef ATTR
    #undef FONT_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_font_desc_new
 * Params: const PangoFontDescription *desc
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font description attribute. (This attribute allows setting family, style, weight, variant, stretch, and size simultaneously.)
 * Params Values: font_desc,PANGO_WEIGHT_LIGHT
 * Expected: a new font description attribute,with weight PANGO_WEIGHT_LIGHT
 *   
 */
static void test_purpose_38()
{
    #define FONT_DESC font_desc
    #define WEIGHT PANGO_WEIGHT_LIGHT
    
    PangoFontDescription *font_desc;
    PangoAttribute *desc;
    PangoAttrFontDesc *descInt;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font description.*/
    font_desc = pango_font_description_new();
    
    /*Change weight of the font description.*/
    pango_font_description_set_weight(font_desc,WEIGHT);
    
    /*Create a new description attribute from the font description.*/
    desc = pango_attr_font_desc_new(FONT_DESC);
    descInt = (PangoAttrFontDesc *)desc;
    
    /*Check whether the description of the description attribute is font_desc.*/
    rlt = pango_font_description_equal(descInt->desc,font_desc);
    if (!rlt)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    pango_attribute_destroy(desc);
    
    #undef WEIGHT
    #undef FONT_DESC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_font_desc_new
 * Params: const PangoFontDescription *desc
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font description attribute. (This attribute allows setting family, style, weight, variant, stretch, and size simultaneously.)
 * Params Values: font_desc,PANGO_WEIGHT_BOLD
 * Expected: a new font description attribute,with weight PANGO_WEIGHT_BOLD
 *   
 */
static void test_purpose_39()
{
    #define FONT_DESC font_desc
    #define WEIGHT PANGO_WEIGHT_BOLD
    
    PangoFontDescription *font_desc;
    PangoAttribute *desc;
    PangoAttrFontDesc *descInt;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font description.*/
    font_desc = pango_font_description_new();
    
    /*Change weight of the font description.*/
    pango_font_description_set_weight(font_desc,WEIGHT);
    
    /*Create a new description attribute from the font description.*/
    desc = pango_attr_font_desc_new(FONT_DESC);
    descInt = (PangoAttrFontDesc *)desc;
    
    /*Check whether the description of the description attribute is font_desc.*/
    rlt = pango_font_description_equal(descInt->desc,font_desc);
    if (!rlt)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    pango_attribute_destroy(desc);
    
    #undef WEIGHT
    #undef FONT_DESC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_font_desc_new
 * Params: const PangoFontDescription *desc
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font description attribute. (This attribute allows setting family, style, weight, variant, stretch, and size simultaneously.)
 * Params Values: font_desc,PANGO_WEIGHT_HEAVY
 * Expected: a new font description attribute,with weight PANGO_WEIGHT_HEAVY
 *   
 */
static void test_purpose_40()
{
    #define FONT_DESC font_desc
    #define WEIGHT PANGO_WEIGHT_HEAVY
    
    PangoFontDescription *font_desc;
    PangoAttribute *desc;
    PangoAttrFontDesc *descInt;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font description.*/
    font_desc = pango_font_description_new();
    
    /*Change weight of the font description.*/
    pango_font_description_set_weight(font_desc,WEIGHT);
    
    /*Create a new description attribute from the font description.*/
    desc = pango_attr_font_desc_new(FONT_DESC);
    descInt = (PangoAttrFontDesc *)desc;
    
    /*Check whether the description of the description attribute is font_desc.*/
    rlt = pango_font_description_equal(descInt->desc,font_desc);
    if (!rlt)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_font_description_free(font_desc);
    pango_attribute_destroy(desc);
    
    #undef WEIGHT
    #undef FONT_DESC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_family_new
 * Params: const char *family
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font family attribute.
 * Params Values: my_str 
 * Expected: a new font family
 *   
 */
static void test_purpose_41()
{
    #define FAMILY my_str 
    
    PangoAttribute *family;
    PangoAttrString *family_str;
    const char *my_str = "string family";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font family attribute.*/
    family = pango_attr_family_new(FAMILY);
    family_str = (PangoAttrString *)family;
    
    /*Verify that the font family is correct.*/
    if (strcmp(family_str->value,FAMILY))
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(family);
    
    #undef FAMILY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_family_new
 * Params: const char *family
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font family attribute.
 * Params Values: "family string" 
 * Expected: a new font family
 *   
 */
static void test_purpose_42()
{
    #define FAMILY "family string" 
    
    PangoAttribute *family;
    PangoAttrString *family_str;
    const char *my_str = "string family";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font family attribute.*/
    family = pango_attr_family_new(FAMILY);
    family_str = (PangoAttrString *)family;
    
    /*Verify that the font family is correct.*/
    if (strcmp(family_str->value,FAMILY))
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(family);
    
    #undef FAMILY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_family_new
 * Params: const char *family
 * Returns: the new PangoAttribute.
 * Assertion: Create a new font family attribute.
 * Params Values: "string1, ,string2" 
 * Expected: a new font family
 *   
 */
static void test_purpose_43()
{
    #define FAMILY "string1, ,string2" 
    
    PangoAttribute *family;
    PangoAttrString *family_str;
    const char *my_str = "string family";
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new font family attribute.*/
    family = pango_attr_family_new(FAMILY);
    family_str = (PangoAttrString *)family;
    
    /*Verify that the font family is correct.*/
    if (strcmp(family_str->value,FAMILY))
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(family);
    
    #undef FAMILY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_background_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute. 
 * Assertion: Create a new background color attribute.
 * Params Values: 0,0,0 
 * Expected: a new background color attribute with R:0 G:0 B:0
 *   
 */
static void test_purpose_44()
{
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    
    PangoAttribute *backgrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new background colore attribute.*/
    backgrd_color = pango_attr_background_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)backgrd_color;
    
    /*Verify that the color of the attribute is correct.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(backgrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_background_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute. 
 * Assertion: Create a new background color attribute.
 * Params Values: 255,255,65535 
 * Expected: a new background color attribute with R:255 G:255 B:65535
 *   
 */
static void test_purpose_45()
{
    #define RED 255
    #define GREEN 255
    #define BLUE 65535
    
    PangoAttribute *backgrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new background colore attribute.*/
    backgrd_color = pango_attr_background_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)backgrd_color;
    
    /*Verify that the color of the attribute is correct.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(backgrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_background_new
 * Params: guint16 red, guint16 green, guint16 blue
 * Returns: the new PangoAttribute. 
 * Assertion: Create a new background color attribute.
 * Params Values: 65535,65535,65535 
 * Expected: a new background color attribute with R:65535 G:65535 B:65535
 *   
 */
static void test_purpose_46()
{
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    
    PangoAttribute *backgrd_color;
    PangoAttrColor *color_attr;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new background colore attribute.*/
    backgrd_color = pango_attr_background_new(RED,GREEN,BLUE);
    color_attr = (PangoAttrColor *)backgrd_color;
    
    /*Verify that the color of the attribute is correct.*/
    if (color_attr->color.red != RED || color_attr->color.green != GREEN ||color_attr->color.blue != BLUE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(backgrd_color);
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_shape_new
 * Params: const PangoRectangle *ink_rect, const PangoRectangle *logical_rect
 * Returns: the newly created attribute.
 * Assertion: Create a new shape attribute. A shape is used to impose a particular ink and logical rect on the result of shaping a particular glyph. This might be used, for instance, for embedding a picture or a widget inside a PangoLayout.
 * Params Values: &ink_rect,&logical_rect 
 * Expected: a new shape attribute with ink and logical rectangle X:0 Y:0 WIDTH:10 HEIGHT:10
 *   
 */
static void test_purpose_47()
{
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    
    PangoAttribute *shape_new;
    PangoAttrShape *shape_attr;
    PangoRectangle ink_rect;
    PangoRectangle logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Set the value of ink rectangle.*/
    ink_rect.x = X;
    ink_rect.y = Y;
    ink_rect.width = WIDTH;
    ink_rect.height = HEIGHT;
    
    /*Set the value of the logical rectangle.*/
    logical_rect.x = X;
    logical_rect.y = Y;
    logical_rect.width = WIDTH;
    logical_rect.height = HEIGHT;
    
    /*Create new shape attribute from the ink and logical rectangle previously set.*/
    shape_new = pango_attr_shape_new(&ink_rect,&logical_rect);
    shape_attr = (PangoAttrShape *)shape_new;
    
    /*Verify that the ink and logical rectangle value is correct.*/
    if (shape_attr->ink_rect.x != ink_rect.x || shape_attr->ink_rect.y != ink_rect.y || shape_attr->ink_rect.width != ink_rect.width || shape_attr->ink_rect.height != ink_rect.height || shape_attr->logical_rect.width != logical_rect.width || shape_attr->logical_rect.x != logical_rect.x || shape_attr->logical_rect.y != logical_rect.y || shape_attr->logical_rect.height != logical_rect.height)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(shape_new);
    
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_shape_new
 * Params: const PangoRectangle *ink_rect, const PangoRectangle *logical_rect
 * Returns: the newly created attribute.
 * Assertion: Create a new shape attribute. A shape is used to impose a particular ink and logical rect on the result of shaping a particular glyph. This might be used, for instance, for embedding a picture or a widget inside a PangoLayout.
 * Params Values: &ink_rect,&logical_rect 
 * Expected: a new shape attribute with ink and logical rectangle X:20 Y:20 WIDTH:30 HEIGHT:50
 *   
 */
static void test_purpose_48()
{
    #define X 20
    #define Y 20
    #define WIDTH 30
    #define HEIGHT 50
    
    PangoAttribute *shape_new;
    PangoAttrShape *shape_attr;
    PangoRectangle ink_rect;
    PangoRectangle logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Set the value of ink rectangle.*/
    ink_rect.x = X;
    ink_rect.y = Y;
    ink_rect.width = WIDTH;
    ink_rect.height = HEIGHT;
    
    /*Set the value of the logical rectangle.*/
    logical_rect.x = X;
    logical_rect.y = Y;
    logical_rect.width = WIDTH;
    logical_rect.height = HEIGHT;
    
    /*Create new shape attribute from the ink and logical rectangle previously set.*/
    shape_new = pango_attr_shape_new(&ink_rect,&logical_rect);
    shape_attr = (PangoAttrShape *)shape_new;
    
    /*Verify that the ink and logical rectangle value is correct.*/
    if (shape_attr->ink_rect.x != ink_rect.x || shape_attr->ink_rect.y != ink_rect.y || shape_attr->ink_rect.width != ink_rect.width || shape_attr->ink_rect.height != ink_rect.height || shape_attr->logical_rect.width != logical_rect.width || shape_attr->logical_rect.x != logical_rect.x || shape_attr->logical_rect.y != logical_rect.y || shape_attr->logical_rect.height != logical_rect.height)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(shape_new);
    
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_shape_new
 * Params: const PangoRectangle *ink_rect, const PangoRectangle *logical_rect
 * Returns: the newly created attribute.
 * Assertion: Create a new shape attribute. A shape is used to impose a particular ink and logical rect on the result of shaping a particular glyph. This might be used, for instance, for embedding a picture or a widget inside a PangoLayout.
 * Params Values: &ink_rect,&logical_rect 
 * Expected: a new shape attribute with ink and logical rectangle X:100 Y:50 WIDTH:50 HEIGHT:50
 *   
 */
static void test_purpose_49()
{
    #define X 100
    #define Y 50
    #define WIDTH 50
    #define HEIGHT 50
    
    PangoAttribute *shape_new;
    PangoAttrShape *shape_attr;
    PangoRectangle ink_rect;
    PangoRectangle logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Set the value of ink rectangle.*/
    ink_rect.x = X;
    ink_rect.y = Y;
    ink_rect.width = WIDTH;
    ink_rect.height = HEIGHT;
    
    /*Set the value of the logical rectangle.*/
    logical_rect.x = X;
    logical_rect.y = Y;
    logical_rect.width = WIDTH;
    logical_rect.height = HEIGHT;
    
    /*Create new shape attribute from the ink and logical rectangle previously set.*/
    shape_new = pango_attr_shape_new(&ink_rect,&logical_rect);
    shape_attr = (PangoAttrShape *)shape_new;
    
    /*Verify that the ink and logical rectangle value is correct.*/
    if (shape_attr->ink_rect.x != ink_rect.x || shape_attr->ink_rect.y != ink_rect.y || shape_attr->ink_rect.width != ink_rect.width || shape_attr->ink_rect.height != ink_rect.height || shape_attr->logical_rect.width != logical_rect.width || shape_attr->logical_rect.x != logical_rect.x || shape_attr->logical_rect.y != logical_rect.y || shape_attr->logical_rect.height != logical_rect.height)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    pango_attribute_destroy(shape_new);
    
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_attr_iterator_get
 * Params: PangoAttrIterator *iterator, PangoAttrType type
 * Returns: the current attribute of the given type, or NULL if no attribute of that type applies to the current location.
 * Assertion: Find the current attribute of a particular type at the iterator location. When multiple attributes of the same type overlap, the attribute whose range starts closest to the current location is used.
 * Params Values: iterator,PANGO_ATTR_UNDERLINE 
 * Expected: type PANGO_ATTR_UNDERLINE  attribute at the current iterator location
 *   
 */
static void test_purpose_50()
{
    #define ITERATOR iterator
    #define ATTR PANGO_ATTR_UNDERLINE 
    
    PangoAttrList *attrs;
    PangoAttribute *underline;
    GSList *run_attrs;
    PangoAttrIterator *iterator;
    PangoAttribute *weight;
    PangoAttrInt *tmp;
    /*PangoAttrInt *tmp_int;*/
    gboolean iter_next;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new attr list.*/
    attrs = pango_attr_list_new ();
    
    /*Create a new underline attribute.*/
    underline = pango_attr_underline_new (PANGO_UNDERLINE_LOW);
    underline->start_index = 0;
    underline->end_index = 6;
    
    /*Insert the under attribute into the attr list.*/
    pango_attr_list_insert (attrs, underline);
    
    /*Create a new weight attribute.*/
    weight = pango_attr_weight_new (PANGO_WEIGHT_NORMAL);
    weight->start_index = 0;
    weight->end_index = 3;
    
    /*Insert the weight attribute into the attr list.*/
    pango_attr_list_insert (attrs,weight);
    
    /*The start index of the iterator is 0, and if the attr list is not empty,the end index of the last iterator is G_MAXINT.*/
    iterator = pango_attr_list_get_iterator (attrs);
    
    /*Get the underline attribute of current iterator.*/
    tmp = (PangoAttrInt *)pango_attr_iterator_get(ITERATOR,ATTR);
    /*g_printf("The first underline attribute value of the attr list is %d.\n",tmp->value);*/
    
    /*The value of the underline attribute is PANGO_UNDERLINE_LOW.*/
    if (tmp->value != PANGO_UNDERLINE_LOW)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*Get the weight attribute of current iterator.*/
    tmp = (PangoAttrInt *)pango_attr_iterator_get(iterator,PANGO_ATTR_WEIGHT);
    
    /*The value of weight attribute is PANGO_WEIGHT_NORMAL.*/
    if (tmp->value != PANGO_WEIGHT_NORMAL)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_attr_list_unref(attrs);
    pango_attr_iterator_destroy(iterator);
    
    #undef ITERATOR
    #undef ATTR
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_text ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {NULL,0}
};
