/*
 * GtkNotebook methods tests
 * Testing GtkNotebook methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_notebook_new 
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkNotebook widget with no pages.
 * Params Values: void
 * Expected: GtkNotebook*  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    
    gint page;
    gint page_num;
    GtkPositionType tab_pos;
    guint tab_hborder;
    guint tab_vborder;
    gboolean show_tabs;
    gboolean show_border;
    gboolean scrollable;
    gboolean enable_popup;
    gboolean homogeneous;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != -1)
    {
        TEST_FAIL ("page_num = %d, should be -1", page_num);
    }
    
    g_object_get(GTK_OBJECT(widget), "page", &page, NULL);
    if (page != -1) 
    {
        TEST_FAIL("page = %i, should be -1", page);
    }
    
    g_object_get(GTK_OBJECT(widget), "tab-pos", &tab_pos, NULL);
    if (tab_pos != GTK_POS_TOP) 
    {
        TEST_FAIL("tab_pos fails", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "tab-hborder", &tab_hborder, NULL);
    if (tab_hborder != 2) 
    {
        TEST_FAIL("tab_hborder = %i, should be 2", tab_hborder);
    }
    
    g_object_get(GTK_OBJECT(widget), "tab-vborder", &tab_vborder, NULL);
    if (tab_vborder != 2) 
    {
        TEST_FAIL("tab_vborder = %i, should be 2", tab_vborder);
    }
    
    g_object_get(GTK_OBJECT(widget), "show-tabs", &show_tabs, NULL);
    if (!show_tabs) 
    {
        TEST_FAIL("show_tabs fails", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "show-border", &show_border, NULL);
    if (!show_border) 
    {
        TEST_FAIL("show_border fails", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "scrollable", &scrollable, NULL);
    if (scrollable) 
    {
        TEST_FAIL("scrollable fails", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "enable-popup", &enable_popup, NULL);
    if (enable_popup) 
    {
        TEST_FAIL("enable_popup fails", NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous) 
    {
        TEST_FAIL("homogeneous fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 5
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_2()
{
    #define N_PAGES 5
    #define PAGE_NUM G_MININT
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 10
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_3()
{
    #define N_PAGES 10
    #define PAGE_NUM 0
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 49
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_4()
{
    #define N_PAGES 49
    #define PAGE_NUM 1
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 8
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_5()
{
    #define N_PAGES 8
    #define PAGE_NUM 2
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 100
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_6()
{
    #define N_PAGES 100
    #define PAGE_NUM 101
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 100
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_7()
{
    #define N_PAGES 100
    #define PAGE_NUM -1
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 100
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_8()
{
    #define N_PAGES 100
    #define PAGE_NUM -100
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 100
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_9()
{
    #define N_PAGES 100
    #define PAGE_NUM 100
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_current_page
 * Params: GtkNotebook *notebook,gint page_num
 * Returns: void
 * Assertion: Switches to the page number page_num.
 * Params Values: a newly created GtkNotebook*, 100
 * Expected: void
 * 
 * Name: gtk_notebook_get_current_page
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Returns the page number of the current page.
 * Params Values: a newly created GtkNotebook*
 * Expected: gint  
 */
static void test_purpose_10()
{
    #define N_PAGES 100
    #define PAGE_NUM 49
    
    GtkWidget* widget;
    
    gchar buffer[32];
    gint page_num;
    gint correct_page_num;
    
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), gtk_frame_new (buffer), NULL); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), PAGE_NUM);
    
    correct_page_num = (((PAGE_NUM) >= (N_PAGES)) ? (0) : (((PAGE_NUM) < (0)) ? (N_PAGES - 1) : (PAGE_NUM)));
    
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N_PAGES 
    #undef PAGE_NUM 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_tab_pos
 * Params: GtkNotebook *notebook,GtkPositionType pos
 * Returns: void
 * Assertion: Sets the edge at which the tabs for switching pages in the notebook are drawn.
 * Params Values: a newly created GtkNotebook*, GTK_POS_LEFT 
 * Expected: void  
 */
static void test_purpose_11()
{
    #define TAB_POS GTK_POS_LEFT 
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (widget), TAB_POS);
    g_object_get(GTK_OBJECT(widget), "tab_pos", &tab_pos, NULL);
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d", tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_tab_pos
 * Params: GtkNotebook *notebook,GtkPositionType pos
 * Returns: void
 * Assertion: Sets the edge at which the tabs for switching pages in the notebook are drawn.
 * Params Values: a newly created GtkNotebook*, GTK_POS_RIGHT
 * Expected: void  
 */
static void test_purpose_12()
{
    #define TAB_POS GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (widget), TAB_POS);
    g_object_get(GTK_OBJECT(widget), "tab_pos", &tab_pos, NULL);
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d", tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_tab_pos
 * Params: GtkNotebook *notebook,GtkPositionType pos
 * Returns: void
 * Assertion: Sets the edge at which the tabs for switching pages in the notebook are drawn.
 * Params Values: a newly created GtkNotebook*, GTK_POS_TOP
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TAB_POS GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (widget), TAB_POS);
    g_object_get(GTK_OBJECT(widget), "tab_pos", &tab_pos, NULL);
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d", tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_set_tab_pos
 * Params: GtkNotebook *notebook,GtkPositionType pos
 * Returns: void
 * Assertion: Sets the edge at which the tabs for switching pages in the notebook are drawn.
 * Params Values: a newly created GtkNotebook*, GTK_POS_BOTTOM
 * Expected: void  
 */
static void test_purpose_14()
{
    #define TAB_POS GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (widget), TAB_POS);
    g_object_get(GTK_OBJECT(widget), "tab_pos", &tab_pos, NULL);
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d", tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_get_tab_pos
 * Params: GtkNotebook *notebook
 * Returns: GtkPositionType
 * Assertion: Gets the edge at which the tabs for switching pages in the  notebook are drawn.
 * Params Values: a newly created GtkNotebook*
 * Expected: GtkPositionType  
 */
static void test_purpose_15()
{
    #define TAB_POS GTK_POS_LEFT 
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "tab_pos", TAB_POS,NULL);
    tab_pos = gtk_notebook_get_tab_pos(GTK_NOTEBOOK (widget));
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d",tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_get_tab_pos
 * Params: GtkNotebook *notebook
 * Returns: GtkPositionType
 * Assertion: Gets the edge at which the tabs for switching pages in the  notebook are drawn.
 * Params Values: a newly created GtkNotebook*
 * Expected: GtkPositionType  
 */
static void test_purpose_16()
{
    #define TAB_POS GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "tab_pos", TAB_POS,NULL);
    tab_pos = gtk_notebook_get_tab_pos(GTK_NOTEBOOK (widget));
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d",tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_get_tab_pos
 * Params: GtkNotebook *notebook
 * Returns: GtkPositionType
 * Assertion: Gets the edge at which the tabs for switching pages in the  notebook are drawn.
 * Params Values: a newly created GtkNotebook*
 * Expected: GtkPositionType  
 */
static void test_purpose_17()
{
    #define TAB_POS GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "tab_pos", TAB_POS,NULL);
    tab_pos = gtk_notebook_get_tab_pos(GTK_NOTEBOOK (widget));
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d",tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_notebook_get_tab_pos
 * Params: GtkNotebook *notebook
 * Returns: GtkPositionType
 * Assertion: Gets the edge at which the tabs for switching pages in the  notebook are drawn.
 * Params Values: a newly created GtkNotebook*
 * Expected: GtkPositionType  
 */
static void test_purpose_18()
{
    #define TAB_POS GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType tab_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "tab_pos", TAB_POS,NULL);
    tab_pos = gtk_notebook_get_tab_pos(GTK_NOTEBOOK (widget));
    if (tab_pos != TAB_POS) 
    {
        TEST_FAIL ("tab_pos is %d, should be %d",tab_pos, TAB_POS);
    }
    
    
    #undef TAB_POS 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_show_tabs
 * Params: GtkNotebook *notebook,gboolean show_tabs
 * Returns: void
 * Assertion:Sets whether to show the tabs for the notebook or not.
 * Params Values: a newly created GtkNotebook*, TRUE
 * Expected: void  
 */
static void test_purpose_19()
{
    #define SHOW_TABS TRUE
    
    GtkWidget* widget;
    gboolean show_tabs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (widget), SHOW_TABS);
    g_object_get(GTK_OBJECT(widget), "show_tabs", &show_tabs, NULL);
    if (show_tabs != SHOW_TABS) 
    {
        TEST_FAIL ("show-tabs is %d, should be %d", show_tabs, SHOW_TABS);
    }
    
    
    #undef SHOW_TABS
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_show_tabs
 * Params: GtkNotebook *notebook,gboolean show_tabs
 * Returns: void
 * Assertion:Sets whether to show the tabs for the notebook or not.
 * Params Values: a newly created GtkNotebook*, FALSE
 * Expected: void  
 */
static void test_purpose_20()
{
    #define SHOW_TABS FALSE
    
    GtkWidget* widget;
    gboolean show_tabs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (widget), SHOW_TABS);
    g_object_get(GTK_OBJECT(widget), "show_tabs", &show_tabs, NULL);
    if (show_tabs != SHOW_TABS) 
    {
        TEST_FAIL ("show-tabs is %d, should be %d", show_tabs, SHOW_TABS);
    }
    
    
    #undef SHOW_TABS
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_show_tabs
 * Params: GtkNotebook *notebook
 * Returns: gboolean
 * Assertion: Returns whether the tabs of the notebook are shown.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_21()
{
    #define SHOW_TABS TRUE
    
    GtkWidget* widget;
    gboolean show_tabs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "show_tabs", SHOW_TABS,NULL);
    show_tabs = gtk_notebook_get_show_tabs(GTK_NOTEBOOK (widget));
    if (show_tabs != SHOW_TABS) 
    {
        TEST_FAIL ("show-tabs is %d, should be %d", show_tabs,SHOW_TABS);
    }
    
    
    #undef SHOW_TABS
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_show_tabs
 * Params: GtkNotebook *notebook
 * Returns: gboolean
 * Assertion: Returns whether the tabs of the notebook are shown.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_22()
{
    #define SHOW_TABS FALSE
    
    GtkWidget* widget;
    gboolean show_tabs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "show_tabs", SHOW_TABS,NULL);
    show_tabs = gtk_notebook_get_show_tabs(GTK_NOTEBOOK (widget));
    if (show_tabs != SHOW_TABS) 
    {
        TEST_FAIL ("show-tabs is %d, should be %d", show_tabs,SHOW_TABS);
    }
    
    
    #undef SHOW_TABS
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_show_border
 * Params: GtkNotebook *notebook,gboolean show_border
 * Returns: void
 * Assertion: Sets whether a bevel will be drawn around the notebook pages. 
 * Params Values: a newly created GtkNotebook*, TRUE
 * Expected: void  
 */
static void test_purpose_23()
{
    #define SHOW_BORDER TRUE
    
    GtkWidget* widget;
    gboolean show_border;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_show_border (GTK_NOTEBOOK (widget), SHOW_BORDER);
    g_object_get (GTK_OBJECT(widget), "show_border", &show_border, NULL);
    if (show_border != SHOW_BORDER) 
    {
        TEST_FAIL ("show-border is %d, should be %d", show_border, SHOW_BORDER);
    }
    
    
    #undef SHOW_BORDER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_show_border
 * Params: GtkNotebook *notebook,gboolean show_border
 * Returns: void
 * Assertion: Sets whether a bevel will be drawn around the notebook pages. 
 * Params Values: a newly created GtkNotebook*, FALSE
 * Expected: void  
 */
static void test_purpose_24()
{
    #define SHOW_BORDER FALSE
    
    GtkWidget* widget;
    gboolean show_border;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_show_border (GTK_NOTEBOOK (widget), SHOW_BORDER);
    g_object_get (GTK_OBJECT(widget), "show_border", &show_border, NULL);
    if (show_border != SHOW_BORDER) 
    {
        TEST_FAIL ("show-border is %d, should be %d", show_border, SHOW_BORDER);
    }
    
    
    #undef SHOW_BORDER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_show_border
 * Params: GtkNotebook *notebook
 * Returns: qboolean
 * Assertion: Returns whether a bevel will be drawn around the notebook pages.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_25()
{
    #define SHOW_BORDER TRUE
    
    GtkWidget* widget;
    gboolean show_border;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "show_border", SHOW_BORDER,NULL);
    show_border = gtk_notebook_get_show_border(GTK_NOTEBOOK (widget));
    if (show_border != SHOW_BORDER) 
    {
        TEST_FAIL ("show-border is %d, should be %d", show_border, SHOW_BORDER);
    }
    
    
    #undef SHOW_BORDER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_show_border
 * Params: GtkNotebook *notebook
 * Returns: qboolean
 * Assertion: Returns whether a bevel will be drawn around the notebook pages.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_26()
{
    #define SHOW_BORDER FALSE
    
    GtkWidget* widget;
    gboolean show_border;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "show_border", SHOW_BORDER,NULL);
    show_border = gtk_notebook_get_show_border(GTK_NOTEBOOK (widget));
    if (show_border != SHOW_BORDER) 
    {
        TEST_FAIL ("show-border is %d, should be %d", show_border, SHOW_BORDER);
    }
    
    
    #undef SHOW_BORDER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_scrollable 
 * Params: GtkNotebook *notebook,gboolean scrollable
 * Returns: void
 * Assertion: Sets whether the tab label area will have arrows for scrolling if there are too many tabs to fit in the area.
 * Params Values: a newly created GtkNotebook*, TRUE
 * Expected: void  
 */
static void test_purpose_27()
{
    #define SHOW_SCROLLABLE TRUE
    
    GtkWidget* widget;
    gboolean show_scrollable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_scrollable (GTK_NOTEBOOK (widget), SHOW_SCROLLABLE);
    g_object_get(GTK_OBJECT(widget), "scrollable", &show_scrollable, NULL);
    if (show_scrollable != SHOW_SCROLLABLE) 
    {
        TEST_FAIL ("scrollable is %d, should be %d", 
                   show_scrollable, SHOW_SCROLLABLE);
    }
    
    
    #undef SHOW_SCROLLABLE
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_scrollable 
 * Params: GtkNotebook *notebook,gboolean scrollable
 * Returns: void
 * Assertion: Sets whether the tab label area will have arrows for scrolling if there are too many tabs to fit in the area.
 * Params Values: a newly created GtkNotebook*, FALSE
 * Expected: void  
 */
static void test_purpose_28()
{
    #define SHOW_SCROLLABLE FALSE
    
    GtkWidget* widget;
    gboolean show_scrollable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_notebook_set_scrollable (GTK_NOTEBOOK (widget), SHOW_SCROLLABLE);
    g_object_get(GTK_OBJECT(widget), "scrollable", &show_scrollable, NULL);
    if (show_scrollable != SHOW_SCROLLABLE) 
    {
        TEST_FAIL ("scrollable is %d, should be %d", 
                   show_scrollable, SHOW_SCROLLABLE);
    }
    
    
    #undef SHOW_SCROLLABLE
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_scrollable
 * Params: GtkNotebook *notebook
 * Returns: qboolean
 * Assertion: Returns whether the tab label area has arrows for scrolling.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_29()
{
    #define SHOW_SCROLLABLE TRUE
    
    GtkWidget* widget;
    gboolean show_scrollable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "scrollable", SHOW_SCROLLABLE,NULL);
    show_scrollable = gtk_notebook_get_scrollable(GTK_NOTEBOOK (widget));
    if (show_scrollable != SHOW_SCROLLABLE) 
    {
        TEST_FAIL ("scrollable is %d, should be %d", 
                   show_scrollable, SHOW_SCROLLABLE);
    }
    
    
    #undef SHOW_SCROLLABLE
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_scrollable
 * Params: GtkNotebook *notebook
 * Returns: qboolean
 * Assertion: Returns whether the tab label area has arrows for scrolling.
 * Params Values: a newly created GtkNotebook*
 * Expected: gboolean  
 */
static void test_purpose_30()
{
    #define SHOW_SCROLLABLE FALSE
    
    GtkWidget* widget;
    gboolean show_scrollable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "scrollable", SHOW_SCROLLABLE,NULL);
    show_scrollable = gtk_notebook_get_scrollable(GTK_NOTEBOOK (widget));
    if (show_scrollable != SHOW_SCROLLABLE) 
    {
        TEST_FAIL ("scrollable is %d, should be %d", 
                   show_scrollable, SHOW_SCROLLABLE);
    }
    
    
    #undef SHOW_SCROLLABLE
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, G_MININT
 * Expected: GtkWidget*  
 */
static void test_purpose_31()
{
    #define PAGE_NUM G_MININT
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, -10000
 * Expected: GtkWidget*  
 */
static void test_purpose_32()
{
    #define PAGE_NUM -10000
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, -1
 * Expected: GtkWidget*  
 */
static void test_purpose_33()
{
    #define PAGE_NUM -1
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 0
 * Expected: GtkWidget*  
 */
static void test_purpose_34()
{
    #define PAGE_NUM 0
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 1
 * Expected: GtkWidget*  
 */
static void test_purpose_35()
{
    #define PAGE_NUM 1
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 2
 * Expected: GtkWidget*  
 */
static void test_purpose_36()
{
    #define PAGE_NUM 2
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 3
 * Expected: GtkWidget*  
 */
static void test_purpose_37()
{
    #define PAGE_NUM 3
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 4
 * Expected: GtkWidget*  
 */
static void test_purpose_38()
{
    #define PAGE_NUM 4
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, 10000
 * Expected: GtkWidget*  
 */
static void test_purpose_39()
{
    #define PAGE_NUM 10000
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_nth_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: GtkWidget*
 * Assertion: Returns the child widget contained in page number page_num.
 * Params Values: a newly created GtkNotebook*, G_MAXINT
 * Expected: GtkWidget*  
 */
static void test_purpose_40()
{
    #define PAGE_NUM G_MAXINT
    GtkWidget* widget;
    GtkWidget* page;
    GtkWidget* page_real;
    GtkWidget* alignment;
    GtkWidget* button;
    GtkWidget* label;
    
    gchar* string;
    
    gint page_num;
    gint max_page = 3;
    gint i;
    GtkWidget *children[4];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page 1";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 1"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[0] = page;
    
    string = "Button Page 2";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 2"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[1] = page;
    
    string = "Button Page 3";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 3"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[2] = page;
    
    string = "Button Page 4";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    page = alignment;
    label = gtk_label_new ("TEXT 4"); 
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),page,label);
    children[3] = page;
    
    page_real = gtk_notebook_get_nth_page( GTK_NOTEBOOK (widget), PAGE_NUM);
    
    if (PAGE_NUM < 0)
        i = max_page;
    else
        i = PAGE_NUM;
    
    if(i < 0 || i > max_page)
    {
        if (page_real)
            TEST_FAIL ("gtk_notebook_get_nth_page should return NULL if page_num is out of bounds", NULL);
    }
    else
    {
        if (page_real != children[i])
            TEST_FAIL ("child widget should be %p, rather than %p", children[i], page_real, NULL);
    }
    
    #undef PAGE_NUM 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_41()
{
    #define MENU_LABEL gtk_label_new ("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new (NULL)
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_42()
{
    #define MENU_LABEL gtk_label_new (NULL)
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("TEXT")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_43()
{
    #define MENU_LABEL gtk_label_new ("TEXT")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("TEXT")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_44()
{
    #define MENU_LABEL gtk_label_new ("TEXT")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("!@#$%^&*")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_45()
{
    #define MENU_LABEL gtk_label_new ("!@#$%^&*")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_46()
{
    #define MENU_LABEL gtk_label_new ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_frame_new ("TEXT")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_47()
{
    #define MENU_LABEL gtk_frame_new ("TEXT")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *menu_label
 * Returns: void
 * Assertion: Changes the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, NULL
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Retrieves the menu label widget of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_48()
{
    #define MENU_LABEL NULL
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = MENU_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_menu_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    
    #undef MENU_LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_label_new(""), " "
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_49()
{
    #define MENU_TEXT " "
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_label_new(""), "Label"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_50()
{
    #define MENU_TEXT "Label"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_label_new(""), "\b\t\n"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_51()
{
    #define MENU_TEXT "\b\t\n"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_label_new(""), "!@#$%^&*"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_52()
{
    #define MENU_TEXT "!@#$%^&*"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_label_new(""), "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_53()
{
    #define MENU_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, NULL, "label"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_54()
{
    #define MENU_TEXT "label"
    #define LABEL NULL
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *menu_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the menu label of child.
 * Params Values: a newly created GtkNotebook*, gtk_frame_new(""), "label"
 * Expected: void
 * 
 * Name:  gtk_notebook_get_menu_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the menu label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_55()
{
    #define MENU_TEXT "label"
    #define LABEL gtk_frame_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* menu_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_menu_label_text (GTK_NOTEBOOK (widget),child,MENU_TEXT);
    
    menu_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (menu_text, (gchar*) MENU_TEXT)) 
    {
        TEST_FAIL ("menu_text is %s, should be %s", menu_text,(gchar*)MENU_TEXT);
    }
    if(!menu_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GTK_LABEL", NULL);
        }
    }
    
    #undef MENU_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_56()
{
    #define TAB_TEXT " "
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_57()
{
    #define TAB_TEXT "Label"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_58()
{
    #define TAB_TEXT "\b\t\n"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_59()
{
    #define TAB_TEXT "!@#$%^&*"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_60()
{
    #define TAB_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define LABEL gtk_label_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, NULL
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_61()
{
    #define TAB_TEXT "label"
    #define LABEL NULL
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child, const gchar *tab_text
 * Returns: void
 * Assertion: Creates a new label and sets it as the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_frame_new("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label_text 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: gchar*
 * Assertion: Retrieves the text of the tab label for the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: gchar*  
 */
static void test_purpose_62()
{
    #define TAB_TEXT "label"
    #define LABEL gtk_frame_new("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    const gchar* tab_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    
    gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (widget),child,TAB_TEXT);
    
    tab_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (widget),child);
    if (strcmp (tab_text, (gchar*) TAB_TEXT)) 
    {
        TEST_FAIL ("tab_text is %s, should be %s", tab_text,(gchar*)TAB_TEXT);
    }
    if(!tab_text && label)
    {
        if(GTK_LABEL (label))
        {
            TEST_FAIL ("child is not GtkLabel", NULL);
        }
    }
    
    #undef TAB_TEXT
    #undef LABEL
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Changes the tab label for child. 
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Returns the tab label widget for the page child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_63()
{
    #define TAB_LABEL gtk_label_new ("")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = TAB_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TAB_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Changes the tab label for child. 
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new (NULL)
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Returns the tab label widget for the page child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_64()
{
    #define TAB_LABEL gtk_label_new (NULL)
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = TAB_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TAB_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Changes the tab label for child. 
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("TEXT")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Returns the tab label widget for the page child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_65()
{
    #define TAB_LABEL gtk_label_new ("TEXT")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = TAB_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TAB_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Changes the tab label for child. 
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("!@#$%^&*")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Returns the tab label widget for the page child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_66()
{
    #define TAB_LABEL gtk_label_new ("!@#$%^&*")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = TAB_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TAB_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Changes the tab label for child. 
 * Params Values: a newly created GtkNotebook*, GtkWidget*, gtk_label_new ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789")
 * Expected: void
 * 
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion: Returns the tab label widget for the page child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_67()
{
    #define TAB_LABEL gtk_label_new ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789")
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = TAB_LABEL;
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    
    if (real_label != label) 
    {
        TEST_FAIL ("label is %s, should be %s", label,real_label);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TAB_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, TRUE, TRUE, GTK_PACK_START
 * Expected: void  
 */
static void test_purpose_68()
{
    #define EXPAND TRUE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, TRUE, FALSE, GTK_PACK_START
 * Expected: void  
 */
static void test_purpose_69()
{
    #define EXPAND TRUE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, FALSE, TRUE, GTK_PACK_START
 * Expected: void  
 */
static void test_purpose_70()
{
    #define EXPAND FALSE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, FALSE, FALSE, GTK_PACK_START
 * Expected: void  
 */
static void test_purpose_71()
{
    #define EXPAND FALSE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, TRUE, TRUE, GTK_PACK_END 
 * Expected: void  
 */
static void test_purpose_72()
{
    #define EXPAND TRUE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, TRUE, FALSE, GTK_PACK_END 
 * Expected: void  
 */
static void test_purpose_73()
{
    #define EXPAND TRUE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label_packing
 * Params: GtkNotebook *notebook,GtkWidget *child,gboolean expand, gboolean fill, GtkPackType pack_type
 * Returns: void
 * Assertion: Sets the packing parameters for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, FALSE, FALSE, GTK_PACK_END 
 * Expected: void  
 */
static void test_purpose_74()
{
    #define EXPAND FALSE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    label = gtk_label_new ("");
    
    gtk_notebook_append_page (GTK_NOTEBOOK (widget),child,label);
    
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (widget),child,EXPAND,FILL,PACK_TYPE);
    
    
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Appends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_75()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Appends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_76()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Appends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_77()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Appends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_78()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Appends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_79()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Appends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_80()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Appends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_81()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_append_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Appends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_82()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page appended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page appended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page appended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Prepends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_83()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Prepends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_84()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Prepends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_85()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: Prepends a page to notebook.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_86()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[32];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Prepends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_87()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Prepends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_88()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Prepends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_89()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prepend_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label
 * Returns: void
 * Assertion: Prepends a page to notebook, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_90()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[32];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_prepend_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    sprintf (buffer, "Page %i", N_PAGES - PAGE_NUM - 1);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page prepended at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page prepended at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, 0
 * Expected: void  
 */
static void test_purpose_91()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[64];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), child, tab_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, 0
 * Expected: void  
 */
static void test_purpose_92()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[64];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), child, tab_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, 10
 * Expected: void  
 */
static void test_purpose_93()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[64];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), child, tab_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page 
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, 7
 * Expected: void  
 */
static void test_purpose_94()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    
    gchar buffer[64];
    const gchar* label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), child, tab_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (label_text != NULL)
    {
        if (strcmp (label_text, buffer))
        {
            TEST_FAIL ("Label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_95()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[64];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    menu_label = gtk_label_new (buffer);
    gtk_notebook_insert_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_96()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[64];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    menu_label = gtk_label_new (buffer);
    gtk_notebook_insert_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_97()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[64];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    menu_label = gtk_label_new (buffer);
    gtk_notebook_insert_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_insert_page_menu
 * Params: GtkNotebook *notebook, GtkWidget *child, GtkWidget *tab_label, GtkWidget *menu_label, gint position
 * Returns: void
 * Assertion: Insert a page into notebook at the given position, specifying the widget to use as the label in the popup menu.
 * Params Values: a newly created GtkNotebook*, a newly created GtkWidget*, a newly created GtkWidget*, a newly created GtkWidget*  
 * Expected: void  
 */
static void test_purpose_98()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    GtkWidget* menu_label;
    
    gchar buffer[64];
    const gchar* tab_label_text;
    const gchar* menu_label_text;
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        menu_label = gtk_label_new (buffer);
        gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label); 
    }
    
    sprintf (buffer, "Page that was inserted at %i position.", PAGE_NUM);
    child = gtk_frame_new (buffer);
    tab_label = gtk_label_new (buffer);
    menu_label = gtk_label_new (buffer);
    gtk_notebook_insert_page_menu (GTK_NOTEBOOK (notebook), child, tab_label, menu_label, PAGE_NUM); 
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    tab_label_text = gtk_notebook_get_tab_label_text (GTK_NOTEBOOK (notebook), child);
    menu_label_text = gtk_notebook_get_menu_label_text (GTK_NOTEBOOK (notebook), child);
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("Title of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, page_title, buffer);        
        }
    } else {
            TEST_FAIL ("Title of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (tab_label_text != NULL)
    {
        if (strcmp (tab_label_text, buffer))
        {
            TEST_FAIL ("Tab label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, tab_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Tab label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    if (menu_label_text != NULL)
    {
        if (strcmp (menu_label_text, buffer))
        {
            TEST_FAIL ("Menu label text of page inserted at %i position = '%s', should be '%s'", PAGE_NUM, menu_label_text, buffer);        
        }
    } else {
            TEST_FAIL ("Menu label text of page inserted at %i position = NULL, should be '%s'", PAGE_NUM, buffer);        
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_remove_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: void
 * Assertion: Removes a page from the notebook given its index in the notebook.
 * Params Values: a newly created GtkNotebook*, 0
 * Expected: void  
 */
static void test_purpose_99()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
    }
    
    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), PAGE_NUM); 
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    if (child)
    {
        page_title = gtk_frame_get_label (GTK_FRAME (child));
        if (page_title != NULL)
        {
            if (!strcmp (page_title, buffer))
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
        } else {
            if (buffer == NULL)
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
    }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_remove_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: void
 * Assertion: Removes a page from the notebook given its index in the notebook.
 * Params Values: a newly created GtkNotebook*, 0
 * Expected: void  
 */
static void test_purpose_100()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
    }
    
    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), PAGE_NUM); 
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    if (child)
    {
        page_title = gtk_frame_get_label (GTK_FRAME (child));
        if (page_title != NULL)
        {
            if (!strcmp (page_title, buffer))
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
        } else {
            if (buffer == NULL)
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
    }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_remove_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: void
 * Assertion: Removes a page from the notebook given its index in the notebook.
 * Params Values: a newly created GtkNotebook*, 10
 * Expected: void  
 */
static void test_purpose_101()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
    }
    
    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), PAGE_NUM); 
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    if (child)
    {
        page_title = gtk_frame_get_label (GTK_FRAME (child));
        if (page_title != NULL)
        {
            if (!strcmp (page_title, buffer))
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
        } else {
            if (buffer == NULL)
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
    }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_remove_page 
 * Params: GtkNotebook *notebook, gint page_num
 * Returns: void
 * Assertion: Removes a page from the notebook given its index in the notebook.
 * Params Values: a newly created GtkNotebook*, 7
 * Expected: void  
 */
static void test_purpose_102()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
    }
    
    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), PAGE_NUM); 
    
    sprintf (buffer, "Page %i", PAGE_NUM);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    if (child)
    {
        page_title = gtk_frame_get_label (GTK_FRAME (child));
        if (page_title != NULL)
        {
            if (!strcmp (page_title, buffer))
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
        } else {
            if (buffer == NULL)
            {
                TEST_FAIL ("Page number %i was not removed.", PAGE_NUM);        
            }
    }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_page_num 
 * Params: GtkNotebook *notebook, GtkWidget *child
 * Returns: gint
 * Assertion: Finds the index of the page which contains the given child widget.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebooks page
 * Expected: 0  
 */
static void test_purpose_103()
{
    #define PAGE_NUM 0
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == PAGE_NUM)
        {
            saved_child = child;
        }
    }
    
    page_num = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), saved_child);
    
    if (page_num != PAGE_NUM)
    {
        TEST_FAIL ("gtk_notebook_page_num () return %i instead of %i", page_num, PAGE_NUM);        
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_page_num 
 * Params: GtkNotebook *notebook, GtkWidget *child
 * Returns: gint
 * Assertion: Finds the index of the page which contains the given child widget.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebooks page
 * Expected: 0  
 */
static void test_purpose_104()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == PAGE_NUM)
        {
            saved_child = child;
        }
    }
    
    page_num = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), saved_child);
    
    if (page_num != PAGE_NUM)
    {
        TEST_FAIL ("gtk_notebook_page_num () return %i instead of %i", page_num, PAGE_NUM);        
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_page_num 
 * Params: GtkNotebook *notebook, GtkWidget *child
 * Returns: gint
 * Assertion: Finds the index of the page which contains the given child widget.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebooks page
 * Expected: 10  
 */
static void test_purpose_105()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == PAGE_NUM)
        {
            saved_child = child;
        }
    }
    
    page_num = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), saved_child);
    
    if (page_num != PAGE_NUM)
    {
        TEST_FAIL ("gtk_notebook_page_num () return %i instead of %i", page_num, PAGE_NUM);        
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_page_num 
 * Params: GtkNotebook *notebook, GtkWidget *child
 * Returns: gint
 * Assertion: Finds the index of the page which contains the given child widget.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebooks page
 * Expected: 7  
 */
static void test_purpose_106()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == PAGE_NUM)
        {
            saved_child = child;
        }
    }
    
    page_num = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), saved_child);
    
    if (page_num != PAGE_NUM)
    {
        TEST_FAIL ("gtk_notebook_page_num () return %i instead of %i", page_num, PAGE_NUM);        
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the next page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_107()
{
    #define PAGE_NUM 0
    #define N_PAGES 2
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    gint correct_page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    correct_page_num = 
        (((PAGE_NUM - 1) >= (N_PAGES)) 
         ? (N_PAGES) : (((PAGE_NUM) < (0)) 
                        ? (N_PAGES) : (PAGE_NUM + 1)));
    
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the next page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_108()
{
    #define PAGE_NUM 0
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    gint correct_page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    correct_page_num = 
        (((PAGE_NUM - 1) >= (N_PAGES)) 
         ? (N_PAGES) : (((PAGE_NUM) < (0)) 
                        ? (N_PAGES) : (PAGE_NUM + 1)));
    
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the next page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_109()
{
    #define PAGE_NUM 9
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    gint correct_page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    correct_page_num = 
        (((PAGE_NUM - 1) >= (N_PAGES)) 
         ? (N_PAGES) : (((PAGE_NUM) < (0)) 
                        ? (N_PAGES) : (PAGE_NUM + 1)));
    
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the next page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_110()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    gint correct_page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    correct_page_num = 
        (((PAGE_NUM - 1) >= (N_PAGES)) 
         ? (N_PAGES) : (((PAGE_NUM) < (0)) 
                        ? (N_PAGES) : (PAGE_NUM + 1)));
    
    if (page_num != correct_page_num)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, correct_page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the last page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_111()
{
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), N_PAGES - 1);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, N_PAGES - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the last page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_112()
{
    #define N_PAGES 2
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), N_PAGES - 1);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, N_PAGES - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_next_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the last page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_113()
{
    #define N_PAGES 22
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), N_PAGES - 1);
    gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", N_PAGES, page_num, N_PAGES - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the previous page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_114()
{
    #define PAGE_NUM 1
    #define N_PAGES 2
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != PAGE_NUM - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", 
                   N_PAGES, page_num, PAGE_NUM - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the previous page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_115()
{
    #define PAGE_NUM 1
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != PAGE_NUM - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", 
                   N_PAGES, page_num, PAGE_NUM - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the previous page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_116()
{
    #define PAGE_NUM 10
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != PAGE_NUM - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", 
                   N_PAGES, page_num, PAGE_NUM - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Switches to the previous page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_117()
{
    #define PAGE_NUM 7
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), PAGE_NUM);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != PAGE_NUM - 1)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be %d", 
                   N_PAGES, page_num, PAGE_NUM - 1);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef PAGE_NUM 
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the first page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_118()
{
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
    }
    
    if (page_num != 0)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be 0", N_PAGES, page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the first page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_119()
{
    #define N_PAGES 2
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
    }
    
    if (page_num != 0)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be 0", N_PAGES, page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_prev_page 
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Nothing happens if the current page is the first page.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_120()
{
    #define N_PAGES 22
    
    GtkWidget* notebook;
    GtkWidget* child;
    
    gint i;
    gint page_num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        child = gtk_frame_new (NULL);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
    gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
    page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
    
    if (page_num != N_PAGES - 1)
    {
    }
    
    if (page_num != 0)
    {
        TEST_FAIL ("number of pages = %d, page_num = %d, should be 0", N_PAGES, page_num);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Reorders the page containing child, so that it appears in position position.
 * Params Values: a newly created GtkNotebook*, notebook page from 0 position, 0
 * Expected: void  
 */
static void test_purpose_121()
{
    #define N_PAGES 1
    #define OLD_POSITION 0
    #define NEW_POSITION 0
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), NEW_POSITION);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set in this position.", page_title, NEW_POSITION, buffer);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Reorders the page containing child, so that it appears in position position.
 * Params Values: a newly created GtkNotebook*, notebook page from 0 position, 10
 * Expected: void  
 */
static void test_purpose_122()
{
    #define N_PAGES 11
    #define OLD_POSITION 0
    #define NEW_POSITION 10
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), NEW_POSITION);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set in this position.", page_title, NEW_POSITION, buffer);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: Reorders the page containing child, so that it appears in position position.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, 0
 * Expected: void  
 */
static void test_purpose_123()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION 0
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), NEW_POSITION);
    page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set in this position.", page_title, NEW_POSITION, buffer);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_popup_enable
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Enables the popup menu: if the user clicks with the right mouse button on the bookmarks, a menu with all the pages will be popped up. 
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_124()
{
    GtkWidget* notebook;
    gboolean enable_popup;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (notebook), "enable-popup", FALSE, NULL);
    gtk_notebook_popup_enable (GTK_NOTEBOOK (notebook)); 
    g_object_get(GTK_OBJECT (notebook), "enable-popup", &enable_popup, NULL);
    
    if (enable_popup != TRUE)
    {
        TEST_FAIL ("gtk_notebook_popup_enable () doesn't work properly.", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_popup_disable
 * Params: GtkNotebook *notebook
 * Returns: void
 * Assertion: Disables the popup menu.
 * Params Values: a newly created GtkNotebook*
 * Expected: void  
 */
static void test_purpose_125()
{
    GtkWidget* notebook;
    gboolean enable_popup;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (notebook), "enable-popup", TRUE, NULL);
    gtk_notebook_popup_disable (GTK_NOTEBOOK (notebook)); 
    g_object_get(GTK_OBJECT (notebook), "enable-popup", &enable_popup, NULL);
    
    if (enable_popup != FALSE)
    {
        TEST_FAIL ("gtk_notebook_popup_disable () doesn't work properly.", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_126()
{
    #define EXPAND TRUE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_127()
{
    #define EXPAND TRUE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_128()
{
    #define EXPAND FALSE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_129()
{
    #define EXPAND FALSE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_START
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_130()
{
    #define EXPAND TRUE
    #define FILL TRUE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_131()
{
    #define EXPAND TRUE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_query_tab_label_packing
 * Params: GtkNotebook *notebook, GtkWidget *child, gboolean *expand, gboolean *fill, GtkPackType *pack_type
 * Returns: void
 * Assertion: Query the packing attributes for the tab label of the page containing child.
 * Params Values: a newly created GtkNotebook*, GtkWidget* that is notebook page, gboolean*, gboolean*, GtkPackType*
 * Expected: void  
 */
static void test_purpose_132()
{
    #define EXPAND FALSE
    #define FILL FALSE
    #define PACK_TYPE GTK_PACK_END 
    
    
    GtkWidget* notebook;
    GtkWidget* child;
    gboolean expand;
    gboolean fill; 
    GtkPackType pack_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook =  gtk_notebook_new ();
    
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_frame_new (NULL);
    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL);
    gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook), child, EXPAND, FILL, PACK_TYPE);
    gtk_notebook_query_tab_label_packing (GTK_NOTEBOOK (notebook), child, &expand, &fill, &pack_type);
    
    if (expand != EXPAND)
    {
        TEST_FAIL ("expand = %i, should be %i", expand, EXPAND);
    }
    if (fill != FILL)
    {
        TEST_FAIL ("fill = %i, should be %i", fill, FILL);
    }
    if (pack_type != PACK_TYPE)
    {
        TEST_FAIL ("pack_type = %i, should be %i", pack_type, PACK_TYPE);
    }
    #undef EXPAND 
    #undef FILL 
    #undef PACK_TYPE 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child
 * Returns: GtkWidget*
 * Assertion:  NULL is returned if child is not in notebook or if no tab label has specifically been set for child.
 * Params Values: a newly created GtkNotebook*, GtkWidget*
 * Expected: GtkWidget*  
 */
static void test_purpose_133()
{
    GtkWidget* widget;
    GtkWidget* widget_d;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* child_d;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
     
    label = NULL;
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child);
    if (real_label != NULL) 
    {
        TEST_FAIL ("label is %s, should be NULL",real_label,NULL);
    }
    
    
    widget_d =  gtk_notebook_new ();
    
    string = "Button Page";
    alignment = gtk_alignment_new (0.5,0.5,0.5,0.5);
    button = gtk_button_new_with_label (string);
    gtk_container_add (GTK_CONTAINER (alignment), button);
    child = alignment;
    
    child_d = gtk_alignment_new (0.5,0.5,0.5,0.5);
     
    label = gtk_label_new ("");
    gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, label);
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),child,label);
    
    real_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (widget),child_d);
    if (real_label != NULL) 
    {
        TEST_FAIL ("label is not NULL",NULL);
    }
    
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    gtk_widget_destroy (gtk_widget_get_toplevel (widget_d));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, 15
 * Expected: void  
 */
static void test_purpose_134()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION 15
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, -1
 * Expected: void  
 */
static void test_purpose_135()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION -1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, -5
 * Expected: void  
 */
static void test_purpose_136()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION -5
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, 4
 * Expected: void  
 */
static void test_purpose_137()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION 4
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, 7
 * Expected: void  
 */
static void test_purpose_138()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION 7
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_reorder_child 
 * Params: GtkNotebook *notebook, GtkWidget *child, gint position
 * Returns: void
 * Assertion: If position is greater than or equal to the number of children in the list or negative, child will be moved to the end of the list.
 * Params Values: a newly created GtkNotebook*, notebook page from 10 position, 100
 * Expected: void  
 */
static void test_purpose_139()
{
    #define N_PAGES 11
    #define OLD_POSITION 10
    #define NEW_POSITION 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* saved_child;
    
    gchar buffer[32];
    const gchar* page_title;
    gint i;
    gint new_pos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, NULL); 
        if (i == OLD_POSITION)
        {
            saved_child = child;
        }
    }
    
    gtk_notebook_reorder_child (GTK_NOTEBOOK (notebook), saved_child, NEW_POSITION); 
    
    new_pos = (((NEW_POSITION) > (N_PAGES - 1)) ? (N_PAGES - 1) : (((NEW_POSITION) < (0)) ? (N_PAGES - 1) : (NEW_POSITION)));
    
    sprintf (buffer, "Page %i", OLD_POSITION);
    
    child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), new_pos);
    if (child)
      page_title = gtk_frame_get_label (GTK_FRAME (child));
    
    if (page_title != NULL)
    {
        if (strcmp (page_title, buffer))
        {
            TEST_FAIL ("gtk_notebook_reorder_child () set '%s' at %i position, '%s' should be set at this position.", page_title, new_pos, buffer);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    #undef OLD_POSITION
    #undef NEW_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: If NULL is specified for tab_label, then the page will have the label 'page N'.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, 10
 * Expected: void  
 */
static void test_purpose_140()
{
    #define POS 1
    #define N_PAGES 10
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* saved_child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    G_CONST_RETURN gchar* text;
    gchar buffer[32];
    gchar* buf;
    gint num;
    gint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, gtk_label_new ("Page")); 
        if (i == POS)
            saved_child = child;
    }
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),saved_child,NULL);
    text = gtk_frame_get_label (GTK_FRAME (saved_child));
    
    sprintf (buffer, "Page %i", POS);
    if (strcmp (text,buffer))
    {
        TEST_FAIL ("Page label is '%s',should be '%s'",text,buffer);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POS
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: If NULL is specified for tab_label, then the page will have the label 'page N'.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, 10
 * Expected: void  
 */
static void test_purpose_141()
{
    #define POS 9
    #define N_PAGES 10
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* saved_child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    G_CONST_RETURN gchar* text;
    gchar buffer[32];
    gchar* buf;
    gint num;
    gint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, gtk_label_new ("Page")); 
        if (i == POS)
            saved_child = child;
    }
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),saved_child,NULL);
    text = gtk_frame_get_label (GTK_FRAME (saved_child));
    
    sprintf (buffer, "Page %i", POS);
    if (strcmp (text,buffer))
    {
        TEST_FAIL ("Page label is '%s',should be '%s'",text,buffer);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POS
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: If NULL is specified for tab_label, then the page will have the label 'page N'.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, 10
 * Expected: void  
 */
static void test_purpose_142()
{
    #define POS 5
    #define N_PAGES 10
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* saved_child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    G_CONST_RETURN gchar* text;
    gchar buffer[32];
    gchar* buf;
    gint num;
    gint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, gtk_label_new ("Page")); 
        if (i == POS)
            saved_child = child;
    }
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),saved_child,NULL);
    text = gtk_frame_get_label (GTK_FRAME (saved_child));
    
    sprintf (buffer, "Page %i", POS);
    if (strcmp (text,buffer))
    {
        TEST_FAIL ("Page label is '%s',should be '%s'",text,buffer);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POS
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: If NULL is specified for tab_label, then the page will have the label 'page N'.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, 10
 * Expected: void  
 */
static void test_purpose_143()
{
    #define POS 0
    #define N_PAGES 10
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* saved_child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    G_CONST_RETURN gchar* text;
    gchar buffer[32];
    gchar* buf;
    gint num;
    gint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, gtk_label_new ("Page")); 
        if (i == POS)
            saved_child = child;
    }
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),saved_child,NULL);
    text = gtk_frame_get_label (GTK_FRAME (saved_child));
    
    sprintf (buffer, "Page %i", POS);
    if (strcmp (text,buffer))
    {
        TEST_FAIL ("Page label is '%s',should be '%s'",text,buffer);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POS
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_set_tab_label 
 * Params: GtkNotebook *notebook,GtkWidget *child, GtkWidget *tab_label
 * Returns: void
 * Assertion: If NULL is specified for tab_label, then the page will have the label 'page N'.
 * Params Values: a newly created GtkNotebook*, GtkWidget*, 1
 * Expected: void  
 */
static void test_purpose_144()
{
    #define POS 0
    #define N_PAGES 1
    
    GtkWidget* widget;
    GtkWidget* label;
    GtkWidget* real_label;
    GtkWidget* child;
    GtkWidget* saved_child;
    GtkWidget* alignment;
    GtkWidget* button;
    gchar* string;
    G_CONST_RETURN gchar* text;
    gchar buffer[32];
    gchar* buf;
    gint num;
    gint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_notebook_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (widget), child, gtk_label_new ("Page")); 
        if (i == POS)
            saved_child = child;
    }
    
    gtk_notebook_set_tab_label (GTK_NOTEBOOK (widget),saved_child,NULL);
    text = gtk_frame_get_label (GTK_FRAME (saved_child));
    
    sprintf (buffer, "Page %i", POS);
    if (strcmp (text,buffer))
    {
        TEST_FAIL ("Page label is '%s',should be '%s'",text,buffer);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POS
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_n_pages
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Gets the number of pages in a notebook.
 * Params Values: a newly created GtkNotebook*
 * Expected: 0  
 */
static void test_purpose_145()
{
    #define N_PAGES 0
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    gchar buffer[32];
    gint i;
    gint real_n_pages;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    real_n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
    if (real_n_pages != N_PAGES)
    {
        TEST_FAIL ("real_n_pages = %d, N_PAGES = %d, they should be equal", real_n_pages, N_PAGES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_n_pages
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Gets the number of pages in a notebook.
 * Params Values: a newly created GtkNotebook*
 * Expected: 1  
 */
static void test_purpose_146()
{
    #define N_PAGES 1
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    gchar buffer[32];
    gint i;
    gint real_n_pages;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    real_n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
    if (real_n_pages != N_PAGES)
    {
        TEST_FAIL ("real_n_pages = %d, N_PAGES = %d, they should be equal", real_n_pages, N_PAGES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_n_pages
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Gets the number of pages in a notebook.
 * Params Values: a newly created GtkNotebook*
 * Expected: 11  
 */
static void test_purpose_147()
{
    #define N_PAGES 11
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    gchar buffer[32];
    gint i;
    gint real_n_pages;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    real_n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
    if (real_n_pages != N_PAGES)
    {
        TEST_FAIL ("real_n_pages = %d, N_PAGES = %d, they should be equal", real_n_pages, N_PAGES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_notebook_get_n_pages
 * Params: GtkNotebook *notebook
 * Returns: gint
 * Assertion: Gets the number of pages in a notebook.
 * Params Values: a newly created GtkNotebook*
 * Expected: 100  
 */
static void test_purpose_148()
{
    #define N_PAGES 100
    
    GtkWidget* notebook;
    GtkWidget* child;
    GtkWidget* tab_label;
    gchar buffer[32];
    gint i;
    gint real_n_pages;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    notebook = gtk_notebook_new ();
    if (!notebook)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_NOTEBOOK (notebook))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < N_PAGES; i++)
    {
        sprintf (buffer, "Page %i", i);
        child = gtk_frame_new (buffer);
        tab_label = gtk_label_new (buffer);
        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), child, tab_label); 
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (notebook);
    /******* -------------  *******/  
    
    real_n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
    if (real_n_pages != N_PAGES)
    {
        TEST_FAIL ("real_n_pages = %d, N_PAGES = %d, they should be equal", real_n_pages, N_PAGES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (notebook));
    
    #undef N_PAGES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkNotebook ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {NULL,0}
};
