/*
 * GtkSpinButton methods tests
 * Testing GtkSpinButton methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), G_MINDOUBLE, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = G_MINDOUBLE, digits = 1  
 */
static void test_purpose_1()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE G_MINDOUBLE
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), -1.0, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = -1.0, digits = 1  
 */
static void test_purpose_2()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE -1.0
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), 0.0, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = 0.0, digits = 1  
 */
static void test_purpose_3()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 0.0
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), 1.0, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = 1.0, digits = 1  
 */
static void test_purpose_4()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 1.0
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), 1.5, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = 1.5, digits = 1  
 */
static void test_purpose_5()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 1.5
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), G_MAXDOUBLE, 1
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = G_MAXDOUBLE, digits = 1  
 */
static void test_purpose_6()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE G_MAXDOUBLE
    #define DIGITS 1
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new
 * Params: GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: GtkSpinButton*
 * Assertion: Creates a new GtkSpinButton.
 * Params Values: gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), 1.0, 0
 * Expected: GtkSpinButton* with adjustment = gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0), climb_rate = 1.0, digits = 0  
 */
static void test_purpose_7()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 1.0
    #define DIGITS 0
    
    GtkWidget *widget;
    gdouble climb_rate;
    guint digits;
    GtkObject *adjustment;
    GtkObject *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = ADJUSTMENT;
    climb_rate = CLIMB_RATE;
    digits = DIGITS;
    
    if (adjustment)
    {
        widget = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), climb_rate, digits);
    } else {
        widget = gtk_spin_button_new (NULL, climb_rate, digits);
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != climb_rate)
    {
        TEST_FAIL("real_climb_rate = %i, %i", real_climb_rate, climb_rate);
    }
    
    g_object_get (GTK_OBJECT (widget), "digits", &real_digits, NULL);
    if (real_digits != digits)
    {
        TEST_FAIL("real_digits = %i, %i", real_digits, digits);
    }
    
    g_object_get(GTK_OBJECT(widget), "snap-to-ticks", &snap_to_ticks, NULL);
    if (snap_to_ticks != FALSE) 
    {
        TEST_FAIL("snap_to_ticks = %i", snap_to_ticks);
    }
    
    g_object_get(GTK_OBJECT(widget), "numeric", &numeric, NULL);
    if (numeric != FALSE) 
    {
        TEST_FAIL("numeric = %i", numeric);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap", &wrap, NULL);
    if (wrap != FALSE) 
    {
        TEST_FAIL("wrap = %i", wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "update-policy", &update_policy, NULL);
    if (update_policy != GTK_UPDATE_ALWAYS) 
    {
        TEST_FAIL("update policy = %i", update_policy);
    }
    
    g_object_get(GTK_OBJECT(widget), "value", &value, NULL);
    if (value != 1.0) 
    {
        TEST_FAIL("value = %f", value);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: G_MINDOUBLE, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: G_MINDOUBLE, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: G_MINDOUBLE, 1.0, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_8()
{
    #define MIN_V G_MINDOUBLE
    #define MAX_V 1.0
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: -100000.0, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: -100000.0, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: -100000.0, 1.0, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_9()
{
    #define MIN_V -100000.0
    #define MAX_V 1.0
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: -1.0 , 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: -1.0 , 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: -1.0 , 1.0, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_10()
{
    #define MIN_V -1.0 
    #define MAX_V 1.0
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 0.0, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 0.0, 1.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 0.0, 1.0, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_11()
{
    #define MIN_V 0.0
    #define MAX_V 1.0
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 1.5, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 1.5, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 1.5, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_12()
{
    #define MIN_V 1.0
    #define MAX_V 1.5
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 100000.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 100000.0, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 100000.0, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_13()
{
    #define MIN_V 1.0
    #define MAX_V 100000.0
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, G_MAXDOUBLE, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, G_MAXDOUBLE, 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, G_MAXDOUBLE, 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_14()
{
    #define MIN_V 1.0
    #define MAX_V G_MAXDOUBLE
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0, G_MINDOUBLE
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0, G_MINDOUBLE
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0, G_MINDOUBLE
 * Expected: GtkSpinButton*  
 */
static void test_purpose_15()
{
    #define MIN_V 1.0
    #define MAX_V 2.0
    #define STEP G_MINDOUBLE
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0, -100000.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0, -100000.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0, -100000.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_16()
{
    #define MIN_V 1.0
    #define MAX_V 2.0
    #define STEP -100000.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0, -1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0, -1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0, -1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_17()
{
    #define MIN_V 1.0
    #define MAX_V 2.0
    #define STEP -1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0 , 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0 , 1.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0 , 1.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_18()
{
    #define MIN_V 1.0
    #define MAX_V 2.0 
    #define STEP 1.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0 , 1.5
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0 , 1.5
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0 , 1.5
 * Expected: GtkSpinButton*  
 */
static void test_purpose_19()
{
    #define MIN_V 1.0
    #define MAX_V 2.0 
    #define STEP 1.5
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0, 100000.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0, 100000.0
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0, 100000.0
 * Expected: GtkSpinButton*  
 */
static void test_purpose_20()
{
    #define MIN_V 1.0
    #define MAX_V 2.0
    #define STEP 100000.0
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: This is a convenience constructor that allows creation of a numeric GtkSpinButton without manually creating an adjustment.
 * Params Values: 1.0, 2.0, G_MAXDOUBLE
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The value is initially set to the minimum value and a page increment of 10 * step is the default.
 * Params Values: 1.0, 2.0, G_MAXDOUBLE
 * Expected: GtkSpinButton*
 * 
 * Name: gtk_spin_button_new_with_range
 * Params: gdouble min, gdouble max, gdouble step
 * Returns: GtkSpinButton*
 * Assertion: The precision of the spin button is equivalent to the precision of step.
 * Params Values: 1.0, 2.0, G_MAXDOUBLE
 * Expected: GtkSpinButton*  
 */
static void test_purpose_21()
{
    #define MIN_V 1.0
    #define MAX_V 2.0
    #define STEP G_MAXDOUBLE
    gdouble climb_rate;
    guint digits;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks; 
    gboolean numeric;
    gboolean wrap;
    GtkSpinButtonUpdatePolicy update_policy;
    gdouble value;
    
    
    GtkWidget *widget;
    gdouble min;
    gdouble max;
    gdouble step;
    gdouble real_min;
    gdouble real_max;
    gdouble real_step;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_spin_button_new_with_range ((gdouble) MIN_V, MAX_V, STEP);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get (GTK_OBJECT (widget), "adjustment", &adjustment, NULL);
    if (!adjustment)
    {
        TEST_FAIL("adjustment == NULL", NULL);
        return;
    }
    
    if (adjustment->lower != MIN_V)
    {
        TEST_FAIL("min = %f, should be %f", adjustment->lower, (gdouble) MIN_V);
    }
    
    if (adjustment->value != MIN_V)
    {
        TEST_FAIL("value = %f, should be %f", adjustment->value, (gdouble) MIN_V);
    }
    
    if (adjustment->upper != MAX_V)
    {
        TEST_FAIL("upper = %f, should be %f", adjustment->upper, (gdouble) MAX_V);
    }
    
    if (adjustment->step_increment != STEP)
    {
        TEST_FAIL("step_increment = %f, should be %f", adjustment->step_increment, (gdouble) STEP);
    }
    
    if (STEP < G_MAXDOUBLE / 10)
    {
        if (adjustment->page_increment != 10*STEP)
        {
            TEST_FAIL("page_increment = %f, should be %f", adjustment->page_increment, (gdouble) 10* STEP);
        }
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MIN_V
    #undef MAX_V
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_adjustment
 * Params: GtkSpinButton *spin_button, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Replaces the GtkAdjustment associated with spin_button.
 * Params Values: GtkSpinButton *spin_button, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_22()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON (widget), adjustment);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_adjustment
 * Params: GtkSpinButton *spin_button, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Replaces the GtkAdjustment associated with spin_button.
 * Params Values: GtkSpinButton *spin_button, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_23()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON (widget), adjustment);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_adjustment
 * Params: GtkSpinButton *spin_button
 * Returns:  GtkAdjustment *adjustment
 * Assertion: Get the adjustment associated with a GtkSpinButton
 * Params Values: GtkSpinButton *spin_button
 * Expected:  GtkAdjustment *adjustment  
 */
static void test_purpose_24()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adjustment, NULL);
    real_adjustment = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget));
    
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_adjustment
 * Params: GtkSpinButton *spin_button
 * Returns:  GtkAdjustment *adjustment
 * Assertion: Get the adjustment associated with a GtkSpinButton
 * Params Values: GtkSpinButton *spin_button
 * Expected:  GtkAdjustment *adjustment  
 */
static void test_purpose_25()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "adjustment", adjustment, NULL);
    real_adjustment = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget));
    
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_digits
 * Params: GtkSpinButton *spin_button, guint digits
 * Returns: void 
 * Assertion: Set the precision to be displayed by spin_button.
 * Params Values: GtkSpinButton *spin_button, 1
 * Expected:  void  
 */
static void test_purpose_26()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define DIGITS 1
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_digits(GTK_SPIN_BUTTON (widget), DIGITS);
    g_object_get (GTK_OBJECT (widget), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_digits
 * Params: GtkSpinButton *spin_button, guint digits
 * Returns: void 
 * Assertion: Set the precision to be displayed by spin_button.
 * Params Values: GtkSpinButton *spin_button, 2
 * Expected:  void  
 */
static void test_purpose_27()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_digits(GTK_SPIN_BUTTON (widget), DIGITS);
    g_object_get (GTK_OBJECT (widget), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_digits
 * Params: GtkSpinButton *spin_button, guint digits
 * Returns: void 
 * Assertion: Set the precision to be displayed by spin_button.
 * Params Values: GtkSpinButton *spin_button, 5
 * Expected:  void  
 */
static void test_purpose_28()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 5
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_digits(GTK_SPIN_BUTTON (widget), DIGITS);
    g_object_get (GTK_OBJECT (widget), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_digits
 * Params: GtkSpinButton *spin_button, guint digits
 * Returns: void 
 * Assertion: Set the precision to be displayed by spin_button.
 * Params Values: GtkSpinButton *spin_button, 20
 * Expected:  void  
 */
static void test_purpose_29()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_digits(GTK_SPIN_BUTTON (widget), DIGITS);
    g_object_get (GTK_OBJECT (widget), "digits", &digits, NULL);
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_digits
 * Params: GtkSpinButton *spin_button
 * Returns: guint
 * Assertion: Fetches the precision of spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: 1  
 */
static void test_purpose_30()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define DIGITS 1
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "digits", DIGITS, NULL);
    
    digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_digits
 * Params: GtkSpinButton *spin_button
 * Returns: guint
 * Assertion: Fetches the precision of spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: 2  
 */
static void test_purpose_31()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "digits", DIGITS, NULL);
    
    digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_digits
 * Params: GtkSpinButton *spin_button
 * Returns: guint
 * Assertion: Fetches the precision of spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: 5  
 */
static void test_purpose_32()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 5
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "digits", DIGITS, NULL);
    
    digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_digits
 * Params: GtkSpinButton *spin_button
 * Returns: guint
 * Assertion: Fetches the precision of spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: 20  
 */
static void test_purpose_33()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define DIGITS 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "digits", DIGITS, NULL);
    
    digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (digits != DIGITS)
    {
        TEST_FAIL("digits = %i, should be %i", digits, DIGITS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Sets the step and page increments for spin_button.
 * Params Values: GtkSpinButton *spin_button, 1, 2
 * Expected:  void  
 */
static void test_purpose_34()
{
    #define STEP 1
    #define PAGE 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_increments(GTK_SPIN_BUTTON (widget), STEP, PAGE);
    
    step = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment;
    page = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment;
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, %f\n step = %f,  %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Sets the step and page increments for spin_button.
 * Params Values: GtkSpinButton *spin_button, 10, 20
 * Expected:  void  
 */
static void test_purpose_35()
{
    #define STEP 10
    #define PAGE 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_increments(GTK_SPIN_BUTTON (widget), STEP, PAGE);
    
    step = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment;
    page = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment;
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, %f\n step = %f,  %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Sets the step and page increments for spin_button.
 * Params Values: GtkSpinButton *spin_button, 100000, G_MAXDOUBLE
 * Expected:  void  
 */
static void test_purpose_36()
{
    #define STEP 100000
    #define PAGE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_increments(GTK_SPIN_BUTTON (widget), STEP, PAGE);
    
    step = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment;
    page = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment;
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, %f\n step = %f,  %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Gets the current step and page the increments used by spin_button.
 * Params Values: GtkSpinButton *spin_button, 1, 2
 * Expected:  void  
 */
static void test_purpose_37()
{
    #define STEP 1
    #define PAGE 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment = STEP;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment = PAGE;
    gtk_spin_button_get_increments(GTK_SPIN_BUTTON (widget), &step, &page);
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, should be %f\n step = %f,  should be %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Gets the current step and page the increments used by spin_button.
 * Params Values: GtkSpinButton *spin_button, 10, 20
 * Expected:  void  
 */
static void test_purpose_38()
{
    #define STEP 10
    #define PAGE 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment = STEP;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment = PAGE;
    gtk_spin_button_get_increments(GTK_SPIN_BUTTON (widget), &step, &page);
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, should be %f\n step = %f,  should be %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_increments
 * Params: GtkSpinButton *spin_button, gdouble step, gdouble page
 * Returns: void 
 * Assertion: Gets the current step and page the increments used by spin_button.
 * Params Values: GtkSpinButton *spin_button, 100000, G_MAXDOUBLE
 * Expected:  void  
 */
static void test_purpose_39()
{
    #define STEP 100000
    #define PAGE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble step;
    gdouble page;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 0.0, 0.0, 0.0));
    widget = gtk_spin_button_new (adjustment, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->step_increment = STEP;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->page_increment = PAGE;
    gtk_spin_button_get_increments(GTK_SPIN_BUTTON (widget), &step, &page);
    
    if ((page != PAGE) || (step != STEP))
    {
        TEST_FAIL (" page = %f, should be %f\n step = %f,  should be %f", page, PAGE, step, STEP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PAGE
    #undef STEP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Sets the minimum and maximum allowable values for spin_button
 * Params Values: GtkSpinButton *spin_button, 1, 2
 * Expected:  void  
 */
static void test_purpose_40()
{
    #define VMIN 1
    #define VMAX 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_range(GTK_SPIN_BUTTON (widget), VMIN, VMAX);
    
    min = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower;
    max = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper;
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, %f\n max = %f,  %f", min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Sets the minimum and maximum allowable values for spin_button
 * Params Values: GtkSpinButton *spin_button, 10, 20
 * Expected:  void  
 */
static void test_purpose_41()
{
    #define VMIN 10
    #define VMAX 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_range(GTK_SPIN_BUTTON (widget), VMIN, VMAX);
    
    min = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower;
    max = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper;
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, %f\n max = %f,  %f", min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Sets the minimum and maximum allowable values for spin_button
 * Params Values: GtkSpinButton *spin_button, G_MINDOUBLE              , G_MAXDOUBLE
 * Expected:  void  
 */
static void test_purpose_42()
{
    #define VMIN G_MINDOUBLE              
    #define VMAX G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_range(GTK_SPIN_BUTTON (widget), VMIN, VMAX);
    
    min = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower;
    max = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper;
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, %f\n max = %f,  %f", min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Gets the range allowed for spin_button.
 * Params Values: GtkSpinButton *spin_button, 1, 2
 * Expected:  void  
 */
static void test_purpose_43()
{
    #define VMIN 1
    #define VMAX 2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower = VMIN;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper = VMAX;
    gtk_spin_button_get_range(GTK_SPIN_BUTTON (widget), &min, &max);
    
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, should be %f\n max = %f,  should be %f", 
                   min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Gets the range allowed for spin_button.
 * Params Values: GtkSpinButton *spin_button, 10, 20
 * Expected:  void  
 */
static void test_purpose_44()
{
    #define VMIN 10
    #define VMAX 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower = VMIN;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper = VMAX;
    gtk_spin_button_get_range(GTK_SPIN_BUTTON (widget), &min, &max);
    
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, should be %f\n max = %f,  should be %f", 
                   min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_range
 * Params: GtkSpinButton *spin_button, gdouble min, gdouble max
 * Returns: void 
 * Assertion: Gets the range allowed for spin_button.
 * Params Values: GtkSpinButton *spin_button, G_MINDOUBLE              , G_MAXDOUBLE
 * Expected:  void  
 */
static void test_purpose_45()
{
    #define VMIN G_MINDOUBLE              
    #define VMAX G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble min;
    gdouble max;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->lower = VMIN;
    gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON (widget))->upper = VMAX;
    gtk_spin_button_get_range(GTK_SPIN_BUTTON (widget), &min, &max);
    
    
    if ((min != VMIN) || (max != VMAX))
    {
        TEST_FAIL (" min = %f, should be %f\n max = %f,  should be %f", 
                   min, VMIN, max, VMAX);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VMIN
    #undef VMAX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value_as_int
 * Params: GtkSpinButton *spin_button
 * Returns: gint
 * Assertion: Get the value spin_button represented as an integer.
 * Params Values: GtkSpinButton *spin_button
 * Expected:  0  
 */
static void test_purpose_46()
{
    #define VALUE 0
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint value;
    gint value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MININT, G_MAXINT, 1.0, 5.0, 0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    g_object_set (GTK_OBJECT (widget), "value", (double)value1, NULL);
    
    value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
    
    if (value != value1)
    {
        TEST_FAIL (" value as int = %i, %i", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value_as_int
 * Params: GtkSpinButton *spin_button
 * Returns: gint
 * Assertion: Get the value spin_button represented as an integer.
 * Params Values: GtkSpinButton *spin_button
 * Expected:  1  
 */
static void test_purpose_47()
{
    #define VALUE 1
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint value;
    gint value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MININT, G_MAXINT, 1.0, 5.0, 0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    g_object_set (GTK_OBJECT (widget), "value", (double)value1, NULL);
    
    value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
    
    if (value != value1)
    {
        TEST_FAIL (" value as int = %i, %i", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value_as_int
 * Params: GtkSpinButton *spin_button
 * Returns: gint
 * Assertion: Get the value spin_button represented as an integer.
 * Params Values: GtkSpinButton *spin_button
 * Expected:  G_MAXINT  
 */
static void test_purpose_48()
{
    #define VALUE G_MAXINT
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gint value;
    gint value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MININT, G_MAXINT, 1.0, 5.0, 0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    g_object_set (GTK_OBJECT (widget), "value", (double)value1, NULL);
    
    value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget));
    
    if (value != value1)
    {
        TEST_FAIL (" value as int = %i, %i", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_value
 * Params: GtkSpinButton *spin_button, gdouble value
 * Returns: void
 * Assertion: Set the value of spin_button.
 * Params Values: GtkSpinButton *spin_button, G_MINDOUBLE 
 * Expected:  void  
 */
static void test_purpose_49()
{
    #define VALUE G_MINDOUBLE 
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    gdouble value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value1);
    
    g_object_get (GTK_OBJECT (widget), "value", &value, NULL);
    
    if (value != value1)
    {
        TEST_FAIL (" value = %40.20f, %40.20f", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_value
 * Params: GtkSpinButton *spin_button, gdouble value
 * Returns: void
 * Assertion: Set the value of spin_button.
 * Params Values: GtkSpinButton *spin_button, 1.0
 * Expected:  void  
 */
static void test_purpose_50()
{
    #define VALUE 1.0
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    gdouble value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value1);
    
    g_object_get (GTK_OBJECT (widget), "value", &value, NULL);
    
    if (value != value1)
    {
        TEST_FAIL (" value = %40.20f, %40.20f", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_value
 * Params: GtkSpinButton *spin_button, gdouble value
 * Returns: void
 * Assertion: Set the value of spin_button.
 * Params Values: GtkSpinButton *spin_button, G_MAXFLOAT
 * Expected:  void  
 */
static void test_purpose_51()
{
    #define VALUE G_MAXFLOAT
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    gdouble value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value1);
    
    g_object_get (GTK_OBJECT (widget), "value", &value, NULL);
    
    if (value != value1)
    {
        TEST_FAIL (" value = %40.20f, %40.20f", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_value
 * Params: GtkSpinButton *spin_button, gdouble value
 * Returns: void
 * Assertion: Set the value of spin_button.
 * Params Values: GtkSpinButton *spin_button, G_MAXDOUBLE
 * Expected:  void  
 */
static void test_purpose_52()
{
    #define VALUE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    gdouble value1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    value1 = VALUE;
    gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value1);
    
    g_object_get (GTK_OBJECT (widget), "value", &value, NULL);
    
    if (value != value1)
    {
        TEST_FAIL (" value = %40.20f, %40.20f", value, value1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value
 * Params: GtkSpinButton *spin_button
 * Returns: gdouble value
 * Assertion: Get the value in the spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: G_MINDOUBLE   
 */
static void test_purpose_53()
{
    #define VALUE G_MINDOUBLE 
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "value", VALUE, NULL);
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    
    if (value != VALUE)
    {
        TEST_FAIL (" value = %40.20f, should be %40.20f", value, VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value
 * Params: GtkSpinButton *spin_button
 * Returns: gdouble value
 * Assertion: Get the value in the spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: 1.0  
 */
static void test_purpose_54()
{
    #define VALUE 1.0
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "value", VALUE, NULL);
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    
    if (value != VALUE)
    {
        TEST_FAIL (" value = %40.20f, should be %40.20f", value, VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value
 * Params: GtkSpinButton *spin_button
 * Returns: gdouble value
 * Assertion: Get the value in the spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: G_MAXFLOAT  
 */
static void test_purpose_55()
{
    #define VALUE G_MAXFLOAT
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "value", VALUE, NULL);
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    
    if (value != VALUE)
    {
        TEST_FAIL (" value = %40.20f, should be %40.20f", value, VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_value
 * Params: GtkSpinButton *spin_button
 * Returns: gdouble value
 * Assertion: Get the value in the spin_button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: G_MAXDOUBLE  
 */
static void test_purpose_56()
{
    #define VALUE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "value", VALUE, NULL);
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    
    if (value != VALUE)
    {
        TEST_FAIL (" value = %40.20f, should be %40.20f", value, VALUE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_update_policy
 * Params: GtkSpinButton *spin_button, GtkSpinButtonUpdatePolicy policy
 * Returns: void
 * Assertion: Sets the update behavior of a spin button.
 * Params Values: GtkSpinButton *spin_button, GTK_UPDATE_ALWAYS
 * Expected:  void  
 */
static void test_purpose_57()
{
    #define POLICY GTK_UPDATE_ALWAYS
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkSpinButtonUpdatePolicy policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("policy = %i, %i", policy, POLICY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_update_policy
 * Params: GtkSpinButton *spin_button, GtkSpinButtonUpdatePolicy policy
 * Returns: void
 * Assertion: Sets the update behavior of a spin button.
 * Params Values: GtkSpinButton *spin_button, GTK_UPDATE_IF_VALID
 * Expected:  void  
 */
static void test_purpose_58()
{
    #define POLICY GTK_UPDATE_IF_VALID
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkSpinButtonUpdatePolicy policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON (widget), POLICY);
    g_object_get (GTK_OBJECT (widget), "update-policy", &policy, NULL);
    
    if (policy != POLICY)
    {
        TEST_FAIL ("policy = %i, %i", policy, POLICY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_update_policy
 * Params: GtkSpinButton *spin_button
 * Returns: GtkSpinButtonUpdatePolicy
 * Assertion: Gets the update behavior of a spin button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: GTK_UPDATE_ALWAYS  
 */
static void test_purpose_59()
{
    #define POLICY GTK_UPDATE_ALWAYS
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkSpinButtonUpdatePolicy policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_spin_button_get_update_policy(GTK_SPIN_BUTTON (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("policy = %i, should be %i", policy, POLICY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_update_policy
 * Params: GtkSpinButton *spin_button
 * Returns: GtkSpinButtonUpdatePolicy
 * Assertion: Gets the update behavior of a spin button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: GTK_UPDATE_IF_VALID  
 */
static void test_purpose_60()
{
    #define POLICY GTK_UPDATE_IF_VALID
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkSpinButtonUpdatePolicy policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "update-policy", POLICY, NULL);
    policy = gtk_spin_button_get_update_policy(GTK_SPIN_BUTTON (widget));
    
    if (policy != POLICY)
    {
        TEST_FAIL ("policy = %i, should be %i", policy, POLICY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef POLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_numeric
 * Params: GtkSpinButton *spin_button, gboolean numeric
 * Returns: void
 * Assertion: Sets the flag that determines if non-numeric text can be typed into the spin button.
 * Params Values: GtkSpinButton *spin_button, FALSE
 * Expected:  void  
 */
static void test_purpose_61()
{
    #define NUMERIC FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean numeric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON (widget), NUMERIC);
    g_object_get (GTK_OBJECT (widget), "numeric", &numeric, NULL);
    
    if (numeric != NUMERIC)
    {
        TEST_FAIL ("numeric = %i, %i", numeric, NUMERIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef NUMERIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_numeric
 * Params: GtkSpinButton *spin_button, gboolean numeric
 * Returns: void
 * Assertion: Sets the flag that determines if non-numeric text can be typed into the spin button.
 * Params Values: GtkSpinButton *spin_button, TRUE
 * Expected:  void  
 */
static void test_purpose_62()
{
    #define NUMERIC TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean numeric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_numeric(GTK_SPIN_BUTTON (widget), NUMERIC);
    g_object_get (GTK_OBJECT (widget), "numeric", &numeric, NULL);
    
    if (numeric != NUMERIC)
    {
        TEST_FAIL ("numeric = %i, %i", numeric, NUMERIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef NUMERIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_numeric
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether non-numeric text can be typed into the spin button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: FALSE  
 */
static void test_purpose_63()
{
    #define NUMERIC FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean numeric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "numeric", NUMERIC, NULL);
    numeric = gtk_spin_button_get_numeric(GTK_SPIN_BUTTON (widget));
    
    if (numeric != NUMERIC)
    {
        TEST_FAIL ("numeric = %i, should be %i", numeric, NUMERIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef NUMERIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_numeric
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether non-numeric text can be typed into the spin button.
 * Params Values: GtkSpinButton *spin_button
 * Expected: TRUE  
 */
static void test_purpose_64()
{
    #define NUMERIC TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean numeric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "numeric", NUMERIC, NULL);
    numeric = gtk_spin_button_get_numeric(GTK_SPIN_BUTTON (widget));
    
    if (numeric != NUMERIC)
    {
        TEST_FAIL ("numeric = %i, should be %i", numeric, NUMERIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef NUMERIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_wrap
 * Params: GtkSpinButton *spin_button, gboolean wrap
 * Returns: void
 * Assertion: Sets the flag that determines if a spin button value wraps around to the opposite limit when the upper or lower limit of the range is exceeded. 
 * Params Values: GtkSpinButton *spin_button, FALSE
 * Expected:  void  
 */
static void test_purpose_65()
{
    #define WRAP FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean wrap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON (widget), WRAP);
    g_object_get (GTK_OBJECT (widget), "wrap", &wrap, NULL);
    
    if (wrap != WRAP)
    {
        TEST_FAIL ("wrap = %i, %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_wrap
 * Params: GtkSpinButton *spin_button, gboolean wrap
 * Returns: void
 * Assertion: Sets the flag that determines if a spin button value wraps around to the opposite limit when the upper or lower limit of the range is exceeded. 
 * Params Values: GtkSpinButton *spin_button, TRUE
 * Expected:  void  
 */
static void test_purpose_66()
{
    #define WRAP TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean wrap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON (widget), WRAP);
    g_object_get (GTK_OBJECT (widget), "wrap", &wrap, NULL);
    
    if (wrap != WRAP)
    {
        TEST_FAIL ("wrap = %i, %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_wrap
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether the spin button's value wraps around to the opposite limit when the upper or lower limit of the range is exceeded.'
 * Params Values: GtkSpinButton *spin_button
 * Expected: FALSE  
 */
static void test_purpose_67()
{
    #define WRAP FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean wrap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "wrap", WRAP, NULL);
    wrap = gtk_spin_button_get_wrap(GTK_SPIN_BUTTON (widget));
    
    if (wrap != WRAP)
    {
        TEST_FAIL ("wrap = %i, shold be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_wrap
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether the spin button's value wraps around to the opposite limit when the upper or lower limit of the range is exceeded.'
 * Params Values: GtkSpinButton *spin_button
 * Expected: TRUE  
 */
static void test_purpose_68()
{
    #define WRAP TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean wrap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "wrap", WRAP, NULL);
    wrap = gtk_spin_button_get_wrap(GTK_SPIN_BUTTON (widget));
    
    if (wrap != WRAP)
    {
        TEST_FAIL ("wrap = %i, shold be %i", wrap, WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_snap_to_ticks
 * Params: GtkSpinButton *spin_button, gboolean snap_to_ticks
 * Returns: void
 * Assertion: Sets the policy as to whether values are corrected to the nearest step increment when a spin button is activated after providing an invalid value.
 * Params Values: GtkSpinButton *spin_button, FALSE
 * Expected:  void  
 */
static void test_purpose_69()
{
    #define SNAP_TO_TICKS FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON (widget), SNAP_TO_TICKS);
    g_object_get (GTK_OBJECT (widget), "snap-to-ticks", &snap_to_ticks, NULL);
    
    if (snap_to_ticks != SNAP_TO_TICKS)
    {
        TEST_FAIL ("snap_to_ticks = %i, %i", snap_to_ticks, SNAP_TO_TICKS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_TO_TICKS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_set_snap_to_ticks
 * Params: GtkSpinButton *spin_button, gboolean snap_to_ticks
 * Returns: void
 * Assertion: Sets the policy as to whether values are corrected to the nearest step increment when a spin button is activated after providing an invalid value.
 * Params Values: GtkSpinButton *spin_button, TRUE
 * Expected:  void  
 */
static void test_purpose_70()
{
    #define SNAP_TO_TICKS TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON (widget), SNAP_TO_TICKS);
    g_object_get (GTK_OBJECT (widget), "snap-to-ticks", &snap_to_ticks, NULL);
    
    if (snap_to_ticks != SNAP_TO_TICKS)
    {
        TEST_FAIL ("snap_to_ticks = %i, %i", snap_to_ticks, SNAP_TO_TICKS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_TO_TICKS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_snap_to_ticks
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether the values are corrected to the nearest step.
 * Params Values: GtkSpinButton *spin_button
 * Expected: FALSE  
 */
static void test_purpose_71()
{
    #define SNAP_TO_TICKS FALSE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-to-ticks", SNAP_TO_TICKS, NULL);
    snap_to_ticks = gtk_spin_button_get_snap_to_ticks(GTK_SPIN_BUTTON (widget));
    
    if (snap_to_ticks != SNAP_TO_TICKS)
    {
        TEST_FAIL ("snap_to_ticks = %i, should be %i", snap_to_ticks, SNAP_TO_TICKS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_TO_TICKS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_get_snap_to_ticks
 * Params: GtkSpinButton *spin_button
 * Returns: gboolean
 * Assertion: Returns whether the values are corrected to the nearest step.
 * Params Values: GtkSpinButton *spin_button
 * Expected: TRUE  
 */
static void test_purpose_72()
{
    #define SNAP_TO_TICKS TRUE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gboolean snap_to_ticks;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, G_MINDOUBLE, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-to-ticks", SNAP_TO_TICKS, NULL);
    snap_to_ticks = gtk_spin_button_get_snap_to_ticks(GTK_SPIN_BUTTON (widget));
    
    if (snap_to_ticks != SNAP_TO_TICKS)
    {
        TEST_FAIL ("snap_to_ticks = %i, should be %i", snap_to_ticks, SNAP_TO_TICKS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_TO_TICKS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_STEP_FORWARD, 0
 * Expected:  void  
 */
static void test_purpose_73()
{
    #define SPIN_TYPE GTK_SPIN_STEP_FORWARD
    #define INIT_VALUE 0
    #define INCREMENT 3.7
    #define EXPECTED_VALUE 3.7
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_STEP_FORWARD, -5.7
 * Expected:  void  
 */
static void test_purpose_74()
{
    #define SPIN_TYPE GTK_SPIN_STEP_FORWARD
    #define INIT_VALUE -5.7
    #define INCREMENT 3.7
    #define EXPECTED_VALUE -2
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_STEP_BACKWARD, -17
 * Expected:  void  
 */
static void test_purpose_75()
{
    #define SPIN_TYPE GTK_SPIN_STEP_BACKWARD
    #define INIT_VALUE -17
    #define INCREMENT 3.0
    #define EXPECTED_VALUE -20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_PAGE_FORWARD, 0
 * Expected:  void  
 */
static void test_purpose_76()
{
    #define SPIN_TYPE GTK_SPIN_PAGE_FORWARD
    #define INIT_VALUE 0
    #define INCREMENT 0
    #define EXPECTED_VALUE 5
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_PAGE_BACKWARD, 0
 * Expected:  void  
 */
static void test_purpose_77()
{
    #define SPIN_TYPE GTK_SPIN_PAGE_BACKWARD
    #define INIT_VALUE 0
    #define INCREMENT 1
    #define EXPECTED_VALUE -5
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_HOME, 10
 * Expected:  void  
 */
static void test_purpose_78()
{
    #define SPIN_TYPE GTK_SPIN_HOME
    #define INIT_VALUE 10
    #define INCREMENT 0
    #define EXPECTED_VALUE -100000
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_spin
 * Params: GtkSpinButton *spin_button, GtkSpinType direction, gdouble increment
 * Returns: void
 * Assertion: Increment or decrement a spin button`s value in a specified direction by a specified amount.
 * Params Values: newly created GtkSpinButton *spin_button, GTK_SPIN_END, 100
 * Expected:  void  
 */
static void test_purpose_79()
{
    #define SPIN_TYPE GTK_SPIN_END
    #define INIT_VALUE 100
    #define INCREMENT 0
    #define EXPECTED_VALUE G_MAXDOUBLE
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    gdouble value;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (INIT_VALUE, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_spin (GTK_SPIN_BUTTON (widget), SPIN_TYPE, (gdouble)(INCREMENT));
    value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (widget));
    if (value != (gdouble)(EXPECTED_VALUE))
    {
        TEST_FAIL ("value = %lf, should be %lf ", value, (gdouble)(EXPECTED_VALUE));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SPIN_TYPE 
    #undef INIT_VALUE
    #undef INCREMENT
    #undef EXPECTED_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_update
 * Params: GtkSpinButton *spin_button
 * Returns: void
 * Assertion: Manually force an update of the spin button.
 * Params Values: newly created GtkSpinButton*
 * Expected:  void  
 */
static void test_purpose_80()
{
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0, -100000, G_MAXDOUBLE, 1.0, 5.0, 5.0));
    widget = gtk_spin_button_new (adjustment, 1, 5);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_spin_button_update (GTK_SPIN_BUTTON (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_configure
 * Params: GtkSpinButton *spin_button, GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: void
 * Assertion: Changes the properties of an existing spin button.
 * Params Values: GtkSpinButton *spin_button, GtkAdjustment *adjustment, 0.5, 1
 * Expected: void  
 */
static void test_purpose_81()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 0.5
    #define DIGITS 1
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_spin_button_configure (GTK_SPIN_BUTTON (widget), adjustment, CLIMB_RATE, DIGITS);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    real_digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (real_digits != DIGITS)
    {
        TEST_FAIL("real_digits = %i, should be %i", real_digits, DIGITS);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != CLIMB_RATE)
    {
        TEST_FAIL("real_climb_rate = %i, should be %i", real_climb_rate, CLIMB_RATE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_configure
 * Params: GtkSpinButton *spin_button, GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: void
 * Assertion: Changes the properties of an existing spin button.
 * Params Values: GtkSpinButton *spin_button, GtkAdjustment *adjustment, 10.49, 20
 * Expected: void  
 */
static void test_purpose_82()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)
    #define CLIMB_RATE 10.49
    #define DIGITS 20
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_spin_button_configure (GTK_SPIN_BUTTON (widget), adjustment, CLIMB_RATE, DIGITS);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    real_digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (real_digits != DIGITS)
    {
        TEST_FAIL("real_digits = %i, should be %i", real_digits, DIGITS);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != CLIMB_RATE)
    {
        TEST_FAIL("real_climb_rate = %i, should be %i", real_climb_rate, CLIMB_RATE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_spin_button_configure
 * Params: GtkSpinButton *spin_button, GtkAdjustment *adjustment, gdouble climb_rate, guint digits
 * Returns: void
 * Assertion: Changes the properties of an existing spin button.
 * Params Values: GtkSpinButton *spin_button, GtkAdjustment *adjustment, 0.6, 5
 * Expected: void  
 */
static void test_purpose_83()
{
    #define ADJUSTMENT gtk_adjustment_new (1.0, 0.0, 2.0, 5.0, 20.0, 100.0)
    #define CLIMB_RATE 0.6
    #define DIGITS 5
    
    GtkWidget *widget;
    GtkAdjustment *adjustment;
    GtkAdjustment *real_adjustment;
    gdouble real_climb_rate;
    guint real_digits;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adjustment = GTK_ADJUSTMENT (ADJUSTMENT);
    widget = gtk_spin_button_new (NULL, 1, 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SPIN_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    gtk_spin_button_configure (GTK_SPIN_BUTTON (widget), adjustment, CLIMB_RATE, DIGITS);
    g_object_get (GTK_OBJECT (widget), "adjustment", &real_adjustment, NULL);
    if (adjustment != real_adjustment)
    {
        TEST_FAIL("real_adjustment = %p, %p", real_adjustment, adjustment);
    }
    
    real_digits = gtk_spin_button_get_digits(GTK_SPIN_BUTTON (widget));
    if (real_digits != DIGITS)
    {
        TEST_FAIL("real_digits = %i, should be %i", real_digits, DIGITS);
    }
    
    g_object_get (GTK_OBJECT (widget), "climb-rate", &real_climb_rate, NULL);
    if (real_climb_rate != CLIMB_RATE)
    {
        TEST_FAIL("real_climb_rate = %i, should be %i", real_climb_rate, CLIMB_RATE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    #undef CLIMB_RATE
    #undef DIGITS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkSpinButton ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {NULL,0}
};
